*     *****************************************************************
*     ***************************************************************** 
* 		File-Name:      do_chapter3.do       	                 
*   	Date:           Feb 2018 (v1) May 2020 (final)                               
*     	Author:         LH                                          
*     	Purpose:        Create tables and figures for chapter 3 measuring IO authority 
*    	*     ****************************************************************  
*     ****************************************************************  
**penultimate change: 9/14/2018**
**last change: 5/05/2020
***NOTE TO USER: statistics produced by using the most recent dataset diverge slightly from this in the book//
*because we corrected minor errors and added scores for the International Coffee Organization (ICO) and EURAMET

use "DP_volIII_aug2018.dta",clear

*FIGURES 3.1 and 3.2: Gary's drawings

*FIGURE 3.3: Delegation and pooling (1975-2010)

//Identify first and last occurrences systematically in each IO panel to construct graphs
by ionumber, sort: egen lasttime = max(cond(delegation >=0, year, .))
gen byte last = year == lasttime

by ionumber, sort: egen firsttime = min(cond(delegation >=0, year, .))
gen byte first = year == firsttime

tab ioname if firsttime <=1975&lasttime==2010
summ pooling delegation if firsttime <=1975&lasttime==2010
 
    Variable |        Obs        Mean    Std. Dev.       Min        Max
-------------+---------------------------------------------------------
     pooling |      2,736    .3084533    .1886028          0   .7283334
  delegation |      2,736    .1843345    .1325801          0   .6519957


gen constantIO=1 if firsttime <=1975&lasttime==2010

egen number = count(ionumber), by(year) //generate count variable for number of IO for each year

*Collapse by 1-yr periods
collapse (mean) delegation pooling delaccess delsuspens delconstit delbudget delfincompl delpolicy ///
DS_sum_st poolaccess poolsuspens poolconstit poolcompliance poolbudget poolpolicy ///
 (sd) delsd=delegation poolsd=pooling (last) inception ionumber ioname number if constantIO==1, by(year )
tsset year
save "collapse_51 delegation pooling aug2018_components.dta"

**Figure 3.3: Delegation and pooling (1975-2010)
twoway (tsline delegation pooling) if year>=1975, tscale(range(1975 2010)) legend(order(1 "Mean delegation" 2 "Mean pooling")) tlabel(#10) scheme(s2mono)

*TABLE 3.1: CHANGE IN DELEGATION AND POOLING (1975-2010)
**now calculate change over time by IO for these 51 to produce Table 3.1
use "DP_volIII_aug2018.dta",clear
gen delegation75=delegation if year==1975
by ionumber, sort: replace delegation75=delegation75[_n-1] if delegation75==.
browse ioname year delegation delegation75 if constantIO==1
gen pooling75=pooling if year==1975
by ionumber, sort: replace pooling75=pooling75[_n-1] if pooling75==.
gen delegdiffsince75=delegation-delegation75 if end==1
gen pooldiffsince75=pooling-pooling75 if end==1

. tabstat pooldiffsince75 delegdiffsince75, stats (mean)

   stats |  poold~75  delegd~5
---------+--------------------
    mean |  .0576154  .0745981
------------------------------

gen delegdiff=0 if delegdiffsince75<=-0.01 & constantIO==1 & year==2010
replace delegdiff=1 if delegdiffsince75>-0.01 & delegdiffsince75<0.01 & constantIO==1 & year==2010
replace delegdiff=2 if delegdiffsince75>=0.01 & delegdiffsince75<0.076 & constantIO==1 & year==2010
replace delegdiff=3 if delegdiffsince75>=0.076 & delegdiffsince75!=. & constantIO==1 & year==2010
gen pooldiff=0 if pooldiffsince75<=-0.01 & constantIO==1 & year==2010
replace pooldiff=1 if pooldiffsince75>-0.01 & pooldiffsince75<0.01 & constantIO==1 & year==2010
replace pooldiff=2 if pooldiffsince75>=0.01 & pooldiffsince75<0.056 & constantIO==1 & year==2010
replace pooldiff=3 if pooldiffsince75>=0.056 & pooldiffsince75!=. & constantIO==1 & year==2010

label define delegdiff 0 "decline" 1 "status quo" 2 "<=mean increase" 3 ">mean increase"
label values delegdiff pooldiff delegdiff 

**Table 3.1: change in delegation and pooling (1975-2010)
tab delegdiff pooldiff if year==2010 & constantIO==1, missing

                 |                  pooldiff
       delegdiff |   decline  status qu  <= mean i  > mean in |     Total
-----------------+--------------------------------------------+----------
         decline |         0          1          0          1 |         2 
      status quo |         4         16          2          1 |        23 
<= mean increase |         2          3          1          2 |         8 
 > mean increase |         1          1          1         15 |        18 
-----------------+--------------------------------------------+----------
           Total |         7         21          4         19 |        51 

sort typeI ioname
. list ioname delegation pooling delegdiffsince75 pooldiffsince75 delegdiff pooldiff typeI if (delegdiff>2 & pooldiff!=0|pooldiff>2 & delegdiff!=0) & constantIO==1 & year==2010, clean noobs
    ioname   d~gation    pooling   delegd~5   pool~e75          delegdiff           pooldiff   typeI   members  
      OAPEC   .1984127        .22   .1428571          0   >=mean increase        status quo     task-specific  
       OSCE   .1884921   .2204167   .1884921   .1241667   >=mean increase   >=mean increase     task-specific  
       OTIF   .2116402   .5408334   .1468254   .4995834   >=mean increase   >=mean increase     task-specific  
       SACU   .0555556       .165   .0555556    .144375   <=mean increase   >=mean increase     task-specific  
        UPU   .3888889   .2841667   .0833333   .0833333   >=mean increase   >=mean increase     task-specific  
      ASEAN        .25    .130625        .25    .130625   >=mean increase   >=mean increase   general purpose  
         AU   .3099206     .56375   .1353175   .3908334   >=mean increase   >=mean increase   general purpose  
        CAN   .3996032   .2629167   .0980159   .1116667   >=mean increase   >=mean increase   general purpose  
      CEMAC    .468254    .289375   .4497355      .1175   >=mean increase   >=mean increase   general purpose  
    Caricom   .3121693   .3304167   .1137566   .1585417   >=mean increase   >=mean increase   general purpose  
     ComSec   .2558025   .3188021   .2002469   .1709896   >=mean increase   >=mean increase   general purpose  
     ECOWAS     .52166    .199375     .52166    .034375   >=mean increase   <=mean increase   general purpose  
         EU   .6519957   .2683333    .155964   .1720833   >=mean increase   >=mean increase   general purpose  
       LOAS   .4021825   .5079167   .2702381      .0825   >=mean increase   >=mean increase   general purpose  
        OAS   .2414021    .404375   .0568783        .22   <=mean increase   >=mean increase   general purpose  
       OECS   .3260582    .269375   .2070106     .19375   >=mean increase   >=mean increase   general purpose  
        OIC        .05   .3445834          0   .0691667        status quo   >=mean increase   general purpose  
        OIF   .1840046   .3961459    .103912   .0798959   >=mean increase   >=mean increase   general purpose  
        PIF   .2777778   .3107292   .2430556   .1952344   >=mean increase   >=mean increase   general purpose  
       SICA   .3412699   .2450521   .2857143   .1828646   >=mean increase   >=mean increase   general purpose  



list ioname delegation pooling delegdiffsince75 pooldiffsince75 typeI if (delegdiff<2 & pooldiff<2) & constantIO==1 & year==2010, clean noobs

     ioname   d~gation    pooling   delegd~75   poold~e75   typeI   members  
       CCNR          0   .1941667           0           0     task-specific  
       CERN   .2638889   .3403125           0           0     task-specific  
        FAO   .2007275   .5109375           0           0     task-specific  
       IAEA   .2592593   .6883333           0           0     task-specific  
       IBRD   .1768982   .4472917    .0062037           0     task-specific  
       ICAO    .255291   .6379167           0           0     task-specific  
        ILO   .4912037   .2444271           0           0     task-specific  
        IMO   .0277778   .5691667           0     -.01375     task-specific  
        IOM   .2539683   .5258334           0           0     task-specific  
        ITU   .2611111   .4370833           0     -.02125     task-specific  
     IWhale   .0555556      .3325           0           0     task-specific  
       NATO   .1353704    .075625           0           0     task-specific  
       OPEC   .0277778      .3875           0           0     task-specific  
        PCA   .0555556   .2916667           0           0     task-specific  
     UNESCO   .1662698   .6430209           0           0     task-specific  
      UNWTO   .0555556   .4979167           0           0     task-specific  
        WCO   .0138889   .3583333   -.0138889   -.0034375     task-specific  
        WHO   .1891534   .5866667           0   -.1416667     task-specific  
       WIPO   .2632275    .501875           0           0     task-specific  
    Benelux   .3512566    .103125           0           0   general purpose  
         UN   .2032408   .4673669   -.0018518   -.0438343   general purpose  

****
**text**
merge 1:1 ionumber year using "INDEP_replication.dta", keepusing(poolend poolchange pooling_ch pooling_chabs delend delchange delegation_ch delegation_chabs)
sort delchange
browse ioname delchange


sort ionumber year
by ionumber, sort: poolcreation=poolcreation[_n-1] if poolcreation==.
by ionumber, sort: replace poolcreation=poolcreation[_n-1] if poolcreation==.
by ionumber: egen meddel=median(delegation)
by ionumber: egen medpool=median(pooling)

gen delchangeab=abs(delchange)
gen poolchangeab=abs(poolchange)
corr delchangeab delchange meddel poolchangeab poolchange medpool
 
 corr delchangeab delchange meddel poolchangeab poolchange medpool
(obs=76)

             | delcha~b delcha~e   meddel poolch~b poolch~e  medpool
-------------+------------------------------------------------------
 delchangeab |   1.0000
   delchange |   0.9786   1.0000
      meddel |   0.0192   0.0239   1.0000
poolchangeab |   0.4251   0.4106  -0.0879   1.0000
  poolchange |   0.4510   0.4332  -0.0923   0.9328   1.0000
     medpool |  -0.3268  -0.3697   0.2479  -0.2531  -0.3308   1.0000



sort ionumber year
by ionumber: egen meddel=median(delegation)
by ionumber: egen medpool=median(pooling)
browse ioname meddel medpool
sort poolchange
list ioname poolcreation poolchange medpool if medpool>0.45 & end==1


      +------------------------------------------+
      | ioname   poolcr~n   poolcha~e    medpool |
      |------------------------------------------|
   1. |    WHO   .7283334   -.1416667   .5866667 |
   2. |   ICAO   .7004167      -.0625   .6379167 |
   5. |     UN   .5112012   -.0438343   .5112012 |
   8. |    COE   .4984375    -.015625   .4984375 |
   9. |    IMO   .5829167     -.01375   .5691667 |
      |------------------------------------------|
  13. |  UNIDO   .4845833           0   .4845833 |
  14. |   IAEA   .6883333           0   .6883333 |
  22. |    ISA    .530625           0    .530625 |
  29. |   WIPO    .501875           0    .501875 |
  34. |    IOM   .5258334           0   .5258334 |
      |------------------------------------------|
  35. |  UNWTO   .4979167           0   .4979167 |
  36. |    BIS   .5266666           0   .5266666 |
  38. |    WTO   .5516667           0   .5516667 |
  54. |    FAO   .3948959    .1160417   .5109375 |
  56. | UNESCO   .5203125    .1227084   .6430209 |
      +------------------------------------------+

**delegation and pooling in tandem or offset
corr delchange poolchange
 corr delchange poolchange if end==1
(obs=76)

             | delcha~e poolch~e
-------------+------------------
   delchange |   1.0000
  poolchange |   0.4332   1.0000

 corr delegation pooling if end==1
(obs=76)

	 
	 
 corr delegation pooling if end==1/*report this number which is consistent with figure*/
(obs=76)

. corr delegation pooling if end==1
(obs=76)

             | delega~n  pooling
-------------+------------------
  delegation |   1.0000
     pooling |   0.1234   1.0000


  
  

**//PS: for conclusion -- same but with all IOs, and calculate pooling and delegation since 1975 or since creation if later
gen deldiffcreation75=delegation-delegation_creation if end==1
replace deldiffcreation75= delegation-delegation75 if constantIO==1 & end==1
gen pooldiffcreation75=pooling-pooling_creation if end==1
replace pooldiffcreation75= pooling-pooling75 if constantIO==1 & end==1

gen delegdiffc=0 if deldiffcreation75<-0.01 & year==2010
replace delegdiffc=1 if deldiffcreation75>=-0.01 & deldiffcreation75<=0.01 & year==2010
replace delegdiffc=2 if deldiffcreation75>0.01 & deldiffcreation75<=0.08 & year==2010
replace delegdiffc=3 if deldiffcreation75>0.08 & deldiffcreation75!=. & year==2010
gen pooldiffc=0 if pooldiffcreation75<-0.01 & year==2010
replace pooldiffc=1 if pooldiffcreation75>=-0.01 & pooldiffcreation75<=0.01 & year==2010
replace pooldiffc=2 if pooldiffcreation75>0.01 & pooldiffcreation75<=0.0533 & year==2010
replace pooldiffc=3 if pooldiffcreation75>0.0533 & pooldiffcreation75!=. & year==2010 //**

**//FIGURES 3.4 AND 3.5: DELEGATION CHANGE AND POOLING CHANGE BY IO FOR ALL IOS
*preparation
sort ionumber year
by ionumber, sort: gen deldiffraw= delegation-delegation[_n-1]/*delegation raw change year to year*/
by ionumber, sort: gen pooldiffraw= pooling-pooling[_n-1]/*pooling raw change year to year*/
gen delend=delegation if end==1 /*delegation in last year extended to all years*/
gsort ionumber -year
bysort ionumber: replace delend=delend[_n-1] if delend==.
gen poolend=pooling if end==1 /*pooling in last year extended to all years*/
bysort ionumber: replace poolend=poolend[_n-1] if poolend==.

sort ionumber year
gen delegation_creation=delegation if initial==1
by ionumber, sort: replace delegation_creation=delegation_creation[_n-1] if delegation_creation==.
gen pooling_creation=pooling if initial==1
by ionumber, sort: replace pooling_creation=pooling_creation[_n-1] if pooling_creation==.

gsort ionumber -year
gen deldiff_end= delend-delegation_creation if end==1 /*change between first and last year (raw) extended*/
bysort ionumber: replace deldiff_end=deldiff_end[_n-1] if deldiff_end==.
gsort ionumber -year
gen pooldiff_end= poolend-pooling_creation if end==1 /*change between first and last year (raw) extended*/
bysort ionumber: replace pooldiff_end=pooldiff_end[_n-1] if pooldiff_end==.

by ionumber, sort: gen deldiff_ab=abs(delegation-delegation[_n-1])/*abs change in pooling year to year*/
by ionumber, sort: gen pooldiff_ab=abs(pooling-pooling[_n-1])/*abs change in pooling year to year*/
bysort ionumber: egen tot_deldiffab = total(deldiff_ab)/*total abs change extended to all years*/
bysort ionumber: egen tot_pooldiffab = total(pooldiff_ab) /*total abs change extended to all years*/


* FIGURE 3.4. Divide the horizontal box plots in two groups for DELEGATION
sort ioname
by ioname: egen meddel=median(delegation)
gen groupmeddel=0
///Use 38 IOs ordered by median values of delegation for each graph
tabstat meddel if end==1, stats (p50)

    variable |       p50
-------------+----------
      meddel |  .1656746
------------------------


replace groupmeddel=1 if meddel>.1656846 

tabstat tot_deldiffab if end==1, stats (p50)

    variable |       p50
-------------+----------
tot_deldif~b |  .0529861
------------------------
gen groupdel=0
replace groupdel=1 if tot_deldiffab>0.0529861

tabstat tot_pooldiffab if end==1, stats (p50)

    variable |       p50
-------------+----------
tot_pooldi~b |  .0459797
------------------------
gen grouppool=0
replace grouppool=1 if tot_pooldiffab>.0459797

**Horizontal boxplots with outside values: 
graph hbox delegation if groupdel==0, over(ioname, sort(1) label(labcolor(gs6))) medtype(marker) medmarker(mcolor(gs6) msize(small) msymbol(diamond)) cwhisker lines(lcolor(gs6) lwidth(thin) lpattern(solid)) ///
ytitle(Delegation (0-1)) ylabel(0(0.1)0.7)
graph save 3, replace
graph hbox delegation if groupdel==1, over(ioname, sort(1) label(labcolor(gs6))) medtype(marker) medmarker(mcolor(gs6) msize(small) msymbol(diamond)) cwhisker lines(lcolor(gs6) lwidth(thin) lpattern(solid)) ///
ytitle(Delegation (0-1)) ylabel(0(0.1)0.7)
graph save 4, replace
 
*Save graphs in working directory then combine them
graph combine 3.gph 4.gph,  saving(figure36) graphregion(fcolor(white))
graph export figure36.tif, replace width(1800)


*FIGURE 3.5: Divide the horizontal box plots in two groups for POOLING
sort ioname
by ioname: egen medpool=median(pooling)
gen group_p=0
///Use 38 IOs ordered by median values of delegation for each graph
tabstat medpool if end==1, stats (p50)
   variable |       p50
-------------+----------
       medpool |  .2167708
------------------------
replace group_p=1 if medpool>.2167708

**Horizontal boxplots with outside values
graph hbox pooling if grouppool==0, over(ioname, sort(1) label(labcolor(gs6))) medtype(marker) medmarker(mcolor(gs6) msize(small) msymbol(diamond)) cwhisker lines(lcolor(gs6) lwidth(thin) lpattern(solid)) ///
ytitle(Pooling (0-1)) ylabel(0(0.1)0.7)
graph save 1, replace
graph hbox pooling if grouppool==1, over(ioname, sort(1) label(labcolor(gs6))) medtype(marker) medmarker(mcolor(gs6) msize(small) msymbol(diamond)) cwhisker lines(lcolor(gs6) lwidth(thin) lpattern(solid)) ///
ytitle(Pooling (0-1)) ylabel(0(0.1)0.7)
graph save 2, replace

*Save graphs in working directory then combine them
graph combine 1.gph 2.gph, saving(figure310) graphregion(fcolor(white))
*Save graphs in working directory then combine them
graph export figure310.tif,replace width(1800)





