*     *****************************************************************
*     ***************************************************************** 
* 		File-Name:      do_chapter2.do       	                 
*   	Date:           Jan 2018                                
*     	Author:         LH                                          
*     	Purpose:        Create tables and figures for chapter 2 
*    	Input File:     DP_volIII.dta  
*     	Output File:    various			                         
*     	Data Output:    various                                            
*     	Previous file:  None                                            
*     	Machine:        	                                      
*     ****************************************************************  
*     ****************************************************************  
**last changed: 9/14/2018**
***NOTE TO USER: statistics produced by using the most recent dataset diverge slightly from this in the book//
*because we corrected minor errors and added scores for the International Coffee Organization (ICO) and EURAMET

use "DP_volIII_aug2018.dta",clear

*FIGURES 2.1 and 2.2: Gary's drawings

*FIGURE 2.3: Delegation and pooling (1975-2010)

//Identify first and last occurrences systematically in each IO panel to construct graphs
by ionumber, sort: egen lasttime = max(cond(delegation >=0, year, .))
gen byte last = year == lasttime

by ionumber, sort: egen firsttime = min(cond(delegation >=0, year, .))
gen byte first = year == firsttime

tab ioname if firsttime <=1975&lasttime==2010
summ pooling delegation if firsttime <=1975&lasttime==2010
 
    Variable |        Obs        Mean    Std. Dev.       Min        Max
-------------+---------------------------------------------------------
     pooling |      2,787    .3063394    .1864706          0   .7283334
  delegation |      2,787    .1840552    .1317292          0   .6519957

gen constantIO=1 if firsttime <=1975&lasttime==2010

egen number = count(ionumber), by(year) //generate count variable for number of IO for each year

*Collapse by 1-yr periods
collapse (mean) delegation pooling delaccess delsuspens delconstit delbudget delfincompl delpolicy ///
DS_sum_st poolaccess poolsuspens poolconstit poolcompliance poolbudget poolpolicy ///
 (sd) delsd=delegation poolsd=pooling (last) inception ionumber ioname number if constantIO==1, by(year )
tsset year
save "collapse_51 delegation pooling aug2018_components.dta"

**Figure 2.3: Delegation and pooling (1975-2010)
twoway (tsline delegation pooling) if year>=1975, tscale(range(1975 2010)) legend(order(1 "Mean delegation" 2 "Mean pooling")) tlabel(#10) scheme(s2mono)

*TABLE 2.1: CHANGE IN DELEGATION AND POOLING (1975-2010)
**now calculate change over time by IO for these 51 to produce Table 2.1
gen delegation75=delegation if year==1975
by ionumber, sort: replace delegation75=delegation75[_n-1] if delegation75==.
browse ioname year delegation delegation75 if constantIO==1
gen pooling75=pooling if year==1975
by ionumber, sort: replace pooling75=pooling75[_n-1] if pooling75==.
gen delegdiffsince75=delegation-delegation75 if end==1
gen pooldiffsince75=pooling-pooling75 if end==1

tabstat pooldiffsince75 delegdiffsince75, stats (mean)

   stats |  poold~75  delegd~5
---------+--------------------
    mean |  .0555935  .0761625
------------------------------

gen delegdiff=0 if delegdiffsince75<=-0.01 & constantIO==1 & year==2010
replace delegdiff=1 if delegdiffsince75>-0.01 & delegdiffsince75<0.01 & constantIO==1 & year==2010
replace delegdiff=2 if delegdiffsince75>=0.01 & delegdiffsince75<0.076 & constantIO==1 & year==2010
replace delegdiff=3 if delegdiffsince75>=0.076 & delegdiffsince75!=. & constantIO==1 & year==2010
gen pooldiff=0 if pooldiffsince75<=-0.01 & constantIO==1 & year==2010
replace pooldiff=1 if pooldiffsince75>-0.01 & pooldiffsince75<0.01 & constantIO==1 & year==2010
replace pooldiff=2 if pooldiffsince75>=0.01 & pooldiffsince75<0.056 & constantIO==1 & year==2010
replace pooldiff=3 if pooldiffsince75>=0.056 & pooldiffsince75!=. & constantIO==1 & year==2010

label define delegdiff 0 "decline" 1 "status quo" 2 "<=mean increase" 3 ">mean increase"
label values delegdiff pooldiff delegdiff 

**Table 2.1: change in delegation and pooling (1975-2010)
tab delegdiff pooldiff if year==2010 & constantIO==1, missing

                 |                  pooldiff
       delegdiff |   decline  status qu  <= mean i  > mean in |     Total
-----------------+--------------------------------------------+----------
         decline |         0          1          0          1 |         2 
      status quo |         4         16          2          1 |        23 
<= mean increase |         2          3          1          2 |         8 
 > mean increase |         1          1          1         15 |        18 
-----------------+--------------------------------------------+----------
           Total |         7         21          4         19 |        51 

sort typeI ioname
. list ioname delegation pooling delegdiffsince75 pooldiffsince75 delegdiff pooldiff typeI if (delegdiff>2 & pooldiff!=0|pooldiff>2 & delegdiff!=0) & constantIO==1 & year==2010, clean noobs
    ioname   d~gation    pooling   delegd~5   pool~e75          delegdiff           pooldiff   typeI   members  
      OAPEC   .1984127        .22   .1428571          0   >=mean increase        status quo     task-specific  
       OSCE   .1884921   .2204167   .1884921   .1241667   >=mean increase   >=mean increase     task-specific  
       OTIF   .2116402   .5408334   .1468254   .4995834   >=mean increase   >=mean increase     task-specific  
       SACU   .0555556       .165   .0555556    .144375   <=mean increase   >=mean increase     task-specific  
        UPU   .3888889   .2841667   .0833333   .0833333   >=mean increase   >=mean increase     task-specific  
      ASEAN        .25    .130625        .25    .130625   >=mean increase   >=mean increase   general purpose  
         AU   .3099206     .56375   .1353175   .3908334   >=mean increase   >=mean increase   general purpose  
        CAN   .3996032   .2629167   .0980159   .1116667   >=mean increase   >=mean increase   general purpose  
      CEMAC    .468254    .289375   .4497355      .1175   >=mean increase   >=mean increase   general purpose  
    Caricom   .3121693   .3304167   .1137566   .1585417   >=mean increase   >=mean increase   general purpose  
     ComSec   .2558025   .3188021   .2002469   .1709896   >=mean increase   >=mean increase   general purpose  
     ECOWAS     .52166    .199375     .52166    .034375   >=mean increase   <=mean increase   general purpose  
         EU   .6519957   .2683333    .155964   .1720833   >=mean increase   >=mean increase   general purpose  
       LOAS   .4021825   .5079167   .2702381      .0825   >=mean increase   >=mean increase   general purpose  
        OAS   .2414021    .404375   .0568783        .22   <=mean increase   >=mean increase   general purpose  
       OECS   .3260582    .269375   .2070106     .19375   >=mean increase   >=mean increase   general purpose  
        OIC        .05   .3445834          0   .0691667        status quo   >=mean increase   general purpose  
        OIF   .1840046   .3961459    .103912   .0798959   >=mean increase   >=mean increase   general purpose  
        PIF   .2777778   .3107292   .2430556   .1952344   >=mean increase   >=mean increase   general purpose  
       SICA   .3412699   .2450521   .2857143   .1828646   >=mean increase   >=mean increase   general purpose  



list ioname delegation pooling delegdiffsince75 pooldiffsince75 typeI if (delegdiff<2 & pooldiff<2) & constantIO==1 & year==2010, clean noobs

     ioname   d~gation    pooling   delegd~75   poold~e75   typeI   members  
       CCNR          0   .1941667           0           0     task-specific  
       CERN   .2638889   .3403125           0           0     task-specific  
        FAO   .2007275   .5109375           0           0     task-specific  
       IAEA   .2592593   .6883333           0           0     task-specific  
       IBRD   .1768982   .4472917    .0062037           0     task-specific  
       ICAO    .255291   .6379167           0           0     task-specific  
        ILO   .4912037   .2444271           0           0     task-specific  
        IMO   .0277778   .5691667           0     -.01375     task-specific  
        IOM   .2539683   .5258334           0           0     task-specific  
        ITU   .2611111   .4370833           0     -.02125     task-specific  
     IWhale   .0555556      .3325           0           0     task-specific  
       NATO   .1353704    .075625           0           0     task-specific  
       OPEC   .0277778      .3875           0           0     task-specific  
        PCA   .0555556   .2916667           0           0     task-specific  
     UNESCO   .1662698   .6430209           0           0     task-specific  
      UNWTO   .0555556   .4979167           0           0     task-specific  
        WCO   .0138889   .3583333   -.0138889   -.0034375     task-specific  
        WHO   .1891534   .5866667           0   -.1416667     task-specific  
       WIPO   .2632275    .501875           0           0     task-specific  
    Benelux   .3512566    .103125           0           0   general purpose  
         UN   .2032408   .4673669   -.0018518   -.0438343   general purpose  




**//PS: for conclusion -- same but with all IOs, and calculate pooling and delegation since 1975 or since creation if later
gen deldiffcreation75=delegation-delegation_creation if end==1
replace deldiffcreation75= delegation-delegation75 if constantIO==1 & end==1
gen pooldiffcreation75=pooling-pooling_creation if end==1
replace pooldiffcreation75= pooling-pooling75 if constantIO==1 & end==1

gen delegdiffc=0 if deldiffcreation75<-0.01 & year==2010
replace delegdiffc=1 if deldiffcreation75>=-0.01 & deldiffcreation75<=0.01 & year==2010
replace delegdiffc=2 if deldiffcreation75>0.01 & deldiffcreation75<=0.08 & year==2010
replace delegdiffc=3 if deldiffcreation75>0.08 & deldiffcreation75!=. & year==2010
gen pooldiffc=0 if pooldiffcreation75<-0.01 & year==2010
replace pooldiffc=1 if pooldiffcreation75>=-0.01 & pooldiffcreation75<=0.01 & year==2010
replace pooldiffc=2 if pooldiffcreation75>0.01 & pooldiffcreation75<=0.0533 & year==2010
replace pooldiffc=3 if pooldiffcreation75>0.0533 & pooldiffcreation75!=. & year==2010 //**

**//FIGURES 2.4 AND 2.5: DELEGATION CHANGE AND POOLING CHANGE BY IO FOR ALL IOS
*preparation
sort ionumber year
by ionumber, sort: gen deldiffraw= delegation-delegation[_n-1]/*delegation raw change year to year*/
by ionumber, sort: gen pooldiffraw= pooling-pooling[_n-1]/*pooling raw change year to year*/
gen delend=delegation if end==1 /*delegation in last year extended to all years*/
gsort ionumber -year
bysort ionumber: replace delend=delend[_n-1] if delend==.
gen poolend=pooling if end==1 /*pooling in last year extended to all years*/
bysort ionumber: replace poolend=poolend[_n-1] if poolend==.

sort ionumber year
gen delegation_creation=delegation if initial==1
by ionumber, sort: replace delegation_creation=delegation_creation[_n-1] if delegation_creation==.
gen pooling_creation=pooling if initial==1
by ionumber, sort: replace pooling_creation=pooling_creation[_n-1] if pooling_creation==.

gsort ionumber -year
gen deldiff_end= delend-delegation_creation if end==1 /*change between first and last year (raw) extended*/
bysort ionumber: replace deldiff_end=deldiff_end[_n-1] if deldiff_end==.
gsort ionumber -year
gen pooldiff_end= poolend-pooling_creation if end==1 /*change between first and last year (raw) extended*/
bysort ionumber: replace pooldiff_end=pooldiff_end[_n-1] if pooldiff_end==.

by ionumber, sort: gen deldiff_ab=abs(delegation-delegation[_n-1])/*abs change in pooling year to year*/
by ionumber, sort: gen pooldiff_ab=abs(pooling-pooling[_n-1])/*abs change in pooling year to year*/
bysort ionumber: egen tot_deldiffab = total(deldiff_ab)/*total abs change extended to all years*/
bysort ionumber: egen tot_pooldiffab = total(pooldiff_ab) /*total abs change extended to all years*/


* FIGURE 2.4. Divide the horizontal box plots in two groups for DELEGATION
sort ioname
by ioname: egen meddel=median(delegation)
gen groupmeddel=0
///Use 38 IOs ordered by median values of delegation for each graph
tabstat meddel if end==1, stats (p50)
   variable |       p50
-------------+----------
      meddel |  .1656846
------------------------

replace groupmeddel=1 if meddel>.1656846 

tabstat tot_deldiffab if end==1, stats (p50)

    variable |       p50
-------------+----------
tot_deldif~b |  .0554861
------------------------
gen groupdel=0
replace groupdel=1 if tot_deldiffab>0.0554861

tabstat tot_pooldiffab if end==1, stats (p50)

    variable |       p50
-------------+----------
tot_pooldi~b |  .0459797
------------------------
gen grouppool=0
replace grouppool=1 if tot_pooldiffab>.0459797

**Horizontal boxplots with outside values: 
graph hbox delegation if groupdel==0, over(ioname, sort(1) label(labcolor(gs6))) medtype(marker) medmarker(mcolor(gs6) msize(small) msymbol(diamond)) cwhisker lines(lcolor(gs6) lwidth(thin) lpattern(solid)) ///
ytitle(Delegation (0-1)) ylabel(0(0.1)0.7)
graph save 3, replace
graph hbox delegation if groupdel==1, over(ioname, sort(1) label(labcolor(gs6))) medtype(marker) medmarker(mcolor(gs6) msize(small) msymbol(diamond)) cwhisker lines(lcolor(gs6) lwidth(thin) lpattern(solid)) ///
ytitle(Delegation (0-1)) ylabel(0(0.1)0.7)
graph save 4, replace
 
*Save graphs in working directory then combine them
graph combine 3.gph 4.gph,  saving(figure36) graphregion(fcolor(white))
graph export figure36.tif, replace width(1800)


*FIGURE 2.5: Divide the horizontal box plots in two groups for POOLING
sort ioname
by ioname: egen medpool=median(pooling)
gen group_p=0
///Use 38 IOs ordered by median values of delegation for each graph
tabstat medpool if end==1, stats (p50)
   variable |       p50
-------------+----------
       medpool |  .2167708
------------------------
replace group_p=1 if medpool>.2167708

**Horizontal boxplots with outside values
graph hbox pooling if grouppool==0, over(ioname, sort(1) label(labcolor(gs6))) medtype(marker) medmarker(mcolor(gs6) msize(small) msymbol(diamond)) cwhisker lines(lcolor(gs6) lwidth(thin) lpattern(solid)) ///
ytitle(Pooling (0-1)) ylabel(0(0.1)0.7)
graph save 1, replace
graph hbox pooling if grouppool==1, over(ioname, sort(1) label(labcolor(gs6))) medtype(marker) medmarker(mcolor(gs6) msize(small) msymbol(diamond)) cwhisker lines(lcolor(gs6) lwidth(thin) lpattern(solid)) ///
ytitle(Pooling (0-1)) ylabel(0(0.1)0.7)
graph save 2, replace

*Save graphs in working directory then combine them
graph combine 1.gph 2.gph, saving(figure310) graphregion(fcolor(white))
*Save graphs in working directory then combine them
graph export figure310.tif,replace width(1800)

**sort on total absolute change for big movers [not used]
sort tot_pooldiffab medpool ioname
list ioname tot_pooldiffab medpool if end==1, clean
graph hbox pooling if grouppool==0, over(ioname, sort(1) label(labcolor(gs6))) medtype(marker) medmarker(mcolor(gs6) msize(small) msymbol(diamond)) cwhisker lines(lcolor(gs6) lwidth(thin) lpattern(solid)) ///
ytitle(Pooling (0-1)) ylabel(0(0.1)0.7)
graph save 1, replace
graph hbox pooling if grouppool==1, over(ioname, sort(tot_pooldiffab) label(labcolor(gs6))) medtype(marker) medmarker(mcolor(gs6) msize(small) msymbol(diamond)) cwhisker lines(lcolor(gs6) lwidth(thin) lpattern(solid)) ///
ytitle(Pooling (0-1)) ylabel(0(0.1)0.7)
graph save 2, replace
*Save graphs in working directory then combine them
graph combine 1.gph 2.gph, saving(figure310) graphregion(fcolor(white))

sort tot_deldiffab meddel ioname
graph hbox delegation if groupdel==0, over(ioname, sort(1) label(labcolor(gs6))) medtype(marker) medmarker(mcolor(gs6) msize(small) msymbol(diamond)) cwhisker lines(lcolor(gs6) lwidth(thin) lpattern(solid)) ///
ytitle(Delegation (0-1)) ylabel(0(0.1)0.7)
graph save 3, replace
graph hbox delegation if groupdel==1, over(ioname, sort(tot_deldiffab) label(labcolor(gs6))) medtype(marker) medmarker(mcolor(gs6) msize(small) msymbol(diamond)) cwhisker lines(lcolor(gs6) lwidth(thin) lpattern(solid)) ///
ytitle(Delegation (0-1)) ylabel(0(0.1)0.7)
graph save 4, replace
 
*Save graphs in working directory then combine them
graph combine 3.gph 4.gph,  saving(figure36) graphregion(fcolor(white))
graph export figure36.tif, replace width(1800)


**FIGURE 2.6: Delegation and Pooling at end
twoway (scatter pooling delegation if end==1, mcolor(gs3) msize(small) msymbol(circle) mlabel(ioname) mlabsize(small) mlabgap(minuscule)), ytitle(Pooling) ylabel(0(.1).7) xtitle(Delegation) xlabel(0(.1).7)







**************not used************

*Times-series graphs for delegation, aggregate with bars for nr of IOs
twoway (tsline number, recast(bar) yaxis(2) fintensity(20) ) (tsline delegation) if year>=1975 ,  tscale(range(1975 2010)) ///
ytitle(Delegation) ytitle(Number of IOs, axis(2)) legend(order(1 "Number of IOs" 2 "Mean delegation score" )) ///
tlabel(#10) yscale(range(50 76) axis(2)) yscale(alt axis(2)) yscale(alt) scheme(s2mono) ///
ylabel(, angle(horizontal)) ylabel(, angle(horizontal) axis(2)) graphregion(fcolor(white)) xtitle("")


**Figure 2.x: Delegation (1975-2010)
graph save figure31, replace
graph export figure31.tif, width(1800)

*Times-series graphs for pooling, aggregate with bars for nr of IOs
twoway (tsline number, recast(bar) yaxis(2) fintensity(20) ) (tsline pooling) if year>=1975 ,  tscale(range(1975 2010)) ///
ytitle(Pooling) ytitle(Number of IOs, axis(2)) legend(order(1 "Number of IOs" 2 "Mean pooling score" )) ///
tlabel(#10) yscale(range(50 76) axis(2)) yscale(alt axis(2)) yscale(alt) scheme(s2mono) ///
ylabel(, angle(horizontal)) ylabel(, angle(horizontal) axis(2)) graphregion(fcolor(white)) xtitle("")

**Figure 2.x: Pooling (1975-2010)
graph save figure32, replace
graph export figure32.tif, width(1800)

gen deleglow=delegation- delsd
gen deleghigh=delegation+delsd
gen poollow=pooling- poolsd
gen poolhigh=pooling+poolsd

twoway (tsline delegation deleglow deleghigh) if year>=1975, tscale(range(1975 2010)) legend(order(1 "Mean delegation" 2 "Low sd delegation" 3 "High sd delegation")) tlabel(#10) scheme(s2mono)

twoway (tsline pooling poollow poolhigh) if year>=1975, tscale(range(1975 2010)) legend(order(1 "Mean pooling" 2 "Low sd pooling" 3 "High sd pooling")) tlabel(#10) scheme(s2mono)


use: "MASTER.dta"
 twoway (tsline delegation pooling) if constantIO==1 & year>1949 & year<2011, xscale( range (19
> 50 2010)) by(ioname) yscale (range(0 .5))



**Figure 2.x: Delegation by decision area (1975-2010)
//Line graph for all dimensions of delegation
twoway (tsline delsuspens, lpattern(longdash_dot)) ///
(tsline delconstit) (tsline delbudget) ///
(tsline delfincompl, lpattern(solid)) ///
 (tsline delaccess) (tsline delpolicy)  if  year>=1975, ///
 ytitle(Delegation) ytitle(, margin(small))  ///
 ttitle(, margin(small)) tscale(range(1975 2010)) tlabel(#10) ///
  legend(order(1 "Suspension" 2 "Constitutional reform" 3 "Budgetary allocation" ///
 4 "Financial compliance" 5 "Accession" 6 "Policy making" ) size(small)) scheme(lean1) xtitle("")

 graph save figure33, replace
 graph export figure33.tif, width(1800)

 **Figure 2.x: Pooling by decision area (1975-2010)
//Line graph for all dimensions of pooling
twoway (tsline poolsuspens, lpattern(longdash_dot)) ///
 (tsline poolconstit) (tsline poolbudget) (tsline poolcompliance, lpattern(solid)) ///
 (tsline poolaccess) (tsline poolpolicy) if  year>=1975, ///
 ytitle(Pooling) ytitle(, margin(small))  ///
 ttitle(, margin(small)) tscale(range(1975 2010)) tlabel(#10) ///
 legend(order(1 "Suspension" 2 "Constitutional reform" 3 "Budgetary allocation" ///
 4 "Financial compliance" 5 "Accession" 6 "Policy making" ) size(small)) scheme(lean1) xtitle("")

 graph save figure37, replace
 graph export figure37.tif, width(1800)

 tabstat delegation pooling if year>1974, stats (mean) by (year)
 
 
 *TABLE 3.4: Correlation matrix: TABLE 3.4
use "DP_volIII_sept2017.dta", clear
 *DELEGATION
pca delaccess delsuspens delconstit delbudget delfincompl delpolicy, components(1) 
predict pca
alpha delaccess delsuspens delconstit delbudget delfincompl delpolicy, gen (alpha)
correl delegation pca alpha
*POOLING
pca poolaccess poolsuspens poolconstit poolcompliance poolbudget poolpolicy , components(1) 
predict pca_p
alpha poolaccess poolsuspens poolconstit poolcompliance poolbudget poolpolicy, gen (alpha_p)
correl pooling pca_p alpha_p
correl delegation pca pooling pca_p 

(obs=3,366)

             | delega~n      pca  pooling    pca_p
-------------+------------------------------------
  delegation |   1.0000
         pca |   0.9991   1.0000
     pooling |   0.2263   0.2291   1.0000
       pca_p |   0.2347   0.2372   0.9967   1.0000

correl pca pooling pca_p alpha_p

*Table 3.3: Factor analysis
pca delaccess delsuspens delconstit delbudget delfincompl delpolicy ///
poolaccess poolsuspens poolconstit poolcompliance poolbudget poolpolicy, components(2) 
rotate, promax

Principal components/correlation                 Number of obs    =      3,366
                                                 Number of comp.  =          2
                                                 Trace            =         12
    Rotation: oblique promax (Kaiser off)        Rho              =     0.6089

    --------------------------------------------------------------------------
       Component |     Variance   Proportion     Rotated comp. are correlated
    -------------+------------------------------------------------------------
           Comp1 |      4.26582       0.3555
           Comp2 |      3.00808       0.2507
    --------------------------------------------------------------------------

Rotated components 

    ------------------------------------------------
        Variable |    Comp1     Comp2 | Unexplained 
    -------------+--------------------+-------------
       delaccess |   0.4213   -0.0510 |       .2682 
      delsuspens |   0.3793    0.0566 |       .3321 
      delconstit |   0.4396   -0.0216 |       .1849 
       delbudget |   0.4104   -0.0142 |       .2858 
     delfincompl |   0.3475    0.0626 |       .4289 
       delpolicy |   0.4257   -0.0290 |       .2407 
      poolaccess |   0.0089    0.4384 |       .4077 
     poolsuspens |   0.0176    0.3667 |       .5775 
     poolconstit |  -0.0019    0.4245 |        .453 
    poolcompli~e |   0.0290    0.4688 |       .3026 
      poolbudget |  -0.1131    0.4345 |       .4607 
      poolpolicy |   0.0373    0.2716 |        .751 
    ------------------------------------------------

*TABLE 3.5 AND 3.6: Descriptive stats
tabstat delaccess delsuspens delconstit ///
delbudget delfincompl delpolicy del_agenda del_final DS_sum_st delegation, stats ///
(mean p50 cv min max p25 p75)

   stats |  delacc~s  delsus~s  delcon~t  delbud~t  delfin~l  delpol~y  del_ag~a  del_fi~l  DS_sum~t  delega~n
---------+----------------------------------------------------------------------------------------------------
    mean |  .1383219  .1085949  .1280535  .3175958  .1308557  .2684391   .231399  .0496133  .2649181  .1819768
     p50 |  .1428571  .1190476  .1190476  .3333333  .1190476  .2539683  .2083333         0         0  .1746032
      cv |  1.153211  1.127834  1.118721  .6261153  1.143222  .6412091  .6382461  2.200772  1.103576  .7283759
     min |         0         0         0         0         0         0         0         0         0         0
     max |  .7777778  .6428571  .6444445         1  .6666667  .9333333     .7075       .55         1  .6519957
     p25 |         0         0         0  .1666667         0  .1666667  .1388889         0         0     .0625
     p75 |  .1904762  .1666667  .1904762  .4433333  .1666667       .36  .3333333      .055        .5  .2592593
--------------------------------------------------------------------------------------------------------------

tabstat poolaccess poolsuspens poolconstit ///
poolbudget poolcompliance poolpolicy poolagenda poolfinal pooling, stats ///
(mean p50 cv min max p25 p75)


   stats |  poolac~s  poolsu~s  poolco~t  poolbu~t  poolco~e  poolpo~y  poolag~a  poolfi~l   pooling
---------+------------------------------------------------------------------------------------------
    mean |  .3547155  .1434128  .2025431  .4387036   .301579  .3109233  .2540259  .3299332  .2919796
     p50 |       .33         0      .165       .33      .165       .25   .226875    .31625  .2853125
      cv |  .6926042  1.807738  .9755037  .7183873  1.085996  .6919419  .7457856  .6152751  .6323573
     min |         0         0         0         0         0         0         0         0         0
     max |         1         1       .83         1         1         1  .7629167       .79  .7283334
     p25 |      .125         0    .04125      .165         0      .165  .0833333  .1666667     .1375
     p75 |        .5       .25       .33       .66       .58      .375  .3866667     .5375  .4254167
----------------------------------------------------------------------------------------------------

outreg2 using del.doc, replace sum(log) keep(delaccess delsuspens delconstit ///
delbudget delfincompl delpolicy del_agenda del_final DS_sum_st delegation) dec(3)

outreg2 using DP_volIII_sept2017, replace sum(log) keep( poolaccess poolsuspens poolconstit ///
poolbudget poolcompliance  poolpolicy poolagenda poolfinal pooling) dec(3)

**Keep only the variables you need for each table, otherwise matsize error message
*keep delaccess delsuspens delconstit delbudget delfincompl delpolicy  del_agenda  del_final DS_sum_st delegation
outreg2 using xxx1.doc, replace sum(detail) eqkeep(mean p50 cv min max p25 p75) dec(3)
*keep poolaccess poolconstit poolsuspens poolcompliance poolbudget poolpolicy poolagenda poolfinal pooling
outreg2 using xxx1.doc, replace sum(detail) eqkeep(mean p50 cv min max p25 p75) dec(3)


 

 



