********************************
*//chapter five on policy scope//
*last change: November 11, 2018, edited May 2020
*LH
********************************
*     *****************************************************************
*     ***************************************************************** 
* 		File-Name:      ch5 do file on scope_may2020.do       	                 
*   	Date:           Feb 2018 (v1) May 2020 (final)                               
*     	Author:         LH                                          
*     	Purpose:        Create tables and figures for chapter 5 changing policy scope
*    	*     ****************************************************************  
*     ****************************************************************  



use:"INDEP_replication.dta"
[this is standard dataset with independent variables]


 *********************FIGURES AND GRAPHS************************************
*Figure 5.1: Gary's art: A Model of the Policy Portfolio
*****************************************************************************
*****************************************************************************
*Figure 5:2a and b change in policy scope by IO
*****************************************************************************
tsset ionumber year
gsort ionumber -year
gen scopeend=scope if end==1
by ionumber: replace scopeend=scopeend[_n-1] if scopeend>=.
gen scopechange=scope-scope_creation if end==1
gsort ionumber -year
gen scopechange_end=scopechange
by ionumber: replace scopechange_end=scopechange_end[_n-1] if scopechange_end==.
sort scopeend ioname
 
graph hbox scope if scopechange_end<2, over(ioname, sort(scopeend) label(labcolor(gs6))) medtype(marker) medmarker(mcolor(gs6) msize(small) msymbol(diamond)) cwhisker lines(lcolor(gs6) lwidth(thin) lpattern(solid)) 
graph save 1
graph hbox scope if scopechange_end>1, over(ioname, sort(scopeend) label(labcolor(gs6))) medtype(marker) medmarker(mcolor(gs6) msize(small) msymbol(diamond)) cwhisker lines(lcolor(gs6) lwidth(thin) lpattern(solid)) 
graph save 2
graph combine 1.gph 2.gph, graphregion(fcolor(white)) cols(2)

 
*****************************************************************************  
*Table 5.1: IOs by contract 
*****************************************************************************
tab contract if initial==1

contract dichotomized |      Freq.     Percent        Cum.
----------------------+-----------------------------------
  relatively complete |         47       61.84       61.84
relatively incomplete |         29       38.16      100.00
----------------------+-----------------------------------
                Total |         76      100.00


. tab contract if end==1

contract dichotomized |      Freq.     Percent        Cum.
----------------------+-----------------------------------
  relatively complete |         44       57.89       57.89
relatively incomplete |         32       42.11      100.00
----------------------+-----------------------------------
                Total |         76      100.00


sort ionumber year
by ionumber, sort: gen contractdiff=contract-contract[_n-1]
tab contractdiff, missing
list ioname contract year contractdiff if contractdiff!=0 & contractdiff!=.


      +---------------------------------------------------+
      |  ioname                contract   year   contra~f |
      |---------------------------------------------------|
 241. | Benelux   relatively incomplete   1960          1 |
 321. | Caricom   relatively incomplete   1973          1 |
1255. |    IGAD   relatively incomplete   1996          1 |
      +---------------------------------------------------+


 
*************************************************************
*Table 5.2: community principal components
*************************************************************
alpha hunt_rae_cat religion1_rae region_rae legal1_rae politystdev, i s
Test scale = mean(standardized items)

                                                            average
                             item-test     item-rest       interitem
Item         |  Obs  Sign   correlation   correlation     correlation     alpha
-------------+-----------------------------------------------------------------
hunt_rae_cat | 3292    +       0.9471        0.9136          0.6969      0.9019
religion1_~e | 3292    +       0.8881        0.8218          0.7408      0.9196
region_rae   | 3292    +       0.8853        0.8176          0.7430      0.9204
legal1_rae   | 3292    +       0.9176        0.8671          0.7190      0.9110
politystdev  | 3279    +       0.8101        0.7066          0.7982      0.9406
-------------+-----------------------------------------------------------------
Test scale   |                                               0.7396      0.9342
-------------------------------------------------------------------------------

corr hunt_rae_cat religion1_rae region_rae legal1_rae politystdev

 corr hunt_rae_cat religion1_rae region_rae legal1_rae politystdev
(obs=3,279)

             | hunt_r~t re~1_rae region~e legal1~e polit~ev
-------------+---------------------------------------------
hunt_rae_cat |   1.0000
religion1_~e |   0.8585   1.0000
  region_rae |   0.8172   0.6782   1.0000
  legal1_rae |   0.8361   0.8421   0.7657   1.0000
 politystdev |   0.7091   0.5757   0.6784   0.6423   1.0000



pca politystdev legal1_rae hunt_rae_cat region_rae religion1_rae, components (1) 


Principal components/correlation                 Number of obs    =      3,279
                                                 Number of comp.  =          1
                                                 Trace            =          5
    Rotation: (unrotated = principal)            Rho              =     0.7946

    --------------------------------------------------------------------------
       Component |   Eigenvalue   Difference         Proportion   Cumulative
    -------------+------------------------------------------------------------
           Comp1 |      3.97293      3.49391             0.7946       0.7946
           Comp2 |      .479017      .192123             0.0958       0.8904
           Comp3 |      .286894      .119801             0.0574       0.9478
           Comp4 |      .167093     .0730283             0.0334       0.9812
           Comp5 |     .0940645            .             0.0188       1.0000
    --------------------------------------------------------------------------

Principal components (eigenvectors) 

    --------------------------------------
        Variable |    Comp1 | Unexplained 
    -------------+----------+-------------
     politystdev |   0.4016 |       .3591 
      legal1_rae |   0.4621 |       .1516 
    hunt_rae_cat |   0.4771 |      .09571 
      region_rae |   0.4439 |        .217 
    religion1_~e |   0.4477 |       .2036 
    --------------------------------------

**create community variables for each of the components: standardize, and rescale from 0 (no community) to 1 (max community)
egen huntingtonstd=std(hunt_rae_cat)
replace huntingtonstd=-huntingtonstd
egen religionstd=std(religion1_rae)
replace religionstd=-religionstd
egen regionstd=std(region_rae)
replace regionstd=-regionstd
egen politystd =std(politystdev)
replace politystd=-politystd
egen legalstd=std(legal1_rae)
replace legalstd=-legalstd
gen huntingtondynamic=huntingtonstd*age_adj
gen religiondynamic=religionstd*age_adj
gen regiondynamic=regionstd*age_adj
gen politydynamic=politystd*age_adj
gen legaldynamic=legalstd*age_adj

	
***************************************	
*Figure 5.3: Community and Contract
***************************************
twoway (histogram community8_creation if end==1 & contract==2, percent width (1) gap (5) color (gs3))(histogram community8_creation if end==1 & contract==1, percent width (1) gap (50) color (gs14))(kdensity community8_creation if end==1 & contract==2, area (100) color (gs1)) (kdensity community8_creation if end==1 & contract==1, area (100) color (gs6)) 

tabstat community8 community8_creation, stats (min max mean)
replace community8_creationr=(community8_creation+2.32)/5.889642
tabstat community8_creation community8_creationr, stats (mean min max p50)
   stats |  commun..  commu~nr
---------+--------------------
    mean |  .1846077  .4252564
     min | -2.310693  .0015803
     max |  3.569642         1
     p50 |  .0097459  .3955666
------------------------------
twoway (histogram community8_creationr if end==1 & (contract==2), percent width (.167) gap(5) color (gs3)) (histogram community8_creationr if end==1 & contract==1, percent width (.167) gap(25) color (gs9))(kdensity community8_creationr if end==1 & (contract==2), area (30) color (gs3)) (kdensity community8_creationr if end==1 & contract==1, area (30) color (gs8))

twoway (histogram community8_creationr if end==1 & (contract==2|contract==3), frequency width (.167) gap(5) color (gs3)) (histogram community8_creationr if end==1 & contract==1, frequency width (.167) gap(25) color (gs9)) (kdensity community8_creationr if end==1 & contract==1, area (10) color (gs8))(kdensity community8_creationr if end==1 & (contract==2| contract==3), area (10) color (gs3))

**alternative format (with normal distribution); used for book
histogram community8_creationr if end==1, percent width (.167) normal normopts(lwidth(medthick)) by(contract, cols(1) ixaxes ixtick) graphregion(margin(vsmall))


*********************************************************************** 
*Table 5.3: Community and Contract, 1950-2010
***********************************************************************
*[and appendix B.1]

 ** create more intelligible gdp variable
gen gdpmean1000=gdpmean/1000

tsset ionumber year

/*(a) cross-section*/

.  xtreg contractdynamic commundynamic, be

Between regression (regression on group means)  Number of obs     =      3,279
Group variable: ionumber                        Number of groups  =         76

R-sq:                                           Obs per group:
     within  = 0.6203                                         min =          9
     between = 0.2624                                         avg =       43.1
     overall = 0.3876                                         max =         61

                                                F(1,74)           =      26.32
sd(u_i + avg(e_i.))=  13.41693                  Prob > F          =     0.0000

-------------------------------------------------------------------------------
contractdyn~c |      Coef.   Std. Err.      t    P>|t|     [95% Conf. Interval]
--------------+----------------------------------------------------------------
commundynamic |   .1622485   .0316257     5.13   0.000      .099233    .2252641
        _cons |    22.4587   2.293843     9.79   0.000     17.88812    27.02928
-------------------------------------------------------------------------------

/*now with controls: drop members because of high multicollinearity with community*/

. xtreg contractdynamic commundynamic politymean capabilities1 gdpmean1000, be

Between regression (regression on group means)  Number of obs     =      3,279
Group variable: ionumber                        Number of groups  =         76

R-sq:                                           Obs per group:
     within  = 0.3333                                         min =          9
     between = 0.4312                                         avg =       43.1
     overall = 0.3124                                         max =         61

                                                F(4,71)           =      13.45
sd(u_i + avg(e_i.))=  12.02859                  Prob > F          =     0.0000

-------------------------------------------------------------------------------
contractdyn~c |      Coef.   Std. Err.      t    P>|t|     [95% Conf. Interval]
--------------+----------------------------------------------------------------
commundynamic |   .2201334    .032256     6.82   0.000     .1558167    .2844501
   politymean |  -.0493014   .3306781    -0.15   0.882    -.7086548     .610052
capabilities1 |  -19.39775    7.42382    -2.61   0.011    -34.20043   -4.595075
  gdpmean1000 |  -.8968409   .2483137    -3.61   0.001    -1.391964   -.4017174
        _cons |   34.71443   4.747197     7.31   0.000     25.24878    44.18007
-------------------------------------------------------------------------------

/*now with GDP disparity*/
. xtreg contractdynamic commundynamic politymean capabilities1 gdpmean1000 gdpcov, be

Between regression (regression on group means)  Number of obs     =      3,279
Group variable: ionumber                        Number of groups  =         76

R-sq:                                           Obs per group:
     within  = 0.4527                                         min =          9
     between = 0.4399                                         avg =       43.1
     overall = 0.3761                                         max =         61

                                                F(5,70)           =      10.99
sd(u_i + avg(e_i.))=  12.02102                  Prob > F          =     0.0000

-------------------------------------------------------------------------------
contractdyn~c |      Coef.   Std. Err.      t    P>|t|     [95% Conf. Interval]
--------------+----------------------------------------------------------------
commundynamic |   .2335439    .034702     6.73   0.000     .1643331    .3027548
   politymean |    .150371   .3818477     0.39   0.695    -.6112002    .9119421
capabilities1 |   -16.9359   7.785057    -2.18   0.033    -32.46271   -1.409096
  gdpmean1000 |  -1.185887   .3718511    -3.19   0.002     -1.92752   -.4442532
     gdpstdev |   .0005542   .0005309     1.04   0.300    -.0005048    .0016131
        _cons |   29.27347   7.048547     4.15   0.000     15.21559    43.33136
-------------------------------------------------------------------------------

/*now also with Idealpoints*/
xtreg contractdynamic commundynamic politymean capabilities1 gdpmean1000 gdpcov idealdistmean, be

 xtreg contractdynamic commundynamic politymean capabilities1 gdpmean1000 gdpcov idealdistmean, be

Between regression (regression on group means)  Number of obs     =      3,279
Group variable: ionumber                        Number of groups  =         76

R-sq:                                           Obs per group:
     within  = 0.2968                                         min =          9
     between = 0.4688                                         avg =       43.1
     overall = 0.3135                                         max =         61

                                                F(6,69)           =      10.15
sd(u_i + avg(e_i.))=  11.79052                  Prob > F          =     0.0000

-------------------------------------------------------------------------------
contractdyn~c |      Coef.   Std. Err.      t    P>|t|     [95% Conf. Interval]
--------------+----------------------------------------------------------------
commundynamic |   .2637425   .0424393     6.21   0.000     .1790783    .3484067
   politymean |  -.2620018   .3418261    -0.77   0.446    -.9439262    .4199226
capabilities1 |  -17.35576   7.336522    -2.37   0.021    -31.99172   -2.719798
  gdpmean1000 |  -.9304158   .2443251    -3.81   0.000    -1.417831   -.4430006
       gdpcov |   .5786082   .4293087     1.35   0.182    -.2778392    1.435056
idealdistmean |   9.402319   5.024267     1.87   0.066    -.6208189    19.42546
        _cons |   27.84542    5.87337     4.74   0.000     16.12837    39.56247
-------------------------------------------------------------------------------



xtreg f.contractdynamic commundynamic, fe vce (cl ionumber)
xtreg f.contractdynamic commundynamic politymean capabilities1 members_log gdpmean1000, fe vce (cl ionumber)

. xtreg f.contractdynamic commundynamic, fe vce (cl ionumber)

Fixed-effects (within) regression               Number of obs     =      3,203
Group variable: ionumber                        Number of groups  =         76

R-sq:                                           Obs per group:
     within  = 0.6188                                         min =          8
     between = 0.2688                                         avg =       42.1
     overall = 0.3889                                         max =         60

                                                F(1,75)           =     187.61
corr(u_i, Xb)  = -0.5263                        Prob > F          =     0.0000

                               (Std. Err. adjusted for 76 clusters in ionumber)
-------------------------------------------------------------------------------
F.            |               Robust
contractdyn~c |      Coef.   Std. Err.      t    P>|t|     [95% Conf. Interval]
--------------+----------------------------------------------------------------
commundynamic |   .3699482   .0270092    13.70   0.000     .3161431    .4237532
        _cons |   14.49453   1.534763     9.44   0.000     11.43713    17.55194
--------------+----------------------------------------------------------------
      sigma_u |  16.541889
      sigma_e |  12.803653
          rho |  .62535269   (fraction of variance due to u_i)
-------------------------------------------------------------------------------



. xtreg f.contractdynamic commundynamic politymean capabilities1 gdpmean1000 yearcc,
>  fe vce (cl ionumber)

Fixed-effects (within) regression               Number of obs     =      3,203
Group variable: ionumber                        Number of groups  =         76

R-sq:                                           Obs per group:
     within  = 0.9182                                         min =          8
     between = 0.0183                                         avg =       42.1
     overall = 0.5141                                         max =         60

                                                F(5,75)           =     131.43
corr(u_i, Xb)  = -0.2055                        Prob > F          =     0.0000

                               (Std. Err. adjusted for 76 clusters in ionumber)
-------------------------------------------------------------------------------
F.            |               Robust
contractdyn~c |      Coef.   Std. Err.      t    P>|t|     [95% Conf. Interval]
--------------+----------------------------------------------------------------
commundynamic |   .1256716   .0266597     4.71   0.000     .0725628    .1787804
   politymean |   .3255971   .3285495     0.99   0.325    -.3289069    .9801012
capabilities1 |   -7.08871    10.6765    -0.66   0.509    -28.35738    14.17996
  gdpmean1000 |  -.2901861   .2150542    -1.35   0.181     -.718596    .1382238
       yearcc |   1.099089   .0970653    11.32   0.000     .9057252    1.292453
        _cons |  -10.52104   4.727599    -2.23   0.029     -19.9389    -1.10318
--------------+----------------------------------------------------------------
      sigma_u |  19.496378
      sigma_e |  5.9358273
          rho |  .91516876   (fraction of variance due to u_i)
-------------------------------------------------------------------------------

/*with GDP dispersion*/
 xtreg f.contractdynamic commundynamic politymean capabilities1 gdpmean1000 gdpcov yearcc, fe vce (cl ionumber)

Fixed-effects (within) regression               Number of obs     =      3,203
Group variable: ionumber                        Number of groups  =         76

R-sq:                                           Obs per group:
     within  = 0.9196                                         min =          8
     between = 0.0061                                         avg =       42.1
     overall = 0.5136                                         max =         60

                                                F(6,75)           =     115.62
corr(u_i, Xb)  = -0.2226                        Prob > F          =     0.0000

                               (Std. Err. adjusted for 76 clusters in ionumber)
-------------------------------------------------------------------------------
F.            |               Robust
contractdyn~c |      Coef.   Std. Err.      t    P>|t|     [95% Conf. Interval]
--------------+----------------------------------------------------------------
commundynamic |   .1244294   .0264376     4.71   0.000     .0717629    .1770958
   politymean |   .3195223   .3263798     0.98   0.331    -.3306597    .9697043
capabilities1 |  -6.377434   10.51537    -0.61   0.546    -27.32513    14.57026
  gdpmean1000 |  -.3157978   .2110966    -1.50   0.139    -.7363238    .1047282
       gdpcov |   .6988917    .356329     1.96   0.054    -.0109521    1.408736
       yearcc |   1.103639   .0965186    11.43   0.000     .9113643    1.295914
        _cons |  -11.06022   4.700672    -2.35   0.021    -20.42444      -1.696
--------------+----------------------------------------------------------------
      sigma_u |  19.503315
      sigma_e |  5.8853445
          rho |  .91654001   (fraction of variance due to u_i)
-------------------------------------------------------------------------------


xtreg f.contractdynamic commundynamic politymean capabilities1 gdpmean1000 gdpcov idealdistmean yearcc, fe vce (cl ionumber)


. xtreg f.contractdynamic commundynamic politymean capabilities1 gdpmean1000 gdpcov idealdistmean y
> earcc, fe vce (cl ionumber)

Fixed-effects (within) regression               Number of obs     =      3,203
Group variable: ionumber                        Number of groups  =         76

R-sq:                                           Obs per group:
     within  = 0.9200                                         min =          8
     between = 0.0130                                         avg =       42.1
     overall = 0.5102                                         max =         60

                                                F(7,75)           =     100.66
corr(u_i, Xb)  = -0.2136                        Prob > F          =     0.0000

                               (Std. Err. adjusted for 76 clusters in ionumber)
-------------------------------------------------------------------------------
F.            |               Robust
contractdyn~c |      Coef.   Std. Err.      t    P>|t|     [95% Conf. Interval]
--------------+----------------------------------------------------------------
commundynamic |   .1220091   .0259823     4.70   0.000     .0702496    .1737685
   politymean |    .359887   .3223655     1.12   0.268     -.282298    1.002072
capabilities1 |  -6.592426   10.50309    -0.63   0.532    -27.51566    14.33081
  gdpmean1000 |  -.2969224   .2085351    -1.42   0.159    -.7123455    .1185008
       gdpcov |   .7086776   .3548482     2.00   0.049     .0017837    1.415572
idealdistmean |   2.303159   2.925246     0.79   0.434     -3.52423    8.130548
       yearcc |   1.109611   .0999456    11.10   0.000      .910509    1.308713
        _cons |   -13.4048    5.89004    -2.28   0.026    -25.13836   -1.671239
--------------+----------------------------------------------------------------
      sigma_u |  19.621587
      sigma_e |  5.8724591
          rho |  .91779167   (fraction of variance due to u_i)
-------------------------------------------------------------------------------

 fp <yearcc>: xtreg f.contractdynamic commundynamic politymean capabilities1 gdpmean1000 gdpcov <yearcc>, fe vce (cl ionumber)


**different community variables
xtreg contractdynamic commundynamic politymean capabilities1 gdpmean1000 gdpcov, be
xtreg f.contractdynamic commundynamic politymean capabilities1 gdpmean1000 gdpcov yearcc, fe vce (cl ionumber)

xtreg contractdynamic huntingtondynamic politymean capabilities1 gdpmean1000 gdpcov, be
xtreg contractdynamic religiondynamic politymean capabilities1 gdpmean1000 gdpcov, be
xtreg contractdynamic regiondynamic politymean capabilities1 gdpmean1000 gdpcov, be
xtreg contractdynamic politydynamic politymean capabilities1 gdpmean1000 gdpcov, be
xtreg contractdynamic legaldynamic politymean capabilities1 gdpmean1000 gdpcov, be
xtreg f.contractdynamic huntingtondynamic politymean capabilities1 gdpmean1000 gdpcov yearcc, fe vce (cl ionumber)
xtreg f.contractdynamic religiondynamic politymean capabilities1 gdpmean1000 gdpcov yearcc, fe vce (cl ionumber)
xtreg f.contractdynamic regiondynamic politymean capabilities1 gdpmean1000 gdpcov yearcc, fe vce (cl ionumber)
xtreg f.contractdynamic politydynamic politymean capabilities1 gdpmean1000 gdpcov yearcc, fe vce (cl ionumber)
xtreg f.contractdynamic legaldynamic politymean capabilities1 gdpmean1000 gdpcov yearcc, fe vce (cl ionumber)


//*APPENDIX B.2*//
//**alternative community measure: historical ties**??//
/*here is there no reason to drop members as control since low multicollinearity*/
/*need to consider decay factor*/

gen historical_ties4 [does not include pans]
/*not EU, LOAS, COE, OAS, AU*/
gen historydynamic=exp(-(inception-ties_end)/25) if historical_ties4==1
replace historydynamic=0 if historical_ties4==0
replace historydynamic=historydynamic*age_adj
tab historydynamic

xtreg contractdynamic historydynamic, be
xtreg f.contractdynamic historydynamic, fe vce(cl ionumber)

Between regression (regression on group means)  Number of obs     =      3,292
Group variable: ionumber                        Number of groups  =         76

R-sq:                                           Obs per group:
     within  = 0.1858                                         min =          9
     between = 0.2002                                         avg =       43.3
     overall = 0.1535                                         max =         61

                                                F(1,74)           =      18.52
sd(u_i + avg(e_i.))=  13.77457                  Prob > F          =     0.0001

--------------------------------------------------------------------------------
contractdyna~c |      Coef.   Std. Err.      t    P>|t|     [95% Conf. Interval]
---------------+----------------------------------------------------------------
historydynamic |   .8070664   .1875405     4.30   0.000     .4333839    1.180749
         _cons |   28.77461   1.663523    17.30   0.000     25.45997    32.08925
--------------------------------------------------------------------------------


. xtreg f.contractdynamic historydynamic if politymean!=., fe vce(cl ionumber)

Fixed-effects (within) regression               Number of obs     =      3,203
Group variable: ionumber                        Number of groups  =         76

R-sq:                                           Obs per group:
     within  = 0.1752                                         min =          8
     between = 0.2209                                         avg =       42.1
     overall = 0.1576                                         max =         60

                                                F(1,75)           =      34.95
corr(u_i, Xb)  = -0.6134                        Prob > F          =     0.0000

                                (Std. Err. adjusted for 76 clusters in ionumber)
--------------------------------------------------------------------------------
F.             |               Robust
contractdyna~c |      Coef.   Std. Err.      t    P>|t|     [95% Conf. Interval]
---------------+----------------------------------------------------------------
historydynamic |   2.169063   .3669051     5.91   0.000     1.438151    2.899976
         _cons |   29.72975   .9788323    30.37   0.000     27.77981    31.67968
---------------+----------------------------------------------------------------
       sigma_u |  17.681788
       sigma_e |  18.832321
           rho |  .46852198   (fraction of variance due to u_i)
--------------------------------------------------------------------------------



. xtreg contractdynamic historydynamic politymean capabilities1 gdpmean1000 members_log , be



Between regression (regression on group means)  Number of obs     =      3,279
Group variable: ionumber                        Number of groups  =         76

R-sq:                                           Obs per group:
     within  = 0.1144                                         min =          9
     between = 0.2927                                         avg =       43.1
     overall = 0.0199                                         max =         61

                                                F(5,70)           =       5.79
sd(u_i + avg(e_i.))=  13.50846                  Prob > F          =     0.0002

--------------------------------------------------------------------------------
contractdyna~c |      Coef.   Std. Err.      t    P>|t|     [95% Conf. Interval]
---------------+----------------------------------------------------------------
historydynamic |   .7937274    .186056     4.27   0.000     .4226504    1.164804
    politymean |   .4686374   .3631708     1.29   0.201     -.255684    1.192959
 capabilities1 |  -14.41777   10.39774    -1.39   0.170    -35.15541    6.319858
   gdpmean1000 |  -.7201393    .283613    -2.54   0.013    -1.285788    -.154491
   members_log |  -5.257964   3.898616    -1.35   0.182    -13.03351    2.517579
         _cons |   41.27248    9.70029     4.25   0.000     21.92586     60.6191
--------------------------------------------------------------------------------


. xtreg contractdynamic historydynamic politymean capabilities1  members_log gdpmean1000 gdpcov , be


Between regression (regression on group means)  Number of obs     =      3,279
Group variable: ionumber                        Number of groups  =         76

R-sq:                                           Obs per group:
     within  = 0.1163                                         min =          9
     between = 0.2962                                         avg =       43.1
     overall = 0.0199                                         max =         61

                                                F(6,69)           =       4.84
sd(u_i + avg(e_i.))=  13.57237                  Prob > F          =     0.0004

--------------------------------------------------------------------------------
contractdyna~c |      Coef.   Std. Err.      t    P>|t|     [95% Conf. Interval]
---------------+----------------------------------------------------------------
historydynamic |    .760034   .1956069     3.89   0.000     .3698089    1.150259
    politymean |   .4500361   .3662718     1.23   0.223    -.2806562    1.180728
 capabilities1 |  -13.51725   10.55972    -1.28   0.205    -34.58332    7.548827
   members_log |  -4.873223   3.971884    -1.23   0.224    -12.79691    3.050469
   gdpmean1000 |  -.7168116   .2850117    -2.52   0.014    -1.285394    -.148229
        gdpcov |   .3020266   .5162539     0.59   0.560    -.7278717    1.331925
         _cons |   40.47813   9.840311     4.11   0.000     20.84725    60.10901
--------------------------------------------------------------------------------




 xtreg f.contractdynamic historydynamic politymean capabilities1 gdpmean1000 members_log yearcc, fe vce (cl ionumber)

Fixed-effects (within) regression               Number of obs     =      3,203
Group variable: ionumber                        Number of groups  =         76

R-sq:                                           Obs per group:
     within  = 0.9141                                         min =          8
     between = 0.0114                                         avg =       42.1
     overall = 0.4525                                         max =         60

                                                F(6,75)           =     114.04
corr(u_i, Xb)  = -0.3442                        Prob > F          =     0.0000

                                (Std. Err. adjusted for 76 clusters in ionumber)
--------------------------------------------------------------------------------
F.             |               Robust
contractdyna~c |      Coef.   Std. Err.      t    P>|t|     [95% Conf. Interval]
---------------+----------------------------------------------------------------
historydynamic |   .8513912   .1526015     5.58   0.000     .5473934    1.155389
    politymean |   .4280027    .292982     1.46   0.148    -.1556473    1.011653
 capabilities1 |  -13.70999   9.930039    -1.38   0.171    -33.49164    6.071664
   gdpmean1000 |  -.0546213   .1909872    -0.29   0.776    -.4350873    .3258448
   members_log |  -6.849913   7.543446    -0.91   0.367    -21.87723    8.177402
        yearcc |   1.243468   .1101845    11.29   0.000     1.023969    1.462966
         _cons |  -1.906532   11.83105    -0.16   0.872    -25.47519    21.66212
---------------+----------------------------------------------------------------
       sigma_u |  22.123644
       sigma_e |  6.0836888
           rho |  .92969877   (fraction of variance due to u_i)
--------------------------------------------------------------------------------

/*with interests*/

xtreg f.contractdynamic historydynamic politymean capabilities1 members_log gdpmean1000 gdpcov yearcc, fe vce (cl ionumber)

Fixed-effects (within) regression               Number of obs     =      3,203
Group variable: ionumber                        Number of groups  =         76

R-sq:                                           Obs per group:
     within  = 0.9143                                         min =          8
     between = 0.0087                                         avg =       42.1
     overall = 0.4498                                         max =         60

                                                F(7,75)           =     103.35
corr(u_i, Xb)  = -0.3529                        Prob > F          =     0.0000

                                (Std. Err. adjusted for 76 clusters in ionumber)
--------------------------------------------------------------------------------
F.             |               Robust
contractdyna~c |      Coef.   Std. Err.      t    P>|t|     [95% Conf. Interval]
---------------+----------------------------------------------------------------
historydynamic |   .8327732   .1521658     5.47   0.000     .5296434    1.135903
    politymean |   .4205299   .2929455     1.44   0.155    -.1630475    1.004107
 capabilities1 |  -13.36761   9.921426    -1.35   0.182     -33.1321    6.396882
   members_log |  -7.130049   7.570005    -0.94   0.349    -22.21027    7.950174
   gdpmean1000 |  -.0662115   .1927855    -0.34   0.732    -.4502599    .3178369
        gdpcov |   .2991128   .2637965     1.13   0.260    -.2263969    .8246225
        yearcc |   1.248341    .111103    11.24   0.000     1.027013     1.46967
         _cons |  -1.761734   11.81891    -0.15   0.882    -25.30622    21.78275
---------------+----------------------------------------------------------------
       sigma_u |  22.216057
       sigma_e |  6.0766042
           rho |  .93039278   (fraction of variance due to u_i)
--------------------------------------------------------------------------------

fp <yearcc>: xtreg contractdynamic historydynamic politymean capabilities1  members_log gdpmean1000 gdpcov <yearcc>, fe vce (cl ionumber)


//*APPENDIX: B.3*//
**more kosher to use logit because dichotomous outcome?

gen contract2=contract-1
logistic contract2 community8 politymean capabilities1 gdpmean1000, vce (cl ionumber)
estat gof
. logistic contract2 community8 politymean capabilities1 gdpmean1000, vce (cl 
> ionumber)

Logistic regression                             Number of obs     =      3,279
                                                Wald chi2(4)      =      23.23
                                                Prob > chi2       =     0.0001
Log pseudolikelihood = -1550.8173               Pseudo R2         =     0.2808

                              (Std. Err. adjusted for 76 clusters in ionumber)
------------------------------------------------------------------------------
             |               Robust
   contract2 | Odds Ratio   Std. Err.      z    P>|z|     [95% Conf. Interval]
-------------+----------------------------------------------------------------
  community8 |   2.179507    .472566     3.59   0.000     1.424947    3.333633
  politymean |   .8826842   .0655412    -1.68   0.093     .7631357     1.02096
capabiliti~1 |   .7813337   1.429616    -0.13   0.893     .0216463    28.20267
 gdpmean1000 |   .9517262   .0263037    -1.79   0.073     .9015433    1.004702
       _cons |   4.341512   5.409827     1.18   0.239     .3775586    49.92264
------------------------------------------------------------------------------
Note: _cons estimates baseline odds.

. estat gof, group (6) table

Logistic model for contract2, goodness-of-fit test

  (Table collapsed on quantiles of estimated probabilities)
  +--------------------------------------------------------+
  | Group |   Prob | Obs_1 | Exp_1 | Obs_0 | Exp_0 | Total |
  |-------+--------+-------+-------+-------+-------+-------|
  |     1 | 0.0970 |    19 |  39.2 |   528 | 507.8 |   547 |
  |     2 | 0.1481 |    26 |  70.6 |   520 | 475.4 |   546 |
  |     3 | 0.2534 |   104 |  99.7 |   443 | 447.3 |   547 |
  |     4 | 0.4793 |   301 | 204.0 |   245 | 342.0 |   546 |
  |     5 | 0.7241 |   326 | 330.4 |   221 | 216.6 |   547 |
  |-------+--------+-------+-------+-------+-------+-------|
  |     6 | 0.9600 |   429 | 461.1 |   117 |  84.9 |   546 |
  +--------------------------------------------------------+

       number of observations =      3279
             number of groups =         6
      Hosmer-Lemeshow chi2(4) =       132.01
                  Prob > chi2 =         0.0000

. listcoef, percent

logit (N=3279): Percentage change in odds 

  Odds of: 1 vs 0

------------------------------------------------------------------------
             |         b        z    P>|z|         %     %StdX     SDofX
-------------+----------------------------------------------------------
  community8 |    0.7791    3.593    0.000     118.0     369.1     1.984
  politymean |   -0.1248   -1.681    0.093     -11.7     -46.9     5.078
capabiliti~1 |   -0.2468   -0.135    0.893     -21.9      -4.7     0.197
 gdpmean1000 |   -0.0495   -1.790    0.073      -4.8     -33.9     8.356
    constant |    1.4682    1.178    0.239         .         .         .
------------------------------------------------------------------------


//* read on hosmer-lemeshow test: http://thestatsgeek.com/2014/02/16/the-hosmer-lemeshow-goodness-of-fit-test-for-logistic-regression/

*looking for influential observations*
predict p
predict stdres, rstand
scatter stdres p if initial==1, mlabel(ioname)
gen id=_n
scatter stdres id if initial==1, mlab(ioname)
predict dv, dev
scatter dv p if initial==1, mlab(ioname) 
predict hat, hat
scatter hat p if initial==1, mlab(ioname)
**UN is outlier, but not an influential observation; GCC is not an outlier, but an influential observation (i.e. has high leverage)
**dropping GCC from analysis does not change results**
/*read on influential observations: https://stats.idre.ucla.edu/stata/webbooks/logistic/chapter3/lesson-3-logistic-regression-diagnostics-2/ */


findit listcoef /*install from stata*/
ssc install listcoeff
listcoef, help percent

listcoef, help percent

logit (N=3279): Percentage change in odds 

  Odds of: 1 vs 0

------------------------------------------------------------------------
             |         b        z    P>|z|         %     %StdX     SDofX
-------------+----------------------------------------------------------
  community8 |    0.6839    2.029    0.043      98.2     288.4     1.984
  politymean |   -0.1221   -1.657    0.097     -11.5     -46.2     5.078
capabiliti~1 |   -0.4586   -0.243    0.808     -36.8      -8.6     0.197
 members_log |   -0.4292   -0.385    0.700     -34.9     -21.1     0.553
 gdpmean1000 |   -0.0484   -1.770    0.077      -4.7     -33.3     8.356
    constant |    2.1027    1.115    0.265         .         .         .
------------------------------------------------------------------------
       b = raw coefficient
       z = z-score for test of b=0
   P>|z| = p-value for z-test
       % = percent change in odds for unit increase in X
   %StdX = percent change in odds for SD increase in X
   SDofX = standard deviation of X

. listcoef, help percent

/*with interests*/

. logistic contract2 community8 politymean capabilities1 gdpmean100 gdpcov, vc
> e (cl ionumber)

Logistic regression                             Number of obs     =      3,279
                                                Wald chi2(5)      =      27.26
                                                Prob > chi2       =     0.0001
Log pseudolikelihood = -1489.3227               Pseudo R2         =     0.3093

                              (Std. Err. adjusted for 76 clusters in ionumber)
------------------------------------------------------------------------------
             |               Robust
   contract2 | Odds Ratio   Std. Err.      z    P>|z|     [95% Conf. Interval]
-------------+----------------------------------------------------------------
  community8 |   2.101373   .4636091     3.37   0.001      1.36367    3.238149
  politymean |   .8943643   .0662202    -1.51   0.132     .7735531    1.034043
capabiliti~1 |   .7030552   1.371775    -0.18   0.857     .0153517    32.19753
 gdpmean1000 |   .9363443   .0256014    -2.41   0.016     .8874873    .9878909
      gdpcov |   1.707886   .7227914     1.26   0.206     .7451151    3.914663
       _cons |   3.412025   4.155397     1.01   0.314     .3135891    37.12475
------------------------------------------------------------------------------
Note: _cons estimates baseline odds.
Note: 0 failures and 10 successes completely determined.

. estat gof, group (7) table

Logistic model for contract2, goodness-of-fit test

  (Table collapsed on quantiles of estimated probabilities)
  +--------------------------------------------------------+
  | Group |   Prob | Obs_1 | Exp_1 | Obs_0 | Exp_0 | Total |
  |-------+--------+-------+-------+-------+-------+-------|
  |     1 | 0.0884 |    13 |  31.6 |   456 | 437.4 |   469 |
  |     2 | 0.1344 |    14 |  53.2 |   454 | 414.8 |   468 |
  |     3 | 0.1718 |    38 |  71.0 |   431 | 398.0 |   469 |
  |     4 | 0.3363 |   178 | 112.2 |   290 | 355.8 |   468 |
  |     5 | 0.5476 |   268 | 204.9 |   201 | 264.1 |   469 |
  |-------+--------+-------+-------+-------+-------+-------|
  |     6 | 0.7867 |   313 | 313.4 |   155 | 154.6 |   468 |
  |     7 | 1.0000 |   381 | 418.6 |    87 |  49.4 |   468 |
  +--------------------------------------------------------+

       number of observations =      3279
             number of groups =         7
      Hosmer-Lemeshow chi2(5) =       179.88
                  Prob > chi2 =         0.0000

. listcoef, percent

logit (N=3279): Percentage change in odds 

  Odds of: 1 vs 0

------------------------------------------------------------------------
             |         b        z    P>|z|         %     %StdX     SDofX
-------------+----------------------------------------------------------
  community8 |    0.7426    3.366    0.001     110.1     336.3     1.984
  politymean |   -0.1116   -1.508    0.132     -10.6     -43.3     5.078
capabiliti~1 |   -0.3523   -0.181    0.857     -29.7      -6.7     0.197
 gdpmean1000 |   -0.0658   -2.406    0.016      -6.4     -42.3     8.356
      gdpcov |    0.5353    1.265    0.206      70.8     396.2     2.993
    constant |    1.2273    1.008    0.314         .         .         .
------------------------------------------------------------------------






 logistic contract2 historical_ties4 politymean capabilities1 members_log gdpm
> ean1000, vce (cl ionumber)

Logistic regression                             Number of obs     =      3,279
                                                Wald chi2(5)      =      28.22
                                                Prob > chi2       =     0.0000
Log pseudolikelihood = -1435.8123               Pseudo R2         =     0.3341

                              (Std. Err. adjusted for 76 clusters in ionumber)
------------------------------------------------------------------------------
             |               Robust
   contract2 | Odds Ratio   Std. Err.      z    P>|z|     [95% Conf. Interval]
-------------+----------------------------------------------------------------
historical~4 |   17.34586    14.0271     3.53   0.000     3.555113    84.63269
  politymean |   .8973684   .0607429    -1.60   0.110     .7858739    1.024681
capabiliti~1 |   .3776316   .7991384    -0.46   0.645     .0059672    23.89838
 members_log |   .1179052   .0988242    -2.55   0.011     .0228078    .6095109
 gdpmean1000 |   .9580424   .0230669    -1.78   0.075     .9138823    1.004336
       _cons |   62.75626    129.711     2.00   0.045     1.092213    3605.842
------------------------------------------------------------------------------
Note: _cons estimates baseline odds.

. estat gof, group (7) table

Logistic model for contract2, goodness-of-fit test

  (Table collapsed on quantiles of estimated probabilities)
  +--------------------------------------------------------+
  | Group |   Prob | Obs_1 | Exp_1 | Obs_0 | Exp_0 | Total |
  |-------+--------+-------+-------+-------+-------+-------|
  |     1 | 0.0771 |    34 |  27.6 |   435 | 441.4 |   469 |
  |     2 | 0.1464 |    59 |  53.3 |   409 | 414.7 |   468 |
  |     3 | 0.1917 |    42 |  79.5 |   427 | 389.5 |   469 |
  |     4 | 0.3036 |    95 | 110.3 |   373 | 357.7 |   468 |
  |     5 | 0.4997 |   222 | 184.9 |   247 | 284.1 |   469 |
  |-------+--------+-------+-------+-------+-------+-------|
  |     6 | 0.8218 |   317 | 309.1 |   151 | 158.9 |   468 |
  |     7 | 0.9950 |   436 | 440.4 |    32 |  27.6 |   468 |
  +--------------------------------------------------------+

       number of observations =      3279
             number of groups =         7
      Hosmer-Lemeshow chi2(5) =        39.93
                  Prob > chi2 =         0.0000

. listcoef

logit (N=3279): Factor change in odds 

  Odds of: 1 vs 0

------------------------------------------------------------------------
             |         b        z    P>|z|       e^b   e^bStdX     SDofX
-------------+----------------------------------------------------------
historical~4 |    2.8534    3.528    0.000    17.346     2.922     0.376
  politymean |   -0.1083   -1.600    0.110     0.897     0.577     5.078
capabiliti~1 |   -0.9738   -0.460    0.645     0.378     0.826     0.197
 members_log |   -2.1379   -2.551    0.011     0.118     0.307     0.553
 gdpmean1000 |   -0.0429   -1.780    0.075     0.958     0.699     8.356
    constant |    4.1393    2.003    0.045         .         .         .
------------------------------------------------------------------------

. listcoef, help percent

logit (N=3279): Percentage change in odds 

  Odds of: 1 vs 0

------------------------------------------------------------------------
             |         b        z    P>|z|         %     %StdX     SDofX
-------------+----------------------------------------------------------
historical~4 |    2.8534    3.528    0.000    1634.6     192.2     0.376
  politymean |   -0.1083   -1.600    0.110     -10.3     -42.3     5.078
capabiliti~1 |   -0.9738   -0.460    0.645     -62.2     -17.4     0.197
 members_log |   -2.1379   -2.551    0.011     -88.2     -69.3     0.553
 gdpmean1000 |   -0.0429   -1.780    0.075      -4.2     -30.1     8.356
    constant |    4.1393    2.003    0.045         .         .         .
------------------------------------------------------------------------
       b = raw coefficient
       z = z-score for test of b=0
   P>|z| = p-value for z-test
       % = percent change in odds for unit increase in X
   %StdX = percent change in odds for SD increase in X
   SDofX = standard deviation of X

/*with interest*/
   
logistic contract2 historical_ties4 politymean capabilities1 members_log gdpmean1000 gdpcov, vce (cl ionumber)

Logistic regression                             Number of obs     =      3,279
                                                Wald chi2(6)      =      28.03
                                                Prob > chi2       =     0.0001
Log pseudolikelihood = -1420.4216               Pseudo R2         =     0.3413

                                (Std. Err. adjusted for 76 clusters in ionumber)
--------------------------------------------------------------------------------
               |               Robust
     contract2 | Odds Ratio   Std. Err.      z    P>|z|     [95% Conf. Interval]
---------------+----------------------------------------------------------------
historical_t~4 |   12.04893   10.80841     2.77   0.006     2.076749     69.9058
    politymean |   .9165048   .0611374    -1.31   0.191     .8041806    1.044518
 capabilities1 |   .3849641   .8336464    -0.44   0.659     .0055224    26.83564
   members_log |   .1219532   .1021016    -2.51   0.012     .0236348    .6292678
   gdpmean1000 |   .9416701    .025398    -2.23   0.026     .8931837    .9927885
        gdpcov |   1.627483   1.110612     0.71   0.475     .4272153    6.199917
         _cons |   44.45839   89.52744     1.88   0.060     .8587341      2301.7
--------------------------------------------------------------------------------
Note: _cons estimates baseline odds.
Note: 0 failures and 12 successes completely determined.

. listcoef, percent

logit (N=3279): Percentage change in odds 

  Odds of: 1 vs 0

------------------------------------------------------------------------
             |         b        z    P>|z|         %     %StdX     SDofX
-------------+----------------------------------------------------------
historical~4 |    2.4890    2.775    0.006    1104.9     154.8     0.376
  politymean |   -0.0872   -1.307    0.191      -8.3     -35.8     5.078
capabiliti~1 |   -0.9546   -0.441    0.659     -61.5     -17.1     0.197
 members_log |   -2.1041   -2.513    0.012     -87.8     -68.7     0.553
 gdpmean1000 |   -0.0601   -2.228    0.026      -5.8     -39.5     8.356
      gdpcov |    0.4870    0.714    0.475      62.7     329.5     2.993
    constant |    3.7946    1.884    0.060         .         .         .
------------------------------------------------------------------------

 estat gof, group (8) table

Logistic model for contract2, goodness-of-fit test

  (Table collapsed on quantiles of estimated probabilities)
  +--------------------------------------------------------+
  | Group |   Prob | Obs_1 | Exp_1 | Obs_0 | Exp_0 | Total |
  |-------+--------+-------+-------+-------+-------+-------|
  |     1 | 0.0728 |    26 |  23.3 |   384 | 386.7 |   410 |
  |     2 | 0.1260 |    53 |  40.5 |   357 | 369.5 |   410 |
  |     3 | 0.1697 |    36 |  62.2 |   374 | 347.8 |   410 |
  |     4 | 0.2285 |    35 |  79.8 |   375 | 330.2 |   410 |
  |     5 | 0.3730 |   134 | 121.7 |   276 | 288.3 |   410 |
  |-------+--------+-------+-------+-------+-------+-------|
  |     6 | 0.5700 |   259 | 191.1 |   151 | 218.9 |   410 |
  |     7 | 0.9018 |   282 | 292.7 |   128 | 117.3 |   410 |
  |     8 | 1.0000 |   380 | 393.7 |    29 |  15.3 |   409 |
  +--------------------------------------------------------+

       number of observations =      3279
             number of groups =         8
      Hosmer-Lemeshow chi2(6) =       109.96
                  Prob > chi2 =         0.0000





xtlogit contract commundynamic politymean capabilities1 members_log gdpmean1000 yearcc, fe vce (oim)
   
     
************************************************************** 
*Table 5.4: Explaining policy scope: Community-Contract Model
**************************************************************
 
 **create new contract dynamic variable

gen inception=inception_adj
replace inception_adj=1950 if inception<1950

gen contractdynamic=contract*age_adj

 **create year variable
gen yearc=year-2010+1
gen yearcc=year-1950+1

 ** create more intelligible gdp variable
gen gdpmean1000=gdpmean/1000

*FAILS the Hausman test
xtreg f.scope commundynamic contractdynamic politymean members_log capabilities1 gdpmean1000 yearcc, fe 
estimates store fixed
xtreg f.scope commundynamic contractdynamic politymean members_log capabilities1 gdpmean1000 yearcc, re 
estimates store random
hausman fixed random
suest fixed random, vce (cl ionumber)
 *<<note: not sure Hausman test is appropriate for panel clustered data; suest may be better option, but cannot make it work>>


**Table 5:4: models + APPENDIX B.5
**with community8 rescaled so that minimal value=0.0
gen community8r=community8+2.404
tabstat community8r, stats (min max)

 tabstat community8 community8r, stats (min max mean)

   stats |  commun~8  commu~8r
---------+--------------------
     min | -2.403077  .0009229
     max |  3.569642  5.973642
    mean | -9.20e-10     2.404
------------------------------

gen commundynamic= community8r*age_adj
tsset ionumber year
xtreg f.scope commundynamic, fe vce (cl ionumber)  /**model 1 **/
estat ic
xtreg f.scope contractdynamic if commundynamic!=., fe vce (cl ionumber) 
xtreg f.scope commundynamic politymean members_log capabilities1 gdpmean1000 yearcc, fe vce (cl ionumber) /** model 1 **/
xtreg f.scope commundynamic politymean members_log capabilities1 gdpmean1000 gdpcov yearcc, fe vce (cl ionumber) /** model 1 WITH INTERESTS **/

xtreg f.scope contractdynamic politymean members_log capabilities1 gdpmean1000 yearcc, fe vce (cl ionumber)/** model 2 **/
xtreg f.scope contractdynamic politymean members_log capabilities1 gdpmean1000 gdpcov yearcc, fe vce (cl ionumber)/** model 2 with interests **/
xtreg f.scope commundynamic contractdynamic politymean  members_log capabilities1 gdpmean1000 yearcc, fe vce (cl ionumber)/** model 3 **/
xtreg f.scope commundynamic contractdynamic politymean  members_log capabilities1 gdpmean1000 gdpcov yearcc, fe vce (cl ionumber)/** model 3  with interests**/
xtreg f.scope commundynamic contractdynamic politymean  members_log capabilities1 gdpmean1000 gdpcov idealdistmean yearcc, fe vce (cl ionumber)/** model 4  with interests + ideal**/
xtreg f.scope commundynamic contractdynamic politymean members_log capabilities1 gdpmean1000 gdpcov idealdistmean, fe vce (cl ionumber) /** model 5 without year**/
fp <yearcc>: xtreg f.scope commundynamic contractdynamic politymean members_log capabilities1 gdpmean1000 gdpcov idealdistmean <yearcc>, fe vce (cl ionumber) /** model 6 WITH polynomial**/
xtreg f.scope commundynamic contractdynamic politymean  members_log capabilities1 gdpmean1000 gdpcov idealdistmean yearcc scope, fe vce (cl ionumber) /** model 7 with interests**/

xtreg f.scope commundynamic contractdynamic politymean capabilities1 members_log gdpmean1000 gdpcov yearcc, fe vce (boot) /** model 8 app**/
jackknife: xtreg f.scope commundynamic contractdynamic politymean capabilities1 members_log gdpmean1000 gdpcov yearcc, fe vce(cl ionumber)/** model 9 app **/ 
reg d.scope d.commundynamic d.contractdynamic d.politymean d.capabilities1 d.members_log d.gdpmean1000 d.gdpcov d.yearcc, vce (cl ionumber)

estat ic


. sort p2

. list ioname community8 contractT p1 p2 p3 if contractT==2, clean noobs

     ioname   communi~8   contra~T         p1         p2         p3  
         UN   -2.269101          2   .9037219   .0873862   .0088919  
        OAS   -.2766542          2   .7268316   .2424892   .0306793  
     ComSec   -.2020428          2   .6830153   .2793717    .037613  
        OIF   -1.038696          2   .6668048    .292814   .0403812  
    Benelux    2.774915          2   .4614889   .4490353   .0894758  
        OIC    .1687079          2   .4567617   .4521995   .0910388  
    Caricom    1.034711          2   .4242588   .4731802   .1025609  
      ASEAN    .0541279          2   .3818406   .4981836   .1199758  
        CIS    1.213445          2   .2953858    .537335   .1672791  
     COMESA   -.4923739          2   .2928168   .5381733     .16901  
     Nordic    3.569642          2   .2793312   .5421802   .1784886  
        PIF    3.071981          2   .2681469   .5449649   .1868882  
        SCO    1.406566          2   .2663248   .5453689   .1883063  
      SAARC    1.186805          2   .1871136   .5450303   .2678561  
       SADC    .6496485          2   .1680484   .5377118   .2942398  
       LOAS    2.239748          2   .1679903   .5376836   .2943261  
    COMECON    1.623353          2   .1617391   .5344166   .3038443  
       IGAD   -.1582405          2   .1378407   .5171526   .3450067  
      ECCAS    1.861714          2   .0798484   .4276496    .492502  
      CEMAC    1.223062          2   .0754811   .4167724   .5077466  
        AMU    3.042046          2   .0324825    .252551   .7149665  

. list ioname community8 contractT p1 p2 p3 if contractT==3, noobs clean

      ioname   communi~8   contra~T         p1         p2         p3  
         GCC    3.105963          3   .8472868   .1377617   .0149515  
         COE    1.281854          3   .5117674   .4138666   .0743659  
          EU    2.264396          3   .3833612    .497341   .1192978  
          AU   -.4648814          3   .3720301    .503513   .1244569  
      ECOWAS    1.019116          3   .1693336   .5383262   .2923402  
        OECS    1.835956          3   .1225753   .5013251   .3760996  
    Mercosur    3.395183          3   .1100156   .4847787   .4052057  
        EAC2    1.549206          3   .0332613    .256791   .7099476  
         CAN    3.102656          3   .0305853   .2419556   .7274591  
        SICA     2.92502          3   .0274206   .2233971   .7491823  
        EAC1    2.359514          3   .0152681   .1402187   .8445132  

*******************************************************************
*APPENDIX:robustness: B.6
/*(a) two-stage model using xtivreg and xtivreg2*/
********************************************************************

 . xtivreg f.scope politymean capabilities1 members_log gdpmean1000 yearcc (contract
> dynamic=commundynamic), fe vce (cl ionumber) first



First-stage within regression

Fixed-effects (within) regression               Number of obs     =      3,203
Group variable: ionumber                        Number of groups  =         76

R-sq:                                           Obs per group:
     within  = 0.9194                                         min =          8
     between = 0.0307                                         avg =       42.1
     overall = 0.5471                                         max =         60

                                                F(6,75)           =     112.57
corr(u_i, Xb)  = -0.1304                        Prob > F          =     0.0000

                               (Std. Err. adjusted for 76 clusters in ionumber)
-------------------------------------------------------------------------------
              |               Robust
contractdyn~c |      Coef.   Std. Err.      t    P>|t|     [95% Conf. Interval]
--------------+----------------------------------------------------------------
   politymean |   .4630624   .3094969     1.50   0.139    -.1534871    1.079612
capabilities1 |  -3.261868   11.54494    -0.28   0.778    -26.26057    19.73683
  members_log |   10.73477   8.007326     1.34   0.184    -5.216638    26.68618
  gdpmean1000 |   -.254702   .2043929    -1.25   0.217    -.6618734    .1524695
       yearcc |   .9922132   .0989568    10.03   0.000     .7950812    1.189345
commundynamic |    .136174   .0292131     4.66   0.000     .0779786    .1943695
        _cons |  -27.56449   12.83985    -2.15   0.035    -53.14278   -1.986202
--------------+----------------------------------------------------------------
      sigma_u |  18.561187
      sigma_e |  5.8927518
          rho |  .90843707   (fraction of variance due to u_i)
-------------------------------------------------------------------------------

Fixed-effects (within) IV regression            Number of obs     =      3,203
Group variable: ionumber                        Number of groups  =         76

R-sq:                                           Obs per group:
     within  = 0.3815                                         min =          8
     between = 0.0066                                         avg =       42.1
     overall = 0.0553                                         max =         60


                                                Wald chi2(6)      =     221.31
corr(u_i, Xb)  = -0.5682                        Prob > chi2       =     0.0000

                                 (Std. Err. adjusted for 76 clusters in ionumber)
---------------------------------------------------------------------------------
                |               Robust
        F.scope |      Coef.   Std. Err.      z    P>|z|     [95% Conf. Interval]
----------------+----------------------------------------------------------------
contractdynamic |   .2194247   .0468604     4.68   0.000     .1275799    .3112694
     politymean |   .1059213   .0874717     1.21   0.226    -.0655201    .2773627
  capabilities1 |   1.938675   2.394496     0.81   0.418    -2.754452    6.631801
    members_log |   1.767976    1.78817     0.99   0.323    -1.736772    5.272724
    gdpmean1000 |  -.0145821   .0466588    -0.31   0.755    -.1060317    .0768676
         yearcc |   -.231007   .0680102    -3.40   0.001    -.3643045   -.0977095
          _cons |   1.919578   2.899143     0.66   0.508    -3.762638    7.601794
----------------+----------------------------------------------------------------
        sigma_u |  6.3948769
        sigma_e |  1.6580862
            rho |  .93700695   (fraction of variance due to u_i)
---------------------------------------------------------------------------------
Instrumented:   contractdynamic
Instruments:    politymean capabilities1 members_log gdpmean1000 yearcc
                commundynamic
---------------------------------------------------------------------------------



. xtivreg2 f.scope politymean capabilities1 members_log gdpmean1000 yearcc (contractdynamic=commundynam
> ic), fe first cl(ionumber)

FIXED EFFECTS ESTIMATION
------------------------
Number of groups =        76                    Obs per group: min =         8
                                                               avg =      42.1
                                                               max =        60

First-stage regressions
-----------------------


FIXED EFFECTS ESTIMATION
------------------------
Number of groups =        76                    Obs per group: min =         8
                                                               avg =      42.1
                                                               max =        60

First-stage regression of contractdynamic:

Statistics robust to heteroskedasticity and clustering on ionumber
Number of obs =                   3203
Number of clusters (ionumber) =     76
-------------------------------------------------------------------------------
              |               Robust
contractdyn~c |      Coef.   Std. Err.      t    P>|t|     [95% Conf. Interval]
--------------+----------------------------------------------------------------
commundynamic |    .136174   .0292085     4.66   0.000     .0789042    .1934439
   politymean |   .4630624   .3094485     1.50   0.135    -.1436809    1.069806
capabilities1 |  -3.261868   11.54314    -0.28   0.778    -25.89477    19.37104
  members_log |   10.73477   8.006073     1.34   0.180     -4.96293    26.43248
  gdpmean1000 |   -.254702   .2043609    -1.25   0.213    -.6553974    .1459934
       yearcc |   .9922132   .0989413    10.03   0.000     .7982166     1.18621
-------------------------------------------------------------------------------
F test of excluded instruments:
  F(  1,    75) =    21.74
  Prob > F      =   0.0000
Sanderson-Windmeijer multivariate F test of excluded instruments:
  F(  1,    75) =    21.74
  Prob > F      =   0.0000



Summary results for first-stage regressions
-------------------------------------------

                                           (Underid)            (Weak id)
Variable     | F(  1,    75)  P-val | SW Chi-sq(  1) P-val | SW F(  1,    75)
contractdyna |      21.74    0.0000 |       22.06   0.0000 |       21.74

NB: first-stage test statistics cluster-robust

Stock-Yogo weak ID F test critical values for single endogenous regressor:
                                   10% maximal IV size             16.38
                                   15% maximal IV size              8.96
                                   20% maximal IV size              6.66
                                   25% maximal IV size              5.53
Source: Stock-Yogo (2005).  Reproduced by permission.
NB: Critical values are for i.i.d. errors only.

Underidentification test
Ho: matrix of reduced form coefficients has rank=K1-1 (underidentified)
Ha: matrix has rank=K1 (identified)
Kleibergen-Paap rk LM statistic          Chi-sq(1)=12.62    P-val=0.0004

Weak identification test
Ho: equation is weakly identified
Cragg-Donald Wald F statistic                                    1113.21
Kleibergen-Paap Wald rk F statistic                                21.74

Stock-Yogo weak ID test critical values for K1=1 and L1=1:
                                   10% maximal IV size             16.38
                                   15% maximal IV size              8.96
                                   20% maximal IV size              6.66
                                   25% maximal IV size              5.53
Source: Stock-Yogo (2005).  Reproduced by permission.
NB: Critical values are for Cragg-Donald F statistic and i.i.d. errors.

Weak-instrument-robust inference
Tests of joint significance of endogenous regressors B1 in main equation
Ho: B1=0 and orthogonality conditions are valid
Anderson-Rubin Wald test           F(1,75)=       17.87     P-val=0.0001
Anderson-Rubin Wald test           Chi-sq(1)=     18.13     P-val=0.0000
Stock-Wright LM S statistic        Chi-sq(1)=     20.35     P-val=0.0000

NB: Underidentification, weak identification and weak-identification-robust
    test statistics cluster-robust

Number of clusters             N_clust  =         76
Number of observations               N  =       3203
Number of regressors                 K  =          6
Number of endogenous regressors      K1 =          1
Number of instruments                L  =          6
Number of excluded instruments       L1 =          1

IV (2SLS) estimation
--------------------

Estimates efficient for homoskedasticity only
Statistics robust to heteroskedasticity and clustering on ionumber

Number of clusters (ionumber) =     76                Number of obs =     3203
                                                      F(  6,    75) =     8.56
                                                      Prob > F      =   0.0000
Total (centered) SS     =  13873.32446                Centered R2   =   0.3815
Total (uncentered) SS   =  13873.32446                Uncentered R2 =   0.3815
Residual SS             =  8580.408792                Root MSE      =    1.656

---------------------------------------------------------------------------------
                |               Robust
        F.scope |      Coef.   Std. Err.      z    P>|z|     [95% Conf. Interval]
----------------+----------------------------------------------------------------
contractdynamic |   .2194247   .0465075     4.72   0.000     .1282717    .3105777
     politymean |   .1059213   .0868129     1.22   0.222    -.0642289    .2760715
  capabilities1 |   1.938675   2.376461     0.82   0.415    -2.719103    6.596453
    members_log |   1.767976   1.774701     1.00   0.319    -1.710375    5.246326
    gdpmean1000 |  -.0145821   .0463074    -0.31   0.753    -.1053429    .0761788
         yearcc |   -.231007   .0674979    -3.42   0.001    -.3633005   -.0987135
---------------------------------------------------------------------------------
Underidentification test (Kleibergen-Paap rk LM statistic):             12.623
                                                   Chi-sq(1) P-val =    0.0004
------------------------------------------------------------------------------
Weak identification test (Cragg-Donald Wald F statistic):             1113.207
                         (Kleibergen-Paap rk Wald F statistic):         21.735
Stock-Yogo weak ID test critical values: 10% maximal IV size             16.38
                                         15% maximal IV size              8.96
                                         20% maximal IV size              6.66
                                         25% maximal IV size              5.53
Source: Stock-Yogo (2005).  Reproduced by permission.
NB: Critical values are for Cragg-Donald F statistic and i.i.d. errors.
------------------------------------------------------------------------------
Hansen J statistic (overidentification test of all instruments):         0.000
                                                 (equation exactly identified)
------------------------------------------------------------------------------
Instrumented:         contractdynamic
Included instruments: politymean capabilities1 members_log gdpmean1000 yearcc
Excluded instruments: commundynamic
------------------------------------------------------------------------------

***with interests****
xtivreg f.scope politymean capabilities1 members_log gdpmean1000 gdpcov idealdistmean yearcc (contractdynamic=commundynamic), fe vce (cl ionumber) first
xtivreg2 f.scope politymean capabilities1 members_log gdpmean1000 gdpcov yearcc (contractdynamic=commundynamic), fe first cl(ionumber) 
fp <yearcc>: xtivreg2 f.scope politymean capabilities1 members_log gdpmean1000 gdpcov idealdistmean <yearcc> (contractdynamic=commundynamic), fe first cl(ionumber) 


//**same results, but note that GDP covariance is negatively and significantly associated with policy scope)

*****************************************************************		
**Poisson model as alternative: B.7		
*****************************************************************
xtpoisson f.scope commundynamic contractdynamic politymean capabilities1 members_log gdpmean1000 year, fe vce (robust)


Iteration 0:   log pseudolikelihood = -5708.3489  
Iteration 1:   log pseudolikelihood = -5338.8551  
Iteration 2:   log pseudolikelihood = -5338.4096  
Iteration 3:   log pseudolikelihood = -5338.4096  

Conditional fixed-effects Poisson regression    Number of obs     =      3,203
Group variable: ionumber                        Number of groups  =         76

                                                Obs per group:
                                                              min =          8
                                                              avg =       42.1
                                                              max =         60

                                                Wald chi2(7)      =      97.48
Log pseudolikelihood  = -5338.4096              Prob > chi2       =     0.0000

                                  (Std. Err. adjusted for clustering on ionumber)
---------------------------------------------------------------------------------
                |               Robust
        F.scope |      Coef.   Std. Err.      z    P>|z|     [95% Conf. Interval]
----------------+----------------------------------------------------------------
  commundynamic |   .0022788   .0010533     2.16   0.031     .0002143    .0043433
contractdynamic |   .0032728   .0031291     1.05   0.296    -.0028601    .0094057
     politymean |   .0198695   .0128401     1.55   0.122    -.0052966    .0450357
  capabilities1 |   .4206792   .2758862     1.52   0.127    -.1200478    .9614062
    members_log |   .5526545   .2693867     2.05   0.040     .0246664    1.080643
    gdpmean1000 |  -.0062231   .0049788    -1.25   0.211    -.0159813    .0035352
           year |  -.0002995   .0041978    -0.07   0.943    -.0085272    .0079281
---------------------------------------------------------------------------------

. 
end of do-file

. estat ic

Akaike's information criterion and Bayesian information criterion

-----------------------------------------------------------------------------
       Model |        Obs  ll(null)  ll(model)      df         AIC        BIC
-------------+---------------------------------------------------------------
           . |      3,203         .   -5338.41       7    10690.82   10733.32
-----------------------------------------------------------------------------
               Note: N=Obs used in calculating BIC; see [R] BIC note.



xtpoisson f.scope contractdynamic politymean capabilities1 members_log gdpmean1000 year, fe vce (robust)


Iteration 0:   log pseudolikelihood = -5708.3489  
Iteration 1:   log pseudolikelihood = -5358.4607  
Iteration 2:   log pseudolikelihood = -5358.0875  
Iteration 3:   log pseudolikelihood = -5358.0875  

Conditional fixed-effects Poisson regression    Number of obs     =      3,203
Group variable: ionumber                        Number of groups  =         76

                                                Obs per group:
                                                              min =          8
                                                              avg =       42.1
                                                              max =         60

                                                Wald chi2(6)      =      81.26
Log pseudolikelihood  = -5358.0875              Prob > chi2       =     0.0000

                                  (Std. Err. adjusted for clustering on ionumber)
---------------------------------------------------------------------------------
                |               Robust
        F.scope |      Coef.   Std. Err.      z    P>|z|     [95% Conf. Interval]
----------------+----------------------------------------------------------------
contractdynamic |    .007835    .002931     2.67   0.008     .0020903    .0135797
     politymean |    .017657   .0129879     1.36   0.174    -.0077988    .0431127
  capabilities1 |   .3645389   .3001563     1.21   0.225    -.2237566    .9528343
    members_log |   .2688379   .2369325     1.13   0.257    -.1955413    .7332171
    gdpmean1000 |  -.0021788   .0047239    -0.46   0.645    -.0114375    .0070799
           year |  -.0007146   .0048774    -0.15   0.884    -.0102741    .0088449
---------------------------------------------------------------------------------

. 
end of do-file

. estat ic

Akaike's information criterion and Bayesian information criterion

-----------------------------------------------------------------------------
       Model |        Obs  ll(null)  ll(model)      df         AIC        BIC
-------------+---------------------------------------------------------------
           . |      3,203         .  -5358.088       6    10728.18   10764.61
---------------------------------------------------------------------------


xtpoisson f.scope commundynamic politymean capabilities1 members_log gdpmean1000 year,  fe vce (robust)

Iteration 0:   log pseudolikelihood = -5708.3489  
Iteration 1:   log pseudolikelihood = -5341.8127  
Iteration 2:   log pseudolikelihood = -5341.3708  
Iteration 3:   log pseudolikelihood = -5341.3708  

Conditional fixed-effects Poisson regression    Number of obs     =      3,203
Group variable: ionumber                        Number of groups  =         76

                                                Obs per group:
                                                              min =          8
                                                              avg =       42.1
                                                              max =         60

                                                Wald chi2(6)      =      96.80
Log pseudolikelihood  = -5341.3708              Prob > chi2       =     0.0000

                                (Std. Err. adjusted for clustering on ionumber)
-------------------------------------------------------------------------------
              |               Robust
      F.scope |      Coef.   Std. Err.      z    P>|z|     [95% Conf. Interval]
--------------+----------------------------------------------------------------
commundynamic |   .0027622   .0009038     3.06   0.002     .0009908    .0045336
   politymean |   .0210292   .0126977     1.66   0.098    -.0038578    .0459163
capabilities1 |   .4065055    .275209     1.48   0.140    -.1328942    .9459052
  members_log |   .5934057   .2632545     2.25   0.024     .0774364    1.109375
  gdpmean1000 |  -.0069159   .0050408    -1.37   0.170    -.0167956    .0029638
         year |   .0034809   .0039261     0.89   0.375    -.0042141     .011176
-------------------------------------------------------------------------------

. 
end of do-file

. estat ic

Akaike's information criterion and Bayesian information criterion

-----------------------------------------------------------------------------
       Model |        Obs  ll(null)  ll(model)      df         AIC        BIC
-------------+---------------------------------------------------------------
           . |      3,203         .  -5341.371       6    10694.74   10731.17
-----------------------------------------------------------------------------
               Note: N=Obs used in calculating BIC; see [R] BIC note.

 **with interests**
xtpoisson f.scope commundynamic politymean cmembers_log apabilities1 gdpmean1000 gdpcov year,  fe vce (robust)
xtpoisson f.scope contractdynamic politymean members_log capabilities1 gdpmean1000 gdpcov year,  fe vce (robust)
xtpoisson f.scope commundynamic contractdynamic politymean members_log capabilities1 gdpmean1000 gdpcov year,  fe vce (robust)
estat ic	   
			   
. ivpoisson gmm scope l1.politymean l1.capabilities1 l1.members_log l1.gdpmean1000 yearcc (contractdynamic = l1.commundynamic), vce(cluster ionumber)

Step 1
Iteration 0:   GMM criterion Q(b) =  1.6254987  
Iteration 1:   GMM criterion Q(b) =  .04950381  
Iteration 2:   GMM criterion Q(b) =  .00002916  
Iteration 3:   GMM criterion Q(b) =  1.598e-11  
Iteration 4:   GMM criterion Q(b) =  6.191e-24  

Step 2
Iteration 0:   GMM criterion Q(b) =  1.063e-26  
Iteration 1:   GMM criterion Q(b) =  2.401e-33  

note: model is exactly identified

Exponential mean model with endogenous regressors

Number of parameters =   7                         Number of obs  =      3,203
Number of moments    =   7
Initial weight matrix: Unadjusted
GMM weight matrix:     Cluster (ionumber)

                                 (Std. Err. adjusted for 76 clusters in ionumber)
---------------------------------------------------------------------------------
                |               Robust
          scope |      Coef.   Std. Err.      z    P>|z|     [95% Conf. Interval]
----------------+----------------------------------------------------------------
contractdynamic |   .0104938   .0028259     3.71   0.000     .0049552    .0160325
                |
     politymean |
            L1. |  -.0198468   .0128996    -1.54   0.124    -.0451295    .0054359
                |
  capabilities1 |
            L1. |   .1135686   .3835318     0.30   0.767    -.6381399    .8652772
                |
    members_log |
            L1. |  -.7231217   .1223978    -5.91   0.000    -.9630169   -.4832265
                |
    gdpmean1000 |
            L1. |  -.0213083   .0076186    -2.80   0.005    -.0362405   -.0063762
                |
         yearcc |   .0142339   .0053926     2.64   0.008     .0036645    .0248033
          _cons |     2.1406    .343991     6.22   0.000      1.46639     2.81481
---------------------------------------------------------------------------------
Instrumented:  contractdynamic
Instruments:   L.politymean L.capabilities1 L.members_log L.gdpmean1000 yearcc
               L.commundynamic


***********************************************
**Table 5.5:Community-contract and trade and appendix table B.8
************************************************
gen trade2=1 if trade==2| trade==1
replace trade2=0 if trade==0
tsset ionumber year
gen regional1=regional /*with some adjustments: regional1=0 if ioname=="CCNR"| ioname=="COE"| ioname=="OAPEC"| ioname=="CERN"| ioname=="ESA"| ioname=="OSCE"| ioname=="SPC" */
list ioname regional1 if regional1==1 & year==2010
   +------------------------------+
  |   ioname   region~1   trade2 |
  |------------------------------|
  |    ALADI          1        1 |
  |      AMU          1        1 |
  |     APEC          1        1 |
  |    ASEAN          1        1 |
  |       AU          1        1 |
  |------------------------------|
  |  Benelux          1        1 |
  |      CAN          1        1 |
  |    CEMAC          1        1 |
  |      CIS          1        1 |
  |  COMECON          1        1 |
  |------------------------------|
  |   COMESA          1        1 |
  |  Caricom          1        1 |
  |     EAC1          1        1 |
  |     EAC2          1        1 |
  |    ECCAS          1        1 |
  |------------------------------|
  |   ECOWAS          1        1 |
  |      EEA          1        1 |
  |     EFTA          1        1 |
  |       EU          1        1 |
  |      GCC          1        1 |
  |------------------------------|
  |     IGAD          1        1 |
  |     LOAS          1        1 |
  | Mercosur          1        1 |
  |    NAFTA          1        1 |
  |   Nordic          1        1 |
  |------------------------------|
  |      OAS          1        1 |
  |     OECS          1        1 |
  |      PIF          1        1 |
  |    SAARC          1        1 |
  |     SACU          1        1 |
  |------------------------------|
  |     SADC          1        1 |
  |      SCO          1        1 |
  |     SELA          1        1 |
  |     SICA          1        1 |
  +------------------------------+




** models 1 and 2 + appendix Table B.8
gen trade2dynamic=trade2*age_adj
gen tradedynamic=trade*age_adj
xtreg f.scope trade2dynamic politymean  members_log capabilities1 gdpmean1000 gdpcov yearcc , fe vce (cl ionumber) /**model 1**/
xtreg f.scope trade2dynamic commundynamic contractdynamic politymean members_log capabilities1 gdpmean1000 gdpcov yearcc , fe vce (cl ionumber) /**model 2**/
xtreg f.scope trade2dynamic commundynamic contractdynamic politymean members_log capabilities1 gdpmean1000 gdpcov idealdistmean yearcc , fe vce (cl ionumber)
fp <yearcc>: xtreg f.scope trade2dynamic commundynamic contractdynamic politymean members_log capabilities1 gdpmean1000 gdpcov <yearcc> , fe vce (cl ionumber) /**model 3**/

xtreg f.scope trade2dynamic commundynamic contractdynamic politymean members_log capabilities1 gdpmean1000 gdpcov yearcc scope , fe vce (cl ionumber) /**model 4**/
estat ic

*************************************************************************
*Table B.9: Substantive effects of trade
*************************************************************************
tabstat trade2dynamic commundynamic contractdynamic, stats (p25 p75 sd min max)


   stats |  trade2~c  commun~c  contra~c
---------+------------------------------
     p25 |         0  5.835187        14
     p75 |        21  87.39869        49
      sd |  16.21398  68.96709  25.45631
     min |         0  .0286091         1
     max |        61  352.4449       122
----------------------------------------

xtreg f.scope trade2dynamic commundynamic contractdynamic politymean members_log capabilities1 gdpmean1000 gdpcov yearcc , fe vce (cl ionumber)
margins, atmeans at((p05)commundynamic) at ((p95) commundynamic)
margins, atmeans at((p05)contractdynamic) at ((p95) contractdynamic)
margins, atmeans at((p05)trade2dynamic) at ((p95) trade2dynamic)

margins, at (trade2dynamic=(16.21 32.42))
margins, at (commundynamic =(68.97 137.94))
margins, at (contractdynamic =(25.45 50.90))

fp<yearcc>: xtreg f.scope trade2dynamic commundynamic contractdynamic politymean members_log capabilities1 gdpmean1000 gdpcov <yearcc>, fe vce (cl ionumber)



*************************************************
** appendix B.10, B.11, B. 12: Does trade shape task-dynamism? 
**************************************************
**zooming into the broad contracts with trade (contract2=1)
**run with all IOs that have trade competence and are regional [otherwise trade interdependence measure does not make sense]
gen tradeend=trade2 if end==1

gen regional1=regional /*with some adjustments: regional1=0 if ioname=="CCNR"| ioname=="COE"| ioname=="OAPEC"| ioname=="CERN"| ioname=="ESA"| ioname=="OSCE"| ioname=="SPC" */
list ioname regional1 trade2 symtradeintrov1 if regional1==1 & end==1
   +------------------------------+
  |   ioname   region~1   trade2 |
  |------------------------------|
  |    ALADI          1        1 |
  |      AMU          1        1 |
  |     APEC          1        1 |
  |    ASEAN          1        1 |
  |       AU          1        1 |
  |------------------------------|
  |  Benelux          1        1 |
  |      CAN          1        1 |
  |    CEMAC          1        1 |
  |      CIS          1        1 |
  |  COMECON          1        1 |
  |------------------------------|
  |   COMESA          1        1 |
  |  Caricom          1        1 |
  |     EAC1          1        1 |
  |     EAC2          1        1 |
  |    ECCAS          1        1 |
  |------------------------------|
  |   ECOWAS          1        1 |
  |      EEA          1        1 |
  |     EFTA          1        1 |
  |       EU          1        1 |
  |      GCC          1        1 |
  |------------------------------|
  |     IGAD          1        1 |
  |     LOAS          1        1 |
  | Mercosur          1        1 |
  |    NAFTA          1        1 |
  |   Nordic          1        1 |
  |------------------------------|
  |      OAS          1        1 |
  |     OECS          1        1 |
  |      PIF          1        1 |
  |    SAARC          1        1 |
  |     SACU          1        1 |
  |------------------------------|
  |     SADC          1        1 |
  |      SCO          1        1 |
  |     SELA          1        1 |
  |     SICA          1        1 |
  +------------------------------+



tab trade2 regional1 if end==1
 
 . tab trade2 regional1 if end==1

     1= if |
  trade is |
  flanking |  not including COE,
or core; 0 |  CCNR, OAPEC, CERN,
     if no |   ESA, OSCE, SPC=0
     trade |         (ch4)
     [ch4] |         0          1 |     Total
-----------+----------------------+----------
         0 |        34          0 |        34 
         1 |         8         34 |        42 
-----------+----------------------+----------
     Total |        42         34 |        76 

 
 
***************************************** 
*Table B.11: Trade interdependence and policy scope
*****************************************
  
gsort ionumber -year
by ionumber, sort: replace tradeend=tradeend[_n-1] if tradeend>=.
sort ionumber year
/*use symbtradeintrov1!=. as additional selector to make sure that all equations have exactly same cases (since there are a few missing values for some IOs/ measures*/
xtreg f.scope commundynamic contractdynamic politymean members_log capabilities1 gdpmean1000 yearcc if year>1969 & tradeend==1 & regional1==1 & symtradeintrov1!=., fe vce (cl ionumber) /**appendix: base line**/
xtreg f.scope commundynamic contractdynamic politymean members_log capabilities1 gdpmean1000 gdpcov yearcc if year>1969 & tradeend==1 & regional1==1 & symtradeintrov1!=., fe vce (cl ionumber) /**appendix: base line with interests**/
fp <yearcc>, scale: xtreg f.scope commundynamic contractdynamic politymean members_log capabilities1 gdpmean1000 gdpcov <yearcc> if year>1969 & tradeend==1 & regional1==1 & symtradeintrov1!=., fe vce (cl ionumber) /**appendix: base line with interests**/

xtreg f.scope intratradeshare1 if year>1969 & tradeend==1 & regional1==1 & symtradeintrov1!=., fe vce (cl ionumber) /**appendix: model 1**/
estat ic
xtreg f.scope intratradeintens1 if year>1969 & tradeend==1 & regional1==1 & symtradeintrov1!=., fe vce (cl ionumber) /**appendix: model 2**/
estat ic
xtreg f.scope symtradeintrov1 if year>1969 & tradeend==1 & regional1==1 & symtradeintrov1!=., fe vce (cl ionumber)  /**appendix: model 3**/
estat ic

xtreg f.scope commundynamic contractdynamic politymean members_log capabilities1 gdpmean1000 yearcc if year>1969 & tradeend==1 & regional1==1 & symtradeintrov1!=., fe vce (cl ionumber) /**appendix: base line**/
estat ic

xtreg f.scope intratradeshare1 politymean capabilities1 members_log gdpmean1000 yearcc if year>1969 & tradeend==1 & regional1==1 & symtradeintrov1!=., fe vce (cl ionumber) /**appendix: model 4**/
estat ic
xtreg f.scope intratradeintens1 politymean capabilities1 members_log gdpmean1000 yearcc if year>1969 & tradeend==1 & regional1==1 & symtradeintrov1!=., fe vce (cl ionumber) /**appendix: model 4**/
estat ic
xtreg f.scope symtradeintrov1 politymean capabilities1 members_log gdpmean1000 yearcc if year>1969 & tradeend==1 & regional1==1 & symtradeintrov1!=., fe vce (cl ionumber)  /**appendix: model 4**/
estat ic

*with interests
xtreg f.scope intratradeshare1 politymean members_log capabilities1 gdpmean1000 gdpcov yearcc if year>1969 & tradeend==1 & regional1==1 & symtradeintrov1!=., fe vce (cl ionumber) /**appendix: model 4**/
estat ic
xtreg f.scope intratradeintens1 politymean members_log capabilities1 gdpmean1000 gdpcov yearcc if year>1969 & tradeend==1 & regional1==1 & symtradeintrov1!=., fe vce (cl ionumber) /**appendix: model 4**/
estat ic
xtreg f.scope symtradeintrov1 politymean members_log capabilities1 gdpmean1000 gdpcov yearcc if year>1969 & tradeend==1 & regional1==1 & symtradeintrov1!=., fe vce (cl ionumber)  /**appendix: model 4**/
estat ic

xtreg f.scope intratradeshare1 commundynamic contractdynamic politymean members_log capabilities1 gdpmean1000 yearcc if year>1969 & tradeend==1 & regional1==1 & symtradeintrov1!=., fe vce (cl ionumber) /**appendix: model 5**/
estat ic
xtreg f.scope commundynamic contractdynamic politymean members_log capabilities1 gdpmean1000 yearcc if year>1969 & tradeend==1 & regional1==1 & symtradeintrov1!=., fe vce (cl ionumber)  /**appendix: model 5**/
estat ic
xtreg f.scope intratradeintens1 commundynamic contractdynamic politymean members_log capabilities1 gdpmean1000 yearcc if year>1969 & tradeend==1 & regional1==1 & symtradeintrov1!=., fe vce (cl ionumber)  /**appendix: model 5**/
estat ic
xtreg f.scope commundynamic contractdynamic symtradeintrov1 politymean members_log capabilities1 gdpmean1000 gdpcov yearcc if year>1969 & tradeend==1 & regional1==1 & symtradeintrov1!=., fe vce (cl ionumber)  /**appendix: model 5** with interests**/
estat ic
fp <yearcc>, scale: xtreg f.scope commundynamic contractdynamic symtradeintrov1 politymean members_log capabilities1 gdpmean1000 gdpcov <yearcc> if year>1969 & tradeend==1 & regional1==1 & symtradeintrov1!=., fe vce (cl ionumber)  /**appendix: model 5** with interests**/


xtreg f.scope intratradeshare1 commundynamic contractdynamic politymean members_log capabilities1 gdpmean1000 yearcc scope if year>1969 & tradeend==1 & regional1==1 & symtradeintrov1!=., fe vce (cl ionumber) /**appendix: model 6**/
estat ic
xtreg f.scope intratradeintens1 commundynamic contractdynamic politymean members_log capabilities1 gdpmean1000 yearcc scope if year>1969 & tradeend==1 & regional1==1 & symtradeintrov1!=., fe vce (cl ionumber)  /**appendix: model 6**/
estat ic
xtreg f.scope symtradeintrov1 commundynamic contractdynamic politymean members_log capabilities1 gdpmean1000 yearcc scope if year>1969 & tradeend==1 & regional1==1 & symtradeintrov1!=., fe vce (cl ionumber)  /**appendix: model 6**/
estat ic
xtreg f.scope symtradeintrov1 commundynamic contractdynamic politymean members_log capabilities1 gdpmean1000 gdpcov yearcc scope if year>1969 & tradeend==1 & regional1==1 & symtradeintrov1!=., fe vce (cl ionumber)  /**appendix: model 6 with interests**/
estat ic

*************************************************************************
*Table B.12: additional models on trade interdependence and policy scope*
*************************************************************************
xtreg f.scope capabilities1 if year>1969 & tradeend==1 & regional1==1 & symtradeintrov1!=., fe vce (cl ionumber) /*base*/
xtreg f.scope members_log capabilities1 yearcc if year>1969 & tradeend==1 & regional1==1 & symtradeintrov1!=., fe vce (cl ionumber) /*model 1*/
xtreg f.scope contractdynamic symtradeintrov1 members_log capabilities1 yearcc if year>1969 & tradeend==1 & regional1==1 & symtradeintrov1!=., fe vce (cl ionumber) /*model 2*/
xtreg f.scope contractdynamic symtradeintrov1 politymean members_log capabilities1 gdpmean1000 gdpcov yearcc if year>1969 & tradeend==1 & regional1==1 & symtradeintrov1!=., fe vce (cl ionumber) /*model 3*/
xtreg f.scope contractdynamic symtradeintrov1 politymean members_log capabilities1 gdpmean1000 gdpcov yearcc if year>1969 & tradeend==1 & regional1==1 & symtradeintrov1!=., fe vce (cl ionumber) /*model 4*/
xtreg f.scope contractdynamic symtradeintrov1 politymean members_log capabilities1 gdpmean1000 gdpcov yearcc if ioname!="EU" & year>1969 & tradeend==1 & regional1==1 & symtradeintrov1!=., fe vce (cl ionumber) /*model 5*/
xtreg f.scope contractdynamic symtradeintrov1 politymean members_log capabilities1 gdpmean1000 gdpcov yearcc if year>1969 & tradeend==1 & regional1==1 & symtradeintrov1!=., fe vce (jack) /*model 6*/

***********************************************************************************************************
*Table B.13: 

gen select=1 if regional1==1 & trade2==1 & year>1969
replace select=0 if select==. & year>1969

gen idealdistmeanr=idealdistmean-.0026667
tabstat idealdistmeanr, stat (mean p50 min max sd)
replace idealdistmeanr=idealdistmean/2.344666
gen idealproxr=1-idealdistmeanr

gen communityproxr=community8r/5.973642
tabstat communityproxr, stats (min max)
mean communityproxr idealproxr capabilities1 if end==1, over(select)
tabstat capabilities1, stats (min max)

mean communityproxr idealproxr capabilities1 if end==1, over(select)
Mean estimation                   Number of obs   =         76

            0: select = 0
            1: select = 1

----------------------------------------------------------------
          Over |       Mean   Std. Err.     [95% Conf. Interval]
---------------+------------------------------------------------
communityproxr |
             0 |    .220762   .0385491      .1439683    .2975557
             1 |   .6676202   .0374087      .5930983    .7421421
---------------+------------------------------------------------
idealproxr     |
             0 |   .6591426   .0159366      .6273952      .69089
             1 |   .8100646   .0266241      .7570267    .8631024
---------------+------------------------------------------------
capabilities1  |
             0 |   .2710556   .0205358      .2301463     .311965
             1 |    .480156    .037736       .404982    .5553301
----------------------------------------------------------------

. 
