*//chapter SIX on changing authority//
*last change: November 11, 2018, edited May 2020
*LH
********************************
*     *****************************************************************
*     ***************************************************************** 
* 		File-Name:      ch6 do file on authority change_may2020.do       	                 
*   	Date:           Feb 2018 (v1) May 2020 (final)                               
*     	Author:         LH                                          
*     	Purpose:        Create tables and figures for chapter 6 changing authority
*    	*     ****************************************************************  
*     ****************************************************************  


////*penultimate change: November 11, 2018* latest check, May 5, 2020
////*author: liesbet hooghe*////
*//CHAPTER SIX: change in delegation & pooling//

use: "INDEP_replication.dta"

*Beginning of chapter six*
gen delD=1 if delchange>=0.01 & delchange!=.
replace delD=0 if delchange>-0.01 & delchange<0.01
replace delD=-1 if delchange<=-0.01

gen poolD=1 if poolchange>=0.01 & poolchange!=.
replace poolD=0 if poolchange>-0.01 & poolchange<0.01
replace poolD=-1 if poolchange<=-0.01

tab delD poolD, column



           |              poolD
      delD |        -1          0          1 |     Total
-----------+---------------------------------+----------
        -1 |         0          3          1 |         4 
           |      0.00       9.68       2.78 |      5.26 
-----------+---------------------------------+----------
         0 |         4         23          2 |        29 
           |     44.44      74.19       5.56 |     38.16 
-----------+---------------------------------+----------
         1 |         5          5         33 |        43 
           |     55.56      16.13      91.67 |     56.58 
-----------+---------------------------------+----------
     Total |         9         31         36 |        76 
           |    100.00     100.00     100.00 |    100.00 


*********************FIGURES AND GRAPHS************************************
 *Figure 6.1: Gary's figure -- a model of international authority
 **************************************************************************

 **************************************************************************
 *Figure 6.2: change in delegation by IO
 **************************************************************************
use "INDEP_replication.dta" (or most recent) or "MASTER_sept2017_FINAL.dta" (or most recent)
 tsset year ionumber
sort ionumber year

gen groupdeldiff=0
replace groupdeldiff=1 if delchange>0.05
sort groupdeldiff ioname
graph hbar (mean) delchange if groupdeldiff==0, over(ioname, sort (delchange) descending)ylabel(-0.3(0.1)0.2)
graph save 1, replace
graph hbar (mean) delchange if groupdeldiff==1 & end==1, over(ioname, sort (delchange)descending)ylabel(0(0.1)0.5)
graph save 2, replace
graph combine 2.gph 1.gph, graphregion(fcolor(white))

sort ionumber year
gen delegation_creation=delegation if initial==1
by ionumber: replace delegation_creation=delegation_creation[_n-1] if delegation_creation==.
sort delchange
list ioname delegation delchange if end==1, noobs clean
sort delegation_creation
list ioname delegation delegation_creation if end==1, noobs clean

*******************************************************************************
**Figure 6.3 A,B,C.D.: change in delegation by IO body: use 
*******************************************************************************
use "C:\MASTER_june2018_FINAL.dta" or most recent version

**Create a variable that registers whether an IO's GS has monopoly of initiative or formal initiative in at least one policy stream
gen PM_25c=1 if PM1_25c==1| PM2_25c==1| PM3_25c==1| PM4_25c==1| PM5_25c==1
replace PM_25c=2 if PM1_25c==2| PM2_25c==2| PM3_25c==2| PM4_25c==2| PM5_25c==2
replace PM_25c=0 if PM_25c==.

**does an IO GS have agenda setting powers on the budget?
gen BUD22_GS=1 if BUD22a_GS1!=.| BUD22a_GS2!=.
replace BUD22_GS=0 if BUD22_GS==.

**does an IO GS have agenda setting powers in at least one policy area?
gen PM_GS=1 if (PM1_25a_GS1>=0 & PM1_25a_GS1!=.)| (PM2_25a_GS1>=0 & PM2_25a_GS1!=.)| (PM3_25a_GS1>=0 & PM3_25a_GS1!=.)| (PM4_25a_GS1>=0 & PM4_25a_GS1!=.)|(PM5_25a_GS1>=0 & PM5_25a_GS1!=.)|  (PM1_25a_GS2>=0 & PM1_25a_GS2!=.)| (PM2_25a_GS2>=0 & PM2_25a_GS2!=.)| (PM3_25a_GS2>=0 & PM3_25a_GS2!=.)| (PM4_25a_GS2>=0 & PM4_25a_GS2!=.)|(PM5_25a_GS2>=0 & PM5_25a_GS2!=.)
replace PM_GS=0 if PM_GS==.

**do this for every decision stream
gen ACC16_GS=1 if (ACC16a_GS1>=0 & ACC16a_GS1!=.)| (ACC16a_GS2>=0 & ACC16a_GS2!=.)
replace ACC16_GS=0 if ACC16_GS==.
gen SUSP18_GS=1 if (SUSP18a_GS1>=0 & SUSP18a_GS1!=.)| (SUSP18a_GS2>=0 & SUSP18a_GS2!=.)
replace SUSP18_GS=0 if SUSP18_GS==.
gen CON19_GS=1 if (CON19a_GS1>=0 & CON19a_GS1!=.)| (CON19a_GS2>=0 & CON19a_GS2!=.)
replace CON19_GS=0 if CON19_GS==.
gen COM24_GS=1 if (COM24a_GS1>=0 & COM24a_GS1!=.)| (COM24a_GS2>=0 & COM24a_GS2!=.)
replace COM24_GS=0 if COM24_GS==.
label variable ACC16_GS "1=IO GS has agenda powers on accession"
label variable SUSP18_GS "1=IO GS has agenda powers on suspension"
label variable CON19_GS "1=IO GS has agenda powers on constitutional reform"
label variable COM24_GS "1=IO GS has agenda powers on compliance"

***
gen budpm_GS=3 if PM_GS==1 & BUD22_GS==1
replace budpm_GS=2 if PM_GS==1 & BUD22_GS==0
replace budpm_GS=1 if PM_GS==0 & BUD22_GS==1
replace budpm_GS=0 if PM_GS==0 & BUD22_GS==0
gen init_end=1 if initial==1
replace init_end=2 if end==1
label variable init_end "1=initial 2=end"
label define init_end 1 "initial" 2 "end"
label define budpm 0 "none" 1 "agenda in budget" 2 "agenda in policy" 3 "agenda in budget + policy"
label values budpm_GS budpm
label values init_end init_end
gen decision= ACC16_GS + SUSP18_GS + CON19_GS + COM24_GS + BUD22_GS + PM_GS
replace decision=0 if decision==.
tab decision

*** dispute settlement
gen DS_strength7=0 if DS_strength<0.5
replace DS_strength7=1 if DS_strength>=0.5 & DS_strength<1.5
replace DS_strength7=2 if DS_strength>=1.5 & DS_strength<2.5
replace DS_strength7=3 if DS_strength>=2.5 & DS_strength<3.5
replace DS_strength7=4 if DS_strength>=3.5 & DS_strength<4.5
replace DS_strength7=5 if DS_strength>=4.5 & DS_strength<5.5
replace DS_strength7=6 if DS_strength>=5.5 & DS_strength<6.5
replace DS_strength7=7 if DS_strength>=6.5

*** Consultative bodies
*a) create dummy variables
foreach v of varlist ACC16a_CB1  SUSP18a_CB* CON19a_CB* BUD22_CB* PM1_25a_CB* PM2_25a_CB* PM3_25a_CB* PM4_25a_CB* PM5_25a_CB*{
gen f`v' =`v' 
}
*list variables

foreach v of varlist ACC16a_CB1-ACC16a_CB3 SUSP18a_CB1-SUSP18a_CB3 CON19a_CB1-CON19a_CB3 BUD22a_CB1-BUD22a_CB3 COM24a_CB1-COM24a_CB3 PM1_25a_CB1-PM1_25a_CB3 PM2_25a_CB1-PM2_25a_CB3 PM3_25a_CB1-PM3_25a_CB3 PM4_25a_CB1-PM4_25a_CB3 PM5_25a_CB1-PM5_25a_CB3 {
gen `v'r =`v' 
}
* list variables

foreach x of varlist ACC16a_CB1r-ACC16a_CB3r SUSP18a_CB1r-SUSP18a_CB3r CON19a_CB1r-CON19a_CB3r BUD22a_CB1r-BUD22a_CB3r COM24a_CB1r-COM24a_CB3r PM1_25a_CB1r-PM1_25a_CB3r PM2_25a_CB1r-PM2_25a_CB3r PM3_25a_CB1r-PM3_25a_CB3r PM4_25a_CB1r-PM4_25a_CB3r PM5_25a_CB1r-PM5_25a_CB3r{
replace `x' = 1 if `x'>=0 & `x'<. 
replace `x' = 0 if `x'==.
}
*create sums of CB role
gen CB_all=ACC16a_CB1r + ACC16a_CB2r + ACC16a_CB3r + SUSP18a_CB1r + SUSP18a_CB2r + SUSP18a_CB3r + CON19a_CB1r + CON19a_CB2r + CON19a_CB3r + BUD22a_CB1r + BUD22a_CB2r + BUD22a_CB3r + COM24a_CB1r + COM24a_CB2r + COM24a_CB3r + PM1_25a_CB1r + PM1_25a_CB2r + PM1_25a_CB3r + PM2_25a_CB1r + PM2_25a_CB2r + PM2_25a_CB3r + PM3_25a_CB1r + PM3_25a_CB2r + PM3_25a_CB3r + PM4_25a_CB1r + PM4_25a_CB2r + PM4_25a_CB3r + PM5_25a_CB1r + PM5_25a_CB2r + PM5_25a_CB3r
gen CB_access=ACC16a_CB1r + ACC16a_CB2r + ACC16a_CB3r
gen CB_susp= SUSP18a_CB1r + SUSP18a_CB2r + SUSP18a_CB3r
gen CB_const=CON19a_CB1r + CON19a_CB2r + CON19a_CB3r
gen CB_budget=BUD22a_CB1r + BUD22a_CB2r + BUD22a_CB3r
gen CB_compl=COM24a_CB1r + COM24a_CB2r + COM24a_CB3r
gen CB_policy=PM1_25a_CB2r + PM1_25a_CB3r + PM2_25a_CB1r + PM2_25a_CB2r + PM2_25a_CB3r + PM3_25a_CB1r + PM3_25a_CB2r + PM3_25a_CB3r + PM4_25a_CB1r + PM4_25a_CB2r + PM4_25a_CB3r + PM5_25a_CB1r + PM5_25a_CB2r + PM5_25a_CB3r

gen CB1_15r=1 if CB1_15!=. & CB1_15!=98
replace CB1_15r=0 if CB1_15r==. 
gen CB2_15r=1 if CB2_15!=.& CB2_15!=98
replace CB2_15r=0 if CB2_15r==.
gen CB3_15r=1 if CB3_15!=. & CB3_15!=98
replace CB3_15r=0 if CB3_15r==.

gen CB_number= CB1_15r + CB2_15r + CB3_15r
tab CB_number

gen contract_end=contract if end==1
gsort ionumber -year
by ionumber, sort: replace contract_end=contract_end[_n-1] if contract_end==.

***assemblies and executives
*use MASTER file to create, first, variables designating non-state assemblies, and then, calculate by policy area

gen A1_1d=1 if A1_1==3
replace A1_1d=0.66 if A1_1==2
replace A1_1d=0.33 if A1_1==1
replace A1_1d=0 if A1_1==0

gen A2_1d=1 if A2_1==3
replace A2_1d=0.66 if A2_1==2
replace A2_1d=0.33 if A2_1==1
replace A2_1d=0 if A2_1==0

gen A3_1d=1 if A3_1==3
replace A3_1d=0.66 if A3_1==2
replace A3_1d=0.33 if A3_1==1
replace A3_1d=0 if A3_1==0

tab A1_1d, missing
tab A2_1d, missing
tab A3_1d, missing

gen E1_8d=1 if E1_8==2
replace E1_8d=0.33 if E1_8==1
replace E1_8d=0 if E1_8==0
replace E1_8d=0 if E1_8==99

gen E2_8d=1 if E2_8==2
replace E2_8d=0.33 if E2_8==1
replace E2_8d=0 if E2_8==0

gen E3_8d=1 if E3_8==2
replace E3_8d=0.33 if E3_8==1
replace E3_8d=0 if E3_8==0

tab E1_8d, missing
tab E2_8d, missing
tab E3_8d, missing

***************** finding out which IOs have an assembly with some non-state rep

gen ACC16_A=1 if (ACC16a_A1!=.|  ACC16b_A1!=.) & A1_1d>0.50 & A1_1d<. 
tab ACC16_A
replace ACC16_A=1 if (ACC16a_A2!=.| ACC16b_A2!=.) &  A2_1d>0.50 & A2_1d<.
tab ACC16_A
replace ACC16_A=1 if (ACC16a_A3!=.| ACC16b_A3!=.) & A3_1d>0.50 & A3_1d<.
tab ACC16_A

gen SUSP18_A=1 if (SUSP18a_A1!=.|  SUSP18b_A1!=.) & A1_1d>0.50 & A1_1d<. 
tab SUSP18_A
replace SUSP18_A=1 if (SUSP18a_A2!=.| SUSP18b_A2!=.) &  A2_1d>0.50 & A2_1d<.
tab SUSP18_A
replace SUSP18_A=1 if (SUSP18a_A3!=.| SUSP18b_A3!=.) & A3_1d>0.50 & A3_1d<.
tab SUSP18_A

gen CON19_A=1 if (CON19a_A1!=.|  CON19b_A1!=.) & A1_1d>0.50 & A1_1d<. 
tab CON19_A
replace CON19_A=1 if (CON19a_A2!=.| CON19b_A2!=.) &  A2_1d>0.50 & A2_1d<.
tab CON19_A
replace CON19_A=1 if (CON19a_A3!=.| CON19b_A3!=.) & A3_1d>0.50 & A3_1d<.
tab CON19_A

gen BUD22_A=1 if (BUD22a_A1!=.|  BUD22b_A1!=.) & A1_1d>0.50 & A1_1d<. 
tab BUD22_A
replace BUD22_A=1 if (BUD22a_A2!=.| BUD22b_A2!=.) &  A2_1d>0.50 & A2_1d<.
tab BUD22_A
replace BUD22_A=1 if (BUD22a_A3!=.| BUD22b_A3!=.) & A3_1d>0.50 & A3_1d<.
tab BUD22_A

gen COM24_A=1 if (COM24a_A1!=.|  COM24b_A1!=.) & A1_1d>0.50 & A1_1d<. 
tab COM24_A
replace COM24_A=1 if (COM24a_A2!=.| COM24b_A2!=.) &  A2_1d>0.50 & A2_1d<.
tab COM24_A
replace COM24_A=1 if (COM24a_A3!=.| COM24b_A3!=.) & A3_1d>0.50 & A3_1d<.
tab COM24_A

gen PM25_A=1 if (PM1_25a_A1!=.|  PM1_25b_A1!=.) & A1_1d>0.50 & A1_1d<. 
tab PM25_A
replace PM25_A=1 if (PM1_25a_A2!=.| PM1_25b_A2!=.) &  A2_1d>0.50 & A2_1d<.
tab PM25_A
replace PM25_A=1 if (PM1_25a_A3!=.| PM1_25b_A3!=.) & A3_1d>0.50 & A3_1d<.
tab PM25_A
replace PM25_A=1 if (PM2_25a_A1!=.|  PM2_25b_A1!=.) & A1_1d>0.50 & A1_1d<. //*second policy stream*// 
tab PM25_A
replace PM25_A=1 if (PM2_25a_A2!=.| PM2_25b_A2!=.) &  A2_1d>0.50 & A2_1d<.
tab PM25_A
replace PM25_A=1 if (PM2_25a_A3!=.| PM2_25b_A3!=.) & A3_1d>0.50 & A3_1d<.
tab PM25_A
replace PM25_A=1 if (PM3_25a_A1!=.|  PM3_25b_A1!=.) & A1_1d>0.50 & A1_1d<. //*third policy stream*// 
tab PM25_A
replace PM25_A=1 if (PM3_25a_A2!=.| PM3_25b_A2!=.) &  A2_1d>0.50 & A2_1d<.
tab PM25_A
replace PM25_A=1 if (PM3_25a_A3!=.| PM3_25b_A3!=.) & A3_1d>0.50 & A3_1d<.
tab PM25_A
replace PM25_A=1 if (PM4_25a_A1!=.|  PM4_25b_A1!=.) & A1_1d>0.50 & A1_1d<. //*fourth policy stream*// 
tab PM25_A
replace PM25_A=1 if (PM4_25a_A2!=.| PM4_25b_A2!=.) &  A2_1d>0.50 & A2_1d<.
tab PM25_A
replace PM25_A=1 if (PM4_25a_A3!=.| PM4_25b_A3!=.) & A3_1d>0.50 & A3_1d<.
tab PM25_A
replace PM25_A=1 if (PM5_25a_A1!=.|  PM5_25b_A1!=.) & A1_1d>0.50 & A1_1d<. //*fifth policy stream*// 
tab PM25_A
replace PM25_A=1 if (PM5_25a_A2!=.| PM5_25b_A2!=.) &  A2_1d>0.50 & A2_1d<.
tab PM25_A
replace PM25_A=1 if (PM5_25a_A3!=.| PM5_25b_A3!=.) & A3_1d>0.50 & A3_1d<.
tab PM25_A

replace ACC16_A=0 if ACC16_A==.
replace SUSP18_A=0 if SUSP18_A==.
replace CON19_A =0 if CON19_A ==.
replace COM24_A =0 if COM24_A ==.
replace PM25_A =0 if PM25_A ==.
replace BUD22_A =0 if BUD22_A ==.

gen ASSEMBLY_all= ACC16_A+ SUSP18_A+ CON19_A + BUD22_A + COM24_A + PM25_A

//**parliamentary bodies
*see excel file "parliaments" in chapter 6
*own counting based on IO profiles
gen parliament=1 if ioname=="COE"| ioname=="EU"| ioname=="EEA"| ioname=="Nordc"|ioname=="EAC1"
replace parliament=1 if ioname=="Caricom" & year>1995 & year<2001
replace parliament=1 if ioname=="ASEAN" & year==2010
replace parliament=1 if ioname=="LOAS" & year>2006
replace parliament=1 if ioname=="AU" & year>2003
replace parliament=1 if ioname=="ECOWAS" & year>2001
replace parliament=1 if ioname=="EAC2" & year>2000
replace parliament=1 if ioname=="CEMAC" & year>1999
replace parliament=1 if ioname=="OIF" & year>1996
replace parliament=1 if ioname=="SADC" & year>1996
replace parliament=1 if ioname=="CIS" & year>1994
replace parliament=1 if ioname=="ECCAS" & year==2010
replace parliament=1 if ioname=="Mercosur" & year>1994
replace parliament=1 if ioname=="SICA" & year>1992
replace parliament=1 if ioname=="AMU" & year>1991
replace parliament=1 if ioname=="OSCE" & year>1990
replace parliament=1 if ioname=="CAN" & year>1983
replace parliament=1 if ioname=="EFTA" & year>1976
replace parliament=1 if ioname=="NATO" & year>1967
replace parliament=1 if ioname=="Benelux" & year>1959
label variable parliament "does IO have a parliament?"
replace parliament=0 if parliament==.

gen parliament2=parliament
replace parliament2=2 if ioname=="EU" & year>1978
replace parliament2=2 if ioname=="SICA" & year>1992
replace parliament2=2 if ioname=="CAN" & year==2010

*Figure 6.3 A,B,C,D:  Agenda setting powers of IO secretariats over time; DS, CB, parliaments
graph bar (count), over(decision) over(init_end) asyvars stack
graph bar (count), over(DS_strength7) over(init_end) asyvars stack
graph bar (count), over (CB_number) over(init_end) asyvars stack 
graph bar (count), over (CB_policy) over(init_end) asyvars stack
graph bar (count), over (CB_all) over(init_end) asyvars stack
graph bar (count), over (ASSEMBLY_all) over(init_end) asyvars stack
graph bar (count), over (parliament) over(init_end) asyvars stack
graph bar (count), over (parliament2) over(init_end) asyvars stack

*******************************************************************
*Figure 6.4: change in pooling by IO
*******************************************************************
use "INDEP_replication.dta" (or most recent) or "MASTER_june2018_FINAL.dta" (or most recent)
 tsset year ionumber
sort ionumber year

gen grouppooldiff=0
replace grouppooldiff=1 if poolchange>0
sort grouppooldiff ioname 
graph hbar (mean) poolchange if grouppooldiff==0, over(ioname, sort (poolchange) descending)ylabel(-0.4(0.1)0.3)
graph save 3, replace
graph hbar (mean) poolchange if grouppooldiff==1 & end==1, over(ioname, sort (poolchange) descending)ylabel(0(0.1)0.7)
graph save 4, replace
graph combine 4.gph 3.gph, graphregion(fcolor(white))

sort pooldiff_end
list ioname pooling pooldiff_end if end==1, noobs clean

**********************************************************************
*Figure 6.5: Change in majority voting in 76 IOs
**********************************************************************
/*use do file pooling_descriptives*/
use "MASTER_june2018_FINAL.dta"

**************** finding out which IOs have an assembly with majority state rep
gen init_end=1 if initial==1
replace init_end=2 if end==1

gen ACC16_B=1 if (ACC16b_A1!=. &  ACC16b_A1>0) & A1_1d<0.50 & A1_1d<. 
tab ACC16_B
replace ACC16_B=1 if (ACC16b_A2!=. & ACC16b_A2>0) &  A2_1d<0.50 & A2_1d<.
tab ACC16_B
replace ACC16_B=1 if (ACC16b_A3!=. & ACC16b_A3>0) & A3_1d<0.50 & A3_1d<.
tab ACC16_B
replace ACC16_B=1 if (ACC16b_E1!=. &  ACC16b_E1>0) & E1_8d<0.50 & E1_8d<. 
tab ACC16_B
replace ACC16_B=1 if (ACC16b_E2!=. &  ACC16b_E2>0) & E2_8d<0.50 & E2_8d<. 
tab ACC16_B
replace ACC16_B=1 if (ACC16b_E3!=. &  ACC16b_E3>0) & E3_8d<0.50 & E3_8d<. 
tab ACC16_B
replace ACC16_B=0 if ACC16_B==.

 tab init_end ACC16_B

gen SUSP18_B=1 if (SUSP18b_A1!=. &  SUSP18b_A1>0) & A1_1d<0.50 & A1_1d<. 
tab SUSP18_B
replace SUSP18_B=1 if (SUSP18b_A2!=. & SUSP18b_A2>0) &  A2_1d<0.50 & A2_1d<.
tab SUSP18_B
replace SUSP18_B=1 if (SUSP18b_A3!=. & SUSP18b_A3>0) & A3_1d<0.50 & A3_1d<.
tab SUSP18_B
replace SUSP18_B=1 if (SUSP18b_E1!=. &  SUSP18b_E1>0) & E1_8d<0.50 & E1_8d<. 
tab SUSP18_B
replace SUSP18_B=1 if (SUSP18b_E2!=. &  SUSP18b_E2>0) & E2_8d<0.50 & E2_8d<. 
tab SUSP18_B
replace SUSP18_B=1 if (SUSP18b_E3!=. &  SUSP18b_E3>0) & E3_8d<0.50 & E3_8d<. 
tab SUSP18_B
replace SUSP18_B=0 if SUSP18_B==.

tab init_end SUSP18_B

gen CON19_B=1 if (CON19b_A1!=. &  CON19b_A1>0) & A1_1d<0.50 & A1_1d<. 
tab CON19_B
replace CON19_B=1 if (CON19b_A2!=. & CON19b_A2>0) &  A2_1d<0.50 & A2_1d<.
tab CON19_B
replace CON19_B=1 if (CON19b_A3!=. & CON19b_A3>0) & A3_1d<0.50 & A3_1d<.
tab CON19_B
replace CON19_B=1 if (CON19b_E1!=. &  CON19b_E1>0) & E1_8d<0.50 & E1_8d<. 
tab CON19_B
replace CON19_B=1 if (CON19b_E2!=. &  CON19b_E2>0) & E2_8d<0.50 & E2_8d<. 
tab CON19_B
replace CON19_B=1 if (CON19b_E3!=. &  CON19b_E3>0) & E3_8d<0.50 & E3_8d<. 
tab CON19_B
replace CON19_B=0 if CON19_B==.

. tab init_end CON19_B

gen BUD22_B=1 if (BUD22b_A1!=. &  BUD22b_A1>0) & A1_1d<0.50 & A1_1d<. 
tab BUD22_B
replace BUD22_B=1 if (BUD22b_A2!=. & BUD22b_A2>0) &  A2_1d<0.50 & A2_1d<.
tab BUD22_B
replace BUD22_B=1 if (BUD22b_A3!=. & BUD22b_A3>0) & A3_1d<0.50 & A3_1d<.
tab BUD22_B
replace BUD22_B=1 if (BUD22b_E1!=. &  BUD22b_E1>0) & E1_8d<0.50 & E1_8d<. 
tab BUD22_B
replace BUD22_B=1 if (BUD22b_E2!=. &  BUD22b_E2>0) & E2_8d<0.50 & E2_8d<. 
tab BUD22_B
replace BUD22_B=1 if (BUD22b_E3!=. &  BUD22b_E3>0) & E3_8d<0.50 & E3_8d<. 
tab BUD22_B
replace BUD22_B=0 if BUD22_B==.

. tab init_end BUD22_B

gen COM24_B=1 if (COM24b_A1!=. &  COM24b_A1>0) & A1_1d<0.50 & A1_1d<. 
tab COM24_B
replace COM24_B=1 if (COM24b_A2!=. & COM24b_A2>0) &  A2_1d<0.50 & A2_1d<.
tab COM24_B
replace COM24_B=1 if (COM24b_A3!=. & COM24b_A3>0) & A3_1d<0.50 & A3_1d<.
tab COM24_B
replace COM24_B=1 if (COM24b_E1!=. &  COM24b_E1>0) & E1_8d<0.50 & E1_8d<. 
tab COM24_B
replace COM24_B=1 if (COM24b_E2!=. &  COM24b_E2>0) & E2_8d<0.50 & E2_8d<. 
tab COM24_B
replace COM24_B=1 if (COM24b_E3!=. &  COM24b_E3>0) & E3_8d<0.50 & E3_8d<. 
tab COM24_B
replace COM24_B=0 if COM24_B==.

tab init_end COM24_B

gen PM25_B=1 if (PM1_25b_A1!=. &  PM1_25b_A1>0) & A1_1d<0.50 & A1_1d<. 
replace PM25_B=1 if (PM1_25b_A2!=. & PM1_25b_A2>0) &  A2_1d<0.50 & A2_1d<.
replace PM25_B=1 if (PM1_25b_A3!=. & PM1_25b_A3>0) & A3_1d<0.50 & A3_1d<.
replace PM25_B=1 if (PM1_25b_E1!=. &  PM1_25b_E1>0) & E1_8d<0.50 & E1_8d<. 
replace PM25_B=1 if (PM1_25b_E2!=. &  PM1_25b_E2>0) & E2_8d<0.50 & E2_8d<. 
replace PM25_B=1 if (PM1_25b_E3!=. &  PM1_25b_E3>0) & E3_8d<0.50 & E3_8d<. 
replace PM25_B=1 if (PM2_25b_A1!=. &  PM2_25b_A1>0) & A1_1d<0.50 & A1_1d<. 
replace PM25_B=1 if (PM2_25b_A2!=. & PM2_25b_A2>0) &  A2_1d<0.50 & A2_1d<.
replace PM25_B=1 if (PM2_25b_A3!=. & PM2_25b_A3>0) & A3_1d<0.50 & A3_1d<.
replace PM25_B=1 if (PM2_25b_E1!=. &  PM2_25b_E1>0) & E1_8d<0.50 & E1_8d<. 
replace PM25_B=1 if (PM2_25b_E2!=. &  PM2_25b_E2>0) & E2_8d<0.50 & E2_8d<. 
replace PM25_B=1 if (PM2_25b_E3!=. &  PM2_25b_E3>0) & E3_8d<0.50 & E3_8d<. 
replace PM25_B=1 if (PM3_25b_A1!=. &  PM3_25b_A1>0) & A1_1d<0.50 & A1_1d<. 
replace PM25_B=1 if (PM3_25b_A2!=. & PM3_25b_A2>0) &  A2_1d<0.50 & A2_1d<.
replace PM25_B=1 if (PM3_25b_A3!=. & PM3_25b_A3>0) & A3_1d<0.50 & A3_1d<.
replace PM25_B=1 if (PM3_25b_E1!=. &  PM3_25b_E1>0) & E1_8d<0.50 & E1_8d<. 
replace PM25_B=1 if (PM3_25b_E2!=. &  PM3_25b_E2>0) & E2_8d<0.50 & E2_8d<. 
replace PM25_B=1 if (PM3_25b_E3!=. &  PM3_25b_E3>0) & E3_8d<0.50 & E3_8d<. 
replace PM25_B=1 if (PM4_25b_A1!=. &  PM4_25b_A1>0) & A1_1d<0.50 & A1_1d<. 
replace PM25_B=1 if (PM4_25b_A2!=. & PM4_25b_A2>0) &  A2_1d<0.50 & A2_1d<.
replace PM25_B=1 if (PM4_25b_A3!=. & PM4_25b_A3>0) & A3_1d<0.50 & A3_1d<.
replace PM25_B=1 if (PM4_25b_E1!=. &  PM4_25b_E1>0) & E1_8d<0.50 & E1_8d<. 
replace PM25_B=1 if (PM4_25b_E2!=. &  PM4_25b_E2>0) & E2_8d<0.50 & E2_8d<. 
replace PM25_B=1 if (PM4_25b_E3!=. &  PM4_25b_E3>0) & E3_8d<0.50 & E3_8d<. 
replace PM25_B=1 if (PM5_25b_A1!=. &  PM5_25b_A1>0) & A1_1d<0.50 & A1_1d<. 
replace PM25_B=1 if (PM5_25b_A2!=. & PM5_25b_A2>0) &  A2_1d<0.50 & A2_1d<.
replace PM25_B=1 if (PM5_25b_A3!=. & PM5_25b_A3>0) & A3_1d<0.50 & A3_1d<.
replace PM25_B=1 if (PM5_25b_E1!=. &  PM5_25b_E1>0) & E1_8d<0.50 & E1_8d<. 
replace PM25_B=1 if (PM5_25b_E2!=. &  PM5_25b_E2>0) & E2_8d<0.50 & E2_8d<. 
replace PM25_B=1 if (PM5_25b_E3!=. &  PM5_25b_E3>0) & E3_8d<0.50 & E3_8d<. 
replace PM25_B=0 if PM25_B==.

. tab init_end PM25_B


gen majvote= ACC16_B + SUSP18_B + CON19_B + BUD22_B + COM24_B + PM25_B

. tabstat majvote, stats (p50 mean) by (init_end)

**graphing # IOs with majority voting in one of six areas (Figure 6.5)
graph hbar (sum) ACC16_B SUSP18_B CON19_B BUD22_B COM24_B PM25_B, over(init_end)


*******************************************************************************************************
*TABLE 6.1: Change in bindingness and ratification in 76 IOs
*******************************************************************************************************
use "do file pooling_descriptives"
use "\dp_components.dta"

****policy making, budget (top rows of table)
gen bindingpolicy1=2 if (PM1_26==2 & PM1_27!=0 & PM1_27!=1) | (PM2_26==2 & PM2_27!=0 & PM2_27!=1)| (PM3_26==2 & PM3_27!=0 & PM3_27!=1)| (PM4_26==2 & PM4_27!=0 & PM4_27!=1)| (PM5_26==2 & PM5_27!=0 &PM5_27!=1)
replace bindingpolicy1=1 if bindingpolicy1!=2 & ((PM1_26==1 & PM1_27!=0) | (PM2_26==1 & PM2_27!=0)| (PM3_26==1 & PM3_27!=0)| (PM4_26==1 & PM4_27!=0)| (PM5_26==1& PM5_27!=0))
replace bindingpolicy1=0 if (bindingpolicy1!=2 & bindingpolicy1!=1)
tab bindingpolicy1 init_end, column

. tab bindingpolicy init_end, column

+-------------------+
| Key               |
|-------------------|
|     frequency     |
| column percentage |
+-------------------+

  
bindingpol |    1=initial 2=end
      icy1 |   initial        end |     Total
-----------+----------------------+----------
         0 |        26         20 |        46 
           |     34.21      26.32 |     30.26 
-----------+----------------------+----------
         1 |        28         28 |        56 
           |     36.84      36.84 |     36.84 
-----------+----------------------+----------
         2 |        22         28 |        50 
           |     28.95      36.84 |     32.89 
-----------+----------------------+----------
     Total |        76         76 |       152 
           |    100.00     100.00 |    100.00 

 
gen bindingbudget=BUD23
replace bindingbudget=0 if BUD23==98|BUD23==99
tab bindingbudget init_end, column
. tab bindingbudget init_end, column

+-------------------+
| Key               |
|-------------------|
|     frequency     |
| column percentage |
+-------------------+

bindingbud |    1=initial 2=end
       get |   initial        end |     Total
-----------+----------------------+----------
         0 |        21          4 |        25 
           |     27.63       5.26 |     16.45 
-----------+----------------------+----------
         1 |         6          7 |        13 
           |      7.89       9.21 |      8.55 
-----------+----------------------+----------
         2 |        49         65 |       114 
           |     64.47      85.53 |     75.00 
-----------+----------------------+----------
     Total |        76         76 |       152 
           |    100.00     100.00 |    100.00 

graph hbar (count), over(bindingbudget) over(init_end) asyvars stack scheme (s1manual)
graph hbar (count), over(bindingpolicy) over(init_end) asyvars stack scheme (s1manual)

*************
**incidence of ratification (bottom rows of table)
gen constitrat= CON20
replace constitrat=0 if CON20==98| CON20==99| CON20==.
tab  init_end constitrat, row


 1=initial |                 constitrat
     2=end |         0          1          2          3 |     Total
-----------+--------------------------------------------+----------
   initial |        36         13         14         13 |        76 
           |     47.37      17.11      18.42      17.11 |    100.00 
-----------+--------------------------------------------+----------
       end |        32         16         17         11 |        76 
           |     42.11      21.05      22.37      14.47 |    100.00 
-----------+--------------------------------------------+----------
     Total |        68         29         31         24 |       152 
           |     44.74      19.08      20.39      15.79 |    100.00 

gen accessrat= ACC17
replace accessrat=0 if ACC17==99|ACC17==98. 

tab  init_end accessrat , row
 1=initial |       accessrat
     2=end |         0          2 |     Total
-----------+----------------------+----------
   initial |        27         49 |        76 
           |     35.53      64.47 |    100.00 
-----------+----------------------+----------
       end |        18         58 |        76 
           |     23.68      76.32 |    100.00 
-----------+----------------------+----------
     Total |        45        107 |       152 
           |     29.61      70.39 |    100.00 

gen polirat=PM1_27 if (PM1_26==1| PM1_26==2)
replace polirat=PM2_27 if PM2_27> PM1_27 & (PM2_26==1| PM2_26==2)
replace polirat=0 if polirat==.
replace polirat=PM3_27 if PM3_27> polirat & (PM3_26==1| PM3_26==2)
replace polirat=PM4_27 if PM4_27> polirat & (PM4_26==1| PM4_26==2)
replace polirat=PM5_27 if PM5_27> polirat & (PM5_26==1| PM5_26==2)

. tab  init_end polirat , row

 1=initial |                   polirat
     2=end |         0          1          2          3 |     Total
-----------+--------------------------------------------+----------
   initial |        28          8          1         39 |        76 
           |     36.84      10.53       1.32      51.32 |    100.00 
-----------+--------------------------------------------+----------
       end |        23          7          0         46 |        76 
           |     30.26       9.21       0.00      60.53 |    100.00 
-----------+--------------------------------------------+----------
     Total |        51         15          1         85 |       152 
           |     33.55       9.87       0.66      55.92 |    100.00 



*********************************NEW VARIABLES FOR ANALYSIS
************************************************************
(**) various
gen yearc=year-2010+1
gen yearcc=year-1950+1
gen gdpmean1000=gdpmean/1000

(A) POLITICIZATION
*New politicization data from Kai Stern
/* politicization=raw numbers of mentions in LexisNexus*/
*divide by 100 to get more readable numbers

tsset ionumber year

gen politmoving3=(politicization+l1.politicization+l2.politicization)/ 3
gen politmoving300= politmoving3/100


****************************************
(B) CORE STATE POWERS
/* control: IOs that deal with core state powers have less demand for delegation or pooling*/

///*FOLLOW DEFINITION OF Genschel and Jachtenfuchs for corestate and market*/
/* MARKET= Economic External Relations; Environmental &Consumer Protection; Occupational Health; Labour; R&D; Economic 
Freedoms; Competition & Industry; Energy & Transport; Agriculture; Social & Territorial Cohesion*/
/*CORE STATE = External political relations (defense); money; taxation; employment; criminal and domestic security*/
*(a): minimal and maximal definition using our core powers
gen corestate1=1 if justice==2| migration==2| military==2| currency_bank==2 /*restrictive*/
replace corestate1=0 if core1==.

gen corestate2=1 if justice==2| migration==2| military==2| currency_bank==2| welfare==2| taxation==2| foreign==2 /*liberal -- USE THIS ONE IN CHIEF ANALYSIS*/
replace corestate2=0 if core2==.

/*(b): alternative calculation using proportion*/ 
gen corestate1prop=1 if justice==2
replace corestate1prop=corestate1prop+1 if migration==2
replace corestate1prop=corestate1prop+1 if military==2
replace corestate1prop=corestate1prop+1 if currency_bank==2
replace corestate1prop=0 if corestate1prop==.
replace corestate1prop=corestate1prop/scope

gen corestate2prop=1 if justice==2
replace corestate2prop=corestate2prop+1 if migration==2
replace corestate2prop=corestate2prop+1 if military==2
replace corestate2prop=corestate2prop+1 if currency_bank==2
replace corestate2prop=corestate2prop+1 if welfare==2
replace corestate2prop=corestate2prop+1 if taxation==2
replace corestate2prop=corestate2prop+1 if foreign==2
replace corestate2prop=0 if corestate2prop==.
replace corestate2prop=corestate2prop/scope

/* (c): maximal definition using primary policy*/
gen corestate3=1 if k_6==1| k_11==1| k_17==1| k_18==1| k_19==1| k_22==1
replace corestate3=0 if corestate3==.

/* (d): primary policy, but take out BIS, OECD, PCA because they are chiefly regulatory, and Comsec, ASEAN, AMU, and SAARC because they are chiefly confidence building*/
gen corestate4=1 if k_6==1| k_11==1| k_17==1| k_18==1| k_19==1| k_22==1
replace corestate4=0 if corestate==.
replace corestate4=0 if ioname=="BIS"| ioname=="OECD"| ioname=="PCA"| ioname=="ASEAN"| ioname=="SAARC"| ioname=="ComSec"

**********************************************************************************************************************************************
*Table 6.2: explaining change in delegation and pooling* [APPENDIX SHOWS FULL CONTROLS in B.12+ MODELS WITHOUT YEAR COUNT and with polynomial] 
***********************************************************************************************************************************************

xtreg f.delegation scope politmoving300 politymean members_log capabilities1 gdpmean1000 gdpcov corestate2 yearcc, fe vce (cl ionumber) /*model 1*/
fp <yearcc>: xtreg f.delegation scope politmoving300 politymean members_log capabilities1 gdpmean1000 gdpcov corestate2 <yearcc>, fe vce (cl ionumber) /*APPENDIX model 3*/

estat ic
margins, at (scope=(1(1)24))
marginsplot
margins, atmeans at (politmoving300=(0(.4)6))


xtreg f.delegation scope politmoving300 politymean members_log capabilities1 gdpmean1000 gdpcov corestate2 , fe vce (cl ionumber) /*APPENDIX model 2*/
estat ic

xtreg f.pooling scope politmoving300 politymean members_log capabilities1 gdpmean1000 gdpcov corestate2 yearcc, fe vce (cl ionumber) /*model 2*/
fp <yearcc>: xtreg f.pooling scope politmoving300 politymean members_log capabilities1 gdpmean1000 gdpcov corestate2 <yearcc>, fe vce (cl ionumber) /*model 3 APPENDIX*/
estat ic
margins, atmeans at (scope=(1(1)24))
marginsplot

xtreg f.pooling scope politmoving300 politymean members_log capabilities1 gdpmean1000 gdpcov corestate2, fe vce (cl ionumber) /*APPENDIX*/
estat ic

*note: corestate2=all Genschel & Jachtenfuchs policies; dichotomy; no adjustment for appropriation*

xtreg f.pooling c.scope##i.corestate2 politmoving300 politymean members_log capabilities1 gdpmean1000 yearcc, fe vce (cl ionumber)/*model 3*/
estat ic

xtreg f.pooling c.scope##i.corestate2 politmoving300 politymean members_log capabilities1 gdpmean1000, fe vce (cl ionumber) /*model4 in appe */
estat ic

PS. hausman test suggests fe appropriate
**Hausman for entire equation
xtreg f.delegation c.scope##i.corestate2 politmoving300 politymean capabilities1 members_log gdpmean1000 yearc, fe 
estimates store fixed
xtreg f.delegation c.scope##i.corestate2 politmoving300 politymean capabilities1 members_log gdpmean1000  yearc, re 
estimates store random
hausman fixed random
*FAILS the Hausman test
xtreg f.pooling c.scope##i.corestate2 politmoving300 politymean capabilities1 members_log gdpmean1000 yearc, fe 
estimates store fixed
xtreg f.pooling c.scope##i.corestate2 politmoving300 politymean capabilities1 members_log gdpmean1000  yearc, re 
estimates store random
hausman fixed random
*[does not converge]*

*******************************************************************************************
*Table 6.3: two-stage instrumental model
*******************************************************************************************
**two-stage model that substitutes scope with contract and community (APPENDIX SHOWS FIRST STAGE + SECOND STAGE + FULL CONTROLS)
xtivreg f.delegation politmoving300 politymean capabilities1 members_log gdpmean1000 gdpcov corestate2 yearcc (scope=contractdynamic commundynamic), fe first 
xtivreg2 f.delegation politmoving300 politymean capabilities1 members_log gdpmean1000 gdpcov corestate2 yearcc (scope=contractdynamic commundynamic), fe first cl (ionumber) /*model 1*/
xtivreg2 f.pooling politmoving300 politymean capabilities1 members_log gdpmean1000 gdpcov corestate2  yearcc (scope=contractdynamic commundynamic), fe first cl (ionumber) /*model 2*/
estat ic

********************************************************************************************
/*ONLINE APPENDIX: full controls for table 6.2 and 6.3 + episteme+ core state powers + heterogeneity*/
********************************************************************************************

*full controls: see above
**************************************************
*Tables for episteme
**************************************************
/*(a) Table B.19: Average politicization for epistemic and non-epistemic IOs*/
mean politmoving300 politicization scope pooling, over(episteme) vce (cl ionumber)
mean politmoving300 politicization scope pooling if ioname!="IBRD", over(episteme) vce (cl ionumber) /*takes out the extreme case*/
mean politmoving300 politicization scope pooling if year>1989, over(episteme) vce (cl ionumber)
mean politmoving300 politicization scope pooling if ioname!="IBRD" & year>1989, over(episteme) vce (cl ionumber)
mean politmoving300 politicization scope pooling if year>2005, over(episteme) vce (cl ionumber)
mean politmoving300 politicization scope pooling if ioname!="IBRD" & year>2005, over(episteme) vce (cl ionumber)

/*(b)Politicization and epistemic (Table B.20*/
xtreg f.delegation scope c.politmoving300#i.episteme politymean members_log capabilities1 gdpmean1000 gdpcov corestate2 yearcc, fe vce (cl ionumber) /*model 1*/
estat ic
margins, at (politmoving300=(0(.3)5.6) episteme=(0(1)1))
marginsplot, noci
xtreg f.pooling scope c.politmoving300#i.episteme politymean members_log capabilities1 gdpmean1000 gdpcov corestate2 yearcc, fe vce (cl ionumber)/*model 2*/
margins, at (politmoving300=(0(.3)5.6) episteme=(0(1)1))
marginsplot, noci
estat ic

*********************************************************************************
*Table B.16, B.17 Tables of core state powers: explaining delegation and pooling  
***********************************************************************************
xtreg f.delegation c.scope##i.corestate2 politmoving300 politymean members_log capabilities1 gdpmean1000 gdpcov yearcc, fe vce (cl ionumber) /*model 1a*/
estat ic
xtreg f.pooling c.scope##i.corestate2 politmoving300 politymean members_log capabilities1 gdpmean1000 gdpcov yearcc, fe vce (cl ionumber)/*model 1b*/
estat ic

xtreg f.delegation c.scope##c.corestate2prop politmoving300 politymean members_log capabilities1 gdpmean1000 gdpcov yearcc, fe vce (cl ionumber) /*model 2a*/
estat ic
margins, at (scope=(1(2)24) corestate2prop=(0(.5)1))
marginsplot, noci
xtreg f.pooling c.scope##c.corestate2prop politmoving300 politymean members_log capabilities1 gdpmean1000 gdpcov yearcc, fe vce (cl ionumber)/*model 2b*/
estat ic

xtreg f.delegation c.scope##i.corestate3 politmoving300 politymean members_log capabilities1 gdpmean1000 gdpcov yearcc, fe vce (cl ionumber) /*model 3a*/
estat ic
margins, at (scope=(0 (2) 24) corestate3= (0 (1) 1))
xtreg f.pooling c.scope##i.corestate3 politmoving300 politymean members_log capabilities1 gdpmean1000 gdpcov yearcc, fe vce (cl ionumber)/*model 3b*/
estat ic

xtreg f.delegation c.scope##i.corestate4 politmoving300 politymean members_log capabilities1 gdpmean1000 gdpcov yearcc, fe vce (cl ionumber) /*model 4a*/
estat ic
xtreg f.pooling c.scope##c.corestate4 politmoving300 politymean members_log capabilities1 gdpmean1000 gdpcov yearcc, fe vce (cl ionumber)/*model 4b*/
estat ic
margins, at (scope=(1 (2) 23) corestate4= (0 (1) 1))
marginsplot, noci

***********************************************************************************
*Table B.21: Geopolitical convergence and international authority
***********************************************************************************
gen idealdistmeanr=idealdistmean-.0026667
tabstat idealdistmeanr, stat (mean p50 min max sd)
replace idealdistmeanr=idealdistmean/2.344666
tabstat idealdistmeanr, stats (min max mean)
gen idealproxr=1-idealdistmeanr

xtreg f.delegation idealproxr typeI, fe vce (cl ionumber)
xtreg f.delegation c.idealproxr##i.typeI, fe vce (cl ionumber)
estat ic
xtreg f.delegation c.idealproxr##i.typeI politmoving300 politymean members_log capabilities1 gdpmean1000 gdpcov yearcc, fe vce (cl ionumber)
estat ic
xtreg f.delegation idealproxr scope politmoving300 politymean members_log capabilities1 gdpmean1000 gdpcov yearcc, fe vce (cl ionumber)
estat ic
xtreg f.pooling c.idealproxr##i.typeI, fe vce (cl ionumber)
estat ic
xtreg f.pooling c.idealproxr##i.typeI politmoving300 politymean members_log capabilities1 gdpmean1000 gdpcov yearcc, fe vce (cl ionumber)
estat ic
xtreg f.pooling idealproxr scope politmoving300 politymean members_log capabilities1 gdpmean1000 gdpcov yearcc, fe vce (cl ionumber)
estat ic

tabstat idealproxr, stats (sd min max mean)
. tabstat idealproxr, stats (sd min max mean)

    variable |        sd       min       max      mean
-------------+----------------------------------------
  idealproxr |  .1771753 -.0011376  .9988627  .6969075
------------------------------------------------------

xtreg f.delegation c.idealproxr##i.typeI politmoving300 politymean members_log capabilities1 gdpmean1000 gdpcov yearcc, fe vce (cl ionumber)
estat ic
margins, at (idealproxr=(0(0.1)1) typeI=(0(1)1))
margins, at (idealproxr=(0(0.1772)1))

***********************************************************************************
*Figure B.3: Figure B.3: Marginal effects of geopolitical convergence by type of IO

************************************************************************************
xtreg f.delegation c.idealproxr##i.typeI politmoving300 politymean members_log capabilities1 gdpmean1000 gdpcov yearcc, fe vce (cl ionumber)
estat ic
margins, at (idealproxr=(0(0.1)1) typeI=(0(1)1))
marginsplot


*Table B.22: Trade interdependence and international authority

xtreg f.deleagation 
xtreg f.delegation symtradeintrov1 if regional1==1 & trade2==1 & year>1969, fe vce (cl ionumber)
estat ic
xtreg f.pooling symtradeintrov1 if regional1==1 & trade2==1 & year>1969, fe vce (cl ionumber)
estat ic

xtreg f.delegation symtradeintrov1 politymean members_log capabilities1 gdpmean1000 gdpcov yearcc if regional1==1 & trade2==1 & year>1969, fe vce (cl ionumber)
estat ic
xtreg f.pooling symtradeintrov1 politymean members_log capabilities1 gdpmean1000 gdpcov yearcc if regional1==1 & trade2==1 & year>1969, fe vce (cl ionumber)
estat ic
tabstat symtradeintrov1 if , stats (sd min max)

xtreg f.delegation symtradeintrov1 scope politmoving300 politymean members_log capabilities1 gdpmean1000 gdpcov yearcc if regional1==1 & trade2==1 & year>1969, fe vce (cl ionumber)
estat ic
xtreg f.pooling symtradeintrov1 scope politmoving300 politymean members_log capabilities1 gdpmean1000 gdpcov yearcc if regional1==1 & trade2==1 & year>1969, fe vce (cl ionumber)
estat ic

xtreg f.pooling symtradeintrov1 scope politmoving300 politymean members_log capabilities1 gdpmean1000 gdpcov yearcc if regional1==1 & trade2==1 & year>1969, fe vce (jack)
estat ic
xtreg f.pooling symtradeintrov1 scope politmoving300 politymean members_log capabilities1 gdpmean1000 gdpcov yearcc if ioname!="EU" & regional1==1 & trade2==1 & year>1969, fe vce (cl ionumber)
estat ic
tabstat members_log members, stats (sd)
. tabstat members_log members, stats (min max mean sd)

   stats |  member~g   members
---------+--------------------
     min |    .30103         3
     max |  2.283301       192
    mean |  1.433145  54.78949
      sd |  .5531837  58.62535
------------------------------

 
margins, at (members_log=(.3(.3)2.24))
margins, at (members_log=(0.77815 1.44716))

