*     *****************************************************************
*     ***************************************************************** 
* 		File-Name:      replication_VolIV_appendix.do       	                 
*   	Date:           May 2020                                 
*     	Author:         LH                                         
*     	Purpose:        Create tables and figures for Appendix 
*    	Input File:     mostly: "INDEP_aug.2018.dta"                                            
*     	Output File:    various			                         
*     	Data Output:    various                                            
*     	Previous file:  None                                            
*     	Machine:        	                                      
*     ****************************************************************  
*     ****************************************************************  
***NOTE TO USER: statistics produced by using the most recent dataset diverge slightly from those in the book//
*because we corrected minor errors and, in the DP_volIII file, added scores for the International Coffee Organization (ICO) and EURAMET

use "DP_volIII_aug2018.dta",clear // or latest version
or use "INDEP_replication.data"

			***********************************
			***********************************
				/*PART ONE: OPERATIONALIZATION*/
			***********************************
			***********************************

***************************
*Table A.1: Operationalization of the variables
***************************
see book


***************************
*Table A.2: descriptives
***************************
or use "INDEP_replication.data"
drop if year>2010
tabstat delegation pooling scope gdpmean community8 contract core corestate2 politymean members_ch episteme gdpcov historical_ties4 historical_ties3 idealdistmean members members_log politmoving3 scope_ch capabilities1 secdummy trade2, stats (mean p50 cv min max N)
/*note: some of these variables are created below -- so better to run after do file*/
/*smaller population for trade variables*/
tabstat  intratradeintens1 intratradeshare1 symtradeintrov1 intratradeintens4 intratradeshare4 symtradeintrov4 if regional1==1 & year>1969 & symtradeintrov1!=., stats (mean p50 cv min max p25 p75 N)

****************************
*Table A.3: IO population in MIA
*****************************


			***********************************
			***********************************
				/*PART TWO: VARIABLES*/
			***********************************
			***********************************

********************************************************
//*DEPENDENT VARIABLES: INTERNATIONAL AUTHORITY DELEGATION AND POOLING*//
********************************************************
(if using "DP_volIII_aug2018.dta" drop year>2010)
 use "INDEP_replication.data"
*Table A.4: Factor analysis
. pca delaccess delsuspens delconstit delbudget delfincompl delpolicy ///
poolaccess poolsuspens poolconstit poolcompliance poolbudget poolpolicy, components(2) 


. rotate, promax

P
Principal components/correlation                 Number of obs    =      3,292
                                                 Number of comp.  =          2
                                                 Trace            =         12
    Rotation: oblique promax (Kaiser off)        Rho              =     0.6176

    --------------------------------------------------------------------------
       Component |     Variance   Proportion     Rotated comp. are correlated
    -------------+------------------------------------------------------------
           Comp1 |      4.30855       0.3590
           Comp2 |      3.05933       0.2549
    --------------------------------------------------------------------------

Rotated components 

    ------------------------------------------------
        Variable |    Comp1     Comp2 | Unexplained 
    -------------+--------------------+-------------
       delaccess |   0.4207   -0.0345 |       .2551 
      delsuspens |   0.3793    0.0436 |       .3345 
      delconstit |   0.4394   -0.0305 |       .1834 
       delbudget |   0.4131   -0.0267 |        .277 
     delfincompl |   0.3428    0.0632 |       .4321 
       delpolicy |   0.4215   -0.0220 |       .2438 
      poolaccess |   0.0027    0.4268 |       .4319 
     poolsuspens |   0.0600    0.3761 |       .4996 
     poolconstit |  -0.0078    0.4065 |       .4931 
    poolcompli~e |   0.0218    0.4691 |       .2938 
      poolbudget |  -0.1266    0.4398 |       .4418 
      poolpolicy |   0.0281    0.2985 |       .7029 
    ------------------------------------------------

Component rotation matrix

    ----------------------------------
                 |    Comp1     Comp2 
    -------------+--------------------
           Comp1 |   0.8789    0.4542 
           Comp2 |  -0.4777    0.8913 
    ----------------------------------

*TABLE A.5: Correlation matrix: 
use "INDEP_replication.dta", clear
 *DELEGATION
pca delaccess delsuspens delconstit delbudget delfincompl delpolicy, components(1) 
predict pca_d
alpha delaccess delsuspens delconstit delbudget delfincompl delpolicy, s gen (alpha_d)
correl delegation pca_d alpha_d
*POOLING
pca poolaccess poolsuspens poolconstit poolcompliance poolbudget poolpolicy , components(1) 
predict pca_p
alpha poolaccess poolsuspens poolconstit poolcompliance poolbudget poolpolicy, s gen (alpha_p)
correl pooling pca_p alpha_p
correl delegation alpha_d pca_d alpha_p pooling pca_p 

. correl delegation alpha_d pca_d alpha_p pooling pca_p 
(obs=3,292)

             | delega~n  alpha_d    pca_d  alpha_p  pooling    pca_p
-------------+------------------------------------------------------
  delegation |   1.0000
     alpha_d |   0.9989   1.0000
       pca_d |   0.9991   0.9998   1.0000
     alpha_p |   0.2533   0.2586   0.2556   1.0000
     pooling |   0.2435   0.2487   0.2458   0.9968   1.0000
       pca_p |   0.2541   0.2593   0.2562   0.9983   0.9971   1.0000


 
*TABLE A.6 AND A.7: Descriptive stats
tabstat delaccess delsuspens delconstit ///
delbudget delfincompl delpolicy del_agenda del_final DS_sum_st delegation, stats ///
(mean p50 cv min max p25 p75 N)

   stats |  delacc~s  delsus~s  delcon~t  delbud~t  delfin~l  delpol~y  del_ag~a  del_fi~l  DS_sum~t  delega~n
---------+----------------------------------------------------------------------------------------------------
    mean |  .1399844  .1085867  .1277466  .3182072  .1323139    .27019  .2311362  .0466353  .2707429  .1828381
     p50 |  .1428571  .1190476  .1190476  .3333333  .1428571  .2539683  .2083333         0  .2857143  .1746032
      cv |  1.143611  1.128947  1.128834  .6264772  1.135962  .6403357  .6422605  2.301416  1.080503  .7300585
     min |         0         0         0         0         0         0         0         0         0         0
     max |  .7777778  .6428571  .6444445         1  .6666667  .9333333     .7075       .55         1  .6519957
     p25 |         0         0         0  .1666667         0  .1666667  .1388889         0         0  .0611111
     p75 |  .1904762  .1666667  .1666667  .4433333  .1785714  .3644444  .3333333         0        .5  .2592593
       N |      3292      3292      3292      3292      3292      3292      3292      3292      3292      3292
--------------------------------------------------------------------------------------------------------------


tabstat poolaccess poolsuspens poolconstit ///
poolbudget poolcompliance poolpolicy poolagenda poolfinal pooling, stats ///
(mean p50 cv min max p25 p75)

   stats |  poolac~s  poolsu~s  poolco~t  poolbu~t  poolco~e  poolpo~y  poolag~a  poolfi~l   pooling
---------+------------------------------------------------------------------------------------------
    mean |  .3536915  .1691411  .2001162   .441782  .2988685   .311575  .2526288  .3380769  .2953528
     p50 |       .33         0      .165       .33      .165       .25    .22125  .3041667  .2916667
      cv |   .693368  1.512748  .9848022  .7148807  1.099225  .6911729  .7491836  .6174427  .6309413
     min |         0         0         0         0         0         0         0         0         0
     max |         1         1       .75         1         1         1  .7491667       .79  .7283334
     p25 |      .125         0    .04125      .165         0      .165  .0833333    .17875     .1375
     p75 |        .5       .33       .33       .66       .58      .375      .375  .5397917  .4472917
----------------------------------------------------------------------------------------------------



outreg2 using del.doc, replace sum(log) keep(delaccess delsuspens delconstit ///
delbudget delfincompl delpolicy del_agenda del_final DS_sum_st delegation) dec(3)

outreg2 using DP_volIII_sept2017, replace sum(log) keep( poolaccess poolsuspens poolconstit ///
poolbudget poolcompliance  poolpolicy poolagenda poolfinal pooling) dec(3)

**Keep only the variables you need for each table, otherwise matsize error message
*keep delaccess delsuspens delconstit delbudget delfincompl delpolicy  del_agenda  del_final DS_sum_st delegation
outreg2 using xxx1.doc, replace sum(detail) eqkeep(mean p50 cv min max p25 p75) dec(3)
*keep poolaccess poolconstit poolsuspens poolcompliance poolbudget poolpolicy poolagenda poolfinal pooling
outreg2 using xxx1.doc, replace sum(detail) eqkeep(mean p50 cv min max p25 p75) dec(3)


*********************
/*POLICY SCOPE*/
*********************

*Table A.8: policy categories*

use: "INDEP_replication.dta"
*Table A.9*
tabstat scope core flank, stats (mean p50 cv min max p25 p75)

   stats |     scope      core     flank
---------+------------------------------
    mean |  5.688943  2.002126  3.685298
     p50 |         3         2         2
      cv |   .874456  .6422193  1.072225
     min |         1         1         0
     max |        24        10        16
     p25 |         2         1         1
     p75 |         9         3         6
----------------------------------------


use: "INDEP_replication.dta"
collapse (mean) scope core flank if data51==1, by(year)
save "scope51.dta"
use "INDEP_replication.dta", clear
egen number = count(ionumber), by(year) //generate count variable for number of IO for each year
collapse (mean) scope core flank number, by(year)
collapse (mean) number, by(year)
rename scope scope_all
rename core core_all
rename flank flank_all
save "scopeall.dta"
merge 1:1 year using "scope51.dta", keepusing(scope core flank)

/*annual change in scope*/
sort ionumber year
by ionumber, sort: gen scope_ch=scope - scope[_n-1]


**Figure A.1: Policy scope over time
twoway (bar number year, yaxis(2) barwidth (.7))(tsline scope if year>1974) (tsline core if year>1974) (tsline flank if year>1974) (tsline scope_all) (tsline core_all) (tsline flank_all), legend (cols (1) position(3))



**********************
 /*COMMUNITY*/
**********************

use "INDEP_replication.dta", replace

pca politystdev legal1_rae hunt_rae_cat region_rae religion1_rae, components (1) 

. pca politystdev legal1_rae hunt_rae_cat region_rae religion1_rae, components (1) 

Principal components/correlation                 Number of obs    =      3,279
                                                 Number of comp.  =          1
                                                 Trace            =          5
    Rotation: (unrotated = principal)            Rho              =     0.7946

    --------------------------------------------------------------------------
       Component |   Eigenvalue   Difference         Proportion   Cumulative
    -------------+------------------------------------------------------------
           Comp1 |      3.97293      3.49391             0.7946       0.7946
           Comp2 |      .479017      .192123             0.0958       0.8904
           Comp3 |      .286894      .119801             0.0574       0.9478
           Comp4 |      .167093     .0730283             0.0334       0.9812
           Comp5 |     .0940645            .             0.0188       1.0000
    --------------------------------------------------------------------------

Principal components (eigenvectors) 

    --------------------------------------
        Variable |    Comp1 | Unexplained 
    -------------+----------+-------------
     politystdev |   0.4016 |       .3591 
      legal1_rae |   0.4621 |       .1516 
    hunt_rae_cat |   0.4771 |      .09571 
      region_rae |   0.4439 |        .217 
    religion1_~e |   0.4477 |       .2036 
    --------------------------------------


. corr community8 community8r hunt_rae_cat region_rae religion1_rae politystdev politystdev legal1_rae
(obs=3,279)

             | commun~8 commu~8r hunt_r~t region~e re~1_rae polit~ev polit~ev legal1~e
-------------+------------------------------------------------------------------------
  community8 |   1.0000
 community8r |   1.0000   1.0000
hunt_rae_cat |  -0.9529  -0.9529   1.0000
  region_rae |  -0.8854  -0.8854   0.8172   1.0000
religion1_~e |  -0.8897  -0.8897   0.8585   0.6782   1.0000
 politystdev |  -0.7953  -0.7953   0.7091   0.6784   0.5757   1.0000
 politystdev |  -0.7953  -0.7953   0.7091   0.6784   0.5757   1.0000   1.0000
  legal1_rae |  -0.9199  -0.9199   0.8361   0.7657   0.8421   0.6423   0.6423   1.0000

/*historical ties as alternative operationalization*/
*(a) narrow definition: colonialism, former federation

. list ioname inception members ties_end ties_gap if historical_ties4==1 & end==1, clean noobs

   ioname   incept~n   members   ties_end   ties_gap  
       EAC1       1967         3       1960          7  
        AMU       1989         5       1960         29  
    Benelux       1948         3       1948          0  
       CABI       1987        41       1960         27  
    Caricom       1968        14       1962          6  
       SICA       1952         7       1922         30  
     COMESA       1982        19       1960         22  
        CIS       1992        11       1991          1  
     ComSec       1949        53       1960        -11  
      CEMAC       1966         6       1958          8  
       EAC2       1993         5       1960         33  
        GCC       1981         6       1971         10  
       IGAD       1986         7       1986          0  
     Nordic       1952         5       1905         47  
       OECS       1968         6       1962          6  
        PIF       1973        14       1907         66  


/*broader definition: including pan-movements*/
 list ioname inception members ties_end ties_gap if historical_ties3==1 & end==1, clean noobs

     ioname   incept~n   members   ties_end   ties_gap  
       EAC1       1967         3       1960          7  
        AMU       1989         5       1960         29  
    Benelux       1948         3       1948          0  
       CABI       1987        41       1960         27  
    Caricom       1968        14       1962          6  
       SICA       1952         7       1922         30  
     COMESA       1982        19       1960         22  
        CIS       1992        11       1991          1  
     ComSec       1949        53       1960        -11  
      CEMAC       1966         6       1958          8  
       EAC2       1993         5       1960         33  
         EU       1952        27       1952          0  
        GCC       1981         6       1971         10  
       IGAD       1986         7       1986          0  
       LOAS       1945        21       1945          0  
     Nordic       1952         5       1905         47  
         AU       1963        52       1963          0  
       OECS       1968         6       1962          6  
        OAS       1951        35       1951          0  
        PIF       1973        14       1907         66  



*******************
*CONTRACT*		
*******************

tab contract

contract dichotomized |      Freq.     Percent        Cum.
----------------------+-----------------------------------
  relatively complete |      2,074       63.00       63.00
relatively incomplete |      1,218       37.00      100.00
----------------------+-----------------------------------
                Total |      3,292      100.00
		
  

****************
*POLITICIZATION*
******************

use "INDEP_replication.dta", replace
*Table A.13
tabstat politicization politmoving3, stats (mean p50 cv min max p25 p75 N)
  stats |  politi~n  politm~3
---------+--------------------
    mean |  6.829587  6.460409
     p50 |         0         0
      cv |  6.563444  5.913715
     min |         0         0
     max |       746       565
     p25 |         0         0
     p75 |         0         0
       N |      3292      3292
------------------------------

histogram politmoving3 if end==1, bin(100) percent

collapse (mean) politicization politmoving3 politlog politlogmoving3, by (year)
save "politicization.dta"
*Figure A.3 Trends.
twoway (tsline politicization) (tsline politmoving3)

//**CALCULATION INCIDENCE OF POLITICIZATION 
gen inception_adj=inception
replace inception_adj=1950 if inception<1950
gen age_adj=year-inception_adj +1
gen age_adjend=age_adj if end==1
tab age_adj 
tab age_adjend

by ionumber, sort: egen polsum=sum(politicization)
by ionumber, sort: egen polsummove=sum(politmoving3)
gen avpol= polsum/ age_adjend
gen avpolmove=polsummove/ (age_adjend-2)
tab avpol
tab avpolmove

/*number of years in IO existence with politicization (use moving average)*/
gen polit_D=1 if politmoving3!=0 // create dummy for each year that IO has politicization
replace polit_D=0 if politmoving3==0
by ionumber, sort: egen polit_Dsum=sum(polit_D) // this aggregates number of years with politicization per IO
tab polit_Dsum if end==1


gen polit_D4=1 if polit_Dsum==0 & end==1
replace polit_D4=2 if polit_Dsum>0 & polit_Dsum<5 & end==1
replace polit_D4=3 if polit_Dsum>4 & polit_Dsum<15 & end==1
replace polit_D4=4 if polit_Dsum>14 & end==1
tab polit_D4 
label define politicization 1 "none" 2 "infrequent (1-4 years)" 3 "frequent (5-14 y)" 4 "very frequent (15 y or more)"
label values polit_D4 politicization

**Table A.13: INCIDENCE
tabstat avpol avpolmove age_adjend , stats (mean p50) by (polit_D4)

Summary statistics: mean, p50
  by categories of: polit_D4 

        polit_D4 |     avpol  avpolm~e  age_ad~d
-----------------+------------------------------
            none |         0         0  43.65217
                 |         0         0        50
-----------------+------------------------------
infrequent (1-4  |  .0407191  .0423574  39.76923
                 |  .0322581   .030303        35
-----------------+------------------------------
frequent (5-14 y |  1.443359  1.397217    35.875
                 |  .2614861  .2393162        37
-----------------+------------------------------
very frequent (1 |  23.37663  24.39625  50.83333
                 |  2.510417  2.351047        61
-----------------+------------------------------
           Total |  7.692925  8.005475  43.61842
                 |  .0871212  .0892157      44.5
------------------------------------------------

**Figure A.2: average annual politicization
collapse (sum) politicization, by (ionumber)
gen polit_ch=politicization if politicization<=10
replace polit_ch=((politicization/10)+10) if politicization>10& politicization<=100
replace polit_ch=((politicization/100)+20) if politicization>100& politicization<=1000
replace polit_ch=((politicization/1000)+30) if politicization>1000& politicization<=10000
**blow up the size of bars for IOs with <10 and adjust others

graph hbar (mean) polit_ch if polit_ch>0, over (ioname, sort (1))

gen polit_av=politicization/var5
gen polit_av2=polit_av
replace polit_av2=polit_av*100 if polit_av<=1
replace polit_av2=(polit_av*10) +100 if polit_av>1 & polit_av<=10
replace polit_av2=(polit_av +200) if polit_av>10
**blow up the size of bars for IOs with <1 per year and for IOs with <10 per year

graph hbar (mean) polit_av2 if polit_av2!=0, over (ioname, sort (1))


replace polit_av=politicization
graph hbar (mean) avpolmove if politmoving3 >0 & politmoving3!=.& polit_D4==4, over(ioname, sort (1))
graph save 3, replace
graph hbar (mean) avpolmove if politmoving3 >0 & politmoving3!=. & polit_D4==3, over(ioname, sort (1))
graph save 2, replace
graph hbar (mean) avpolmove if politmoving3 >0 & politmoving3!=. & polit_D4==2, over(ioname, sort (1))
graph save 1, replace
graph combine 1.gph 2.gph 3.gph, graphregion(fcolor(white))



******************************

/*TRADE INTERDEPENDENCE*/

*********************************

gen regional1=regional
replace regional1=0 if ioname=="CCNR"|  ioname=="COE"| ioname=="OAPEC"| ioname=="CERN"| ioname=="ESA"| ioname=="OSCE"| ioname=="SPC"

/*A.14: Correlations among measures of trade interdependence*/
. pwcorr intratradeshare1 intratradeintens1 symtradeintrov1 if regional1==1 & symtradeintrov1!=. & year>1969, sig o

             | intra~e1 intra~s1 symtra~1
-------------+---------------------------
intratrad~e1 |   1.0000 
             |
             |     1013
             |
intratrad~s1 |  -0.0246   1.0000 
             |   0.4334
             |     1013     1013
             |
symtradein~1 |   0.1356   0.2164   1.0000 
             |   0.0000   0.0000
             |     1013     1013     1013



/*A.15: Descriptives on trade interdependence*/
tabstat intratradeshare1 intratradeintens1 symtradeintrov1 if regional1==1 & symtradeintrov1!=. & year>1969, stats (mean p50 cv min
>  max p25 p75)

   stats |  intra~e1  intra~s1  symtra~1
---------+------------------------------
    mean |   15.9157  56.46991  .6800951
     p50 |      9.93      5.13       .76
      cv |  1.059459   4.73154  .5565879
     min |       .04       .25       -.6
     max |     72.12    5228.3      5.36
     p25 |      5.18      2.21       .62
     p75 |     18.18     18.19       .92
----------------------------------------



