*//chapter SEVEN on pooling//
*last change: November 11, 2018, edited May 2020
*LH
********************************
*     *****************************************************************
*     ***************************************************************** 
* 		File-Name:      ch7 do file on pooling_may2020.do       	                 
*   	Date:           Feb 2018 (v1) May 2020 (final)                               
*     	Author:         LH                                          
*     	Purpose:        Create tables and figures for chapter 7 pooling
*    	*     ****************************************************************  
*     ****************************************************************  
*****************
chapter seven: why states pool
penultimate change: 10/31/2018
last chech: 05/05/2020

use "INDEP_replication.dta"

********************************
calculating within and between variance in pooling
********************************************
xtsum pooling

Variable         |      Mean   Std. Dev.       Min        Max |    Observations
-----------------+--------------------------------------------+----------------
pooling  overall |  .2953528   .1863503          0   .7283334 |     N =    3292
         between |             .1757479   .0230313   .6883333 |     n =      76
         within  |             .0566924   .0288227   .5865892 | T-bar = 43.3158


di .1757479^2 / (.1757479^2 + .0566924^2)
.90575071

/**note: this is (nearly) the same as intraclass correlation rho*]*/

 xtreg pooling

Random-effects GLS regression                   Number of obs     =      3,292
Group variable: ionumber                        Number of groups  =         76

R-sq:                                           Obs per group:
     within  = 0.0000                                         min =          9
     between = 0.0000                                         avg =       43.3
     overall = 0.0000                                         max =         61

                                                Wald chi2(0)      =          .
corr(u_i, X)   = 0 (assumed)                    Prob > chi2       =          .

------------------------------------------------------------------------------
     pooling |      Coef.   Std. Err.      z    P>|z|     [95% Conf. Interval]
-------------+----------------------------------------------------------------
       _cons |   .2791493   .0201597    13.85   0.000     .2396371    .3186615
-------------+----------------------------------------------------------------
     sigma_u |  .17546729
     sigma_e |  .05734964
         rho |  .90348598   (fraction of variance due to u_i)
------------------------------------------------------------------------------



use "INDEP_replication.dta"
*******************

*********************************************************************************************
**FIGURE 7.1, 7.2, 7.3: risks of exploitation, decision costs, trade-off : in word

*********************************************************************************************

******************************************************************************************************
**FIGURE 7.4: SCALE IN 2010 AND POOLING AT START
***********************************************************************************************
twoway (lfitci pooling memberslogend) (scatter pooling memberslogend if initial==1, mcolor(gs4) msize(small) msymbol(diamond) mlabel(ioname)) if initial==1
corr memberslogend pooling if initial==1

log 0.7=5; 1=10; 1.4=25; 1.7=50; 2=100; 2.3=200


********************************************************************************************
/*VARIOUS NEW VARIABLES*/

gen memberslogend=members_log if end==1
gsort ionumber -year
by ionumber, sort: replace memberslogend=memberslogend[_n-1] if memberslogend==.
gen membersend=members if end==1
gsort ionumber -year
by ionumber, sort: replace membersend=membersend[_n-1] if membersend==.
sort ionumber year
by ionumber, sort: gen members_ch=members-members{_n-1]
by ionumber, sort: gen members_chab=abs (members_ch)

gen poolcreation=pooling if initial==1
sort ionumber year
by ionumber, sort: replace poolcreation=poolcreation[_n-1] if poolcreation==.
by ionumber, sort: gen poolchange=pooling-poolcreation if end==1 /*difference in pooling end vs. beginning: 1 value*/
by ionumber, sort: gen pooling_ch=pooling-pooling[_n-1]
by ionumber, sort: gen pooling_chabs=abs(pooling-pooling[_n-1])

gen delcreation=delegation if initial==1
sort ionumber year
by ionumber, sort: replace delcreation=delcreation[_n-1] if delcreation==.
by ionumber, sort: gen delchange=delegation-delcreation if end==1
by ionumber, sort: gen delegation_ch=delegation-delegation[_n-1]
by ionumber, sort: gen delegation_chabs=abs(delegation_ch)
gen delend=delegation if end==1
gsort ionumber -year
by ionumber, sort: replace delend=delend[_n-1] if delend==.

label variable members_ch "annual change in members"
label variable members_chabs "annual absolute change in members"
label variable membersend "members at end generalized"
label variable memberslogend "memberslog at end generalized"

label variable poolcreation "pooling in initial year generalized"
label variable poolend "pooling at end generalized"
label variable poolchange "difference in pooling end vs. beginning: 1 value"
label variable pooling_ch "annual change in pooling"
label variable pooling_chabs "annual absolute change in pooling"

label variable delcreation "delegation in initial year generalized"
label variable delend "delegation at end generalized"
label variable delchange "difference in delegationg end vs. beginning: 1 value"
label variable delegation_ch "annual change in delegation"
label variable delegation_chabs "annual absolute change in delegation"

gen gdpmean1000=gdpmean*1000

*********************************************************************************
****TABLE 7.1: CROSS-SECTIONAL MODELS FOR POOLING:
********************************************************************************** 
tsset ionumber year

reg pooling members_log scope corestate2 politmoving300 politymean capabilities1 gdpmean1000 gdpcov if initial==1
reg pooling memberslogend scope corestate2 politmoving300 politymean capabilities1 gdpmean1000 gdpcov if initial==1
estat ic

*calculate average membership*
collapse (mean) members members_log, by (ionumber)
save "membersav.dta"
rename members membersav 
rename members_log members_logav
merge m:1 ionumber using "membersav.dta", keepusing(membersav members_logav)
gen membersavlog=log10(membersav)
reg pooling membersavlog scope corestate2 politmoving300 politymean capabilities1 gdpmean1000 gdpcov if initial==1
estat ic

/*full results in appendix (B.23) + bivariate analyses in B.24*/
reg pooling members_log scope politmoving300 politymean capabilities1 gdpmean1000 gdpcov corestate2 if initial==1
reg pooling memberslogend scope politmoving300 politymean capabilities1 gdpmean1000 gdpcov corestate2 if initial==1
reg pooling membersavlog scope politmoving300 politymean capabilities1 gdpmean1000 gdpcov corestate2 if initial==1

tabstat membersavlog membersav if initial, stats (mean min max sd)
margins, at (memberslogend=(0(.1)2.3))
marginsplot

reg pooling members_log if initial==1
reg pooling memberslogend if initial==1
reg pooling membersavlog if initial==1
reg pooling members if initial==1
reg pooling membersend if initial==1
reg pooling membersav if initial==1

reg pooling members scope politmoving300 politymean capabilities1 gdpmean1000 corestate2 if initial==1
reg pooling membersend scope politmoving300 politymean capabilities1 gdpmean1000 corestate2 if initial==1
reg pooling membersav scope politmoving300 politymean capabilities1 gdpmean1000 corestate2 if initial==1

**type I and type II
reg pooling membersavlog scope corestate2 politmoving300 politymean capabilities1 gdpmean1000 gdpcov if initial==1 & typeI==0
reg pooling membersavlog scope corestate2 politmoving300 politymean capabilities1 gdpmean1000 gdpcov if initial==1 & typeI==1
reg pooling memberslogend scope corestate2 politmoving300 politymean capabilities1 gdpmean1000 gdpcov if initial==1 & typeI==0
reg pooling memberslogend scope corestate2 politmoving300 politymean capabilities1 gdpmean1000 gdpcov if initial==1 & typeI==1
reg pooling memberslogend scope corestate2 politmoving300 politymean capabilities1 gdpmean1000 gdpcov if initial==1 & typeI==0 & ioname!="IGAD" & ioname!="Benelux" & ioname!="Caricom"
reg pooling memberslogend scope corestate2 politmoving300 politymean capabilities1 gdpmean1000 gdpcov if initial==1 & (typeI==1|ioname=="IGAD"|ioname=="Benelux"|ioname=="Caricom")





*********************************************************************************************

****TABLE 7.3: THREE MEMBERSHIPS AND MAJORITIES 

 
**ESTIMATE WHEN MAJORITARIAN VOTING
 use "MASTER_xxx_FINAL.dta",
clear

*create a variable that counts whether accession is taken by majority + gauge whether ratification (whereby rat by some and binding for all=no ratification)
gen accessvote=0 if (ACC16b_A1<2| ACC16b_A2<2| ACC16b_A3<2| ACC16b_E1<2| ACC16b_E2<2| ACC16b_E3<2)
replace accessvote=1 if accessvote!=0 & (ACC16b_A1==2| ACC16b_A1==3| ACC16b_A2==2| ACC16b_A2==3| ACC16b_A3==2| ACC16b_A3==3| ACC16b_E1==2| ACC16b_E1==3|ACC16b_E2==2| ACC16b_E2==3|ACC16b_E3==2|ACC16b_E3==3|ACC16b_technocratic==1)
replace accessvote=0 if ACC16b_norule==99

gen accessnorat=1 if ACC17==2
replace accessnorat=0 if accessnorat==.


 . tab accessvote accessnorat if end==1 & members>50 & members!=.

           |      accessnorat
accessvote |         0          1 |     Total
-----------+----------------------+----------
         0 |         0          4 |         4 
         1 |         1         25 |        26 
-----------+----------------------+----------
     Total |         1         29 |        30 

. list ioname if accessvote==0 & accessnorat==1 & end==1& members>50

      +--------+
      | ioname |
      |--------|
 773. | ComSec |
2358. |    OIC |
2488. |   OSCE |
2969. |     UN |
      +--------+


	 
**create a variable that counts whether suspension is taken by majority 
gen suspensvote=0 if (SUSP18b_A1<2| SUSP18b_A2<2| SUSP18b_A3<2| SUSP18b_E1<2| SUSP18b_E2<2| SUSP18b_E3<2)
replace suspensvote=1 if suspensvote!=0 & (SUSP18b_A1==2| SUSP18b_A1==3| SUSP18b_A2==2| SUSP18b_A2==3| SUSP18b_A3==2| SUSP18b_A3==3| SUSP18b_E1==2| SUSP18b_E1==3|SUSP18b_E2==2| SUSP18b_E2==3|SUSP18b_E3==2|SUSP18b_E3==3|SUSP18b_technocratic==1)
replace suspensvote=0 if SUSP18b_norules==99|SUSP18b_norules==1

*all but three IOs have no rules for suspension; three use unanimity: ComSec, IMF, OSCE
list ioname suspensvote SUSP18b_norules if members>50 & end==1 & members!=. & suspensvote==0, noobs clean

      ioname   suspen~e   SUSP18~s  
         BIS          0         99  
      ComSec          0          .  
         FAO          0         99  
         GEF          0         99  
         ICC          0         99  
         IMF          0          .  
         ITU          0         99  
      IWhale          0         99  
    Interpol          0         99  
         OIC          0         99  
        OSCE          0          .  
         PCA          0          1  
         UPU          0         99  
         WCO          0         99  
        WIPO          0         99  

**create a variable that counts whether constitutional reform is taken by majority 
gen constitvote=0 if (CON19b_A1<2| CON19b_A2<2| CON19b_A3<2| CON19b_E1<2| CON19b_E2<2| CON19b_E3<2)
replace constitvote=1 if constitvote!=0 & (CON19b_A1==2| CON19b_A1==3| CON19b_A2==2| CON19b_A2==3| CON19b_A3==2| CON19b_A3==3| CON19b_E1==2| CON19b_E1==3|CON19b_E2==2| CON19b_E2==3|CON19b_E3==2|CON19b_E3==3|CON19b_technocratic==1)
replace constitvote=0 if CON19b_norule==99|CON19b_norule==1| CON19b_norule==98

gen constitnorat=1 if CON20==2|CON20==3
replace constitnorat=0 if constitnorat==.
	 
. tab constitvote constitnorat if end==1 & members>50 & members!=.

constitvot |     constitnorat
         e |         0          1 |     Total
-----------+----------------------+----------
         0 |         4          4 |         8 
         1 |         8         14 |        22 
-----------+----------------------+----------
     Total |        12         18 |        30 

	 ** IOs without rules on constitutional ratification/ amendment
	 
list ioname CON20 if (CON20==98| CON20==99) & end==1 & members>50

      +----------------+
      | ioname   CON20 |
      |----------------|
1792. | IWhale      98 |
2610. |    PCA      98 |
      +----------------
  
  ** IOs that use consensus on constitutional amendment or do not provide for constitutional amendment
 
 list ioname constitvote CON20 if end==1 & members>50 & constitvote==0, noobs clean

    ioname   consti~e   CON20  
    ComSec          0       3  
       GEF          0       3  
      IBRD          0       0  
       ISA          0       2  
    IWhale          0      98 ** contract cannot be amended
      OSCE          0       3  
       PCA          0      98 ** contract cannot be amended 
       WCO          0       0  


 **create a variable that counts whether budgetary allocation is decided by majority 
gen budgetvote=0 if (BUD22b_A1<2| BUD22b_A2<2| BUD22b_A3<2| BUD22b_E1<2| BUD22b_E2<2| BUD22b_E3<2)
replace budgetvote=1 if budgetvote!=0 & (BUD22b_A1==2| BUD22b_A1==3| BUD22b_A2==2| BUD22b_A2==3| BUD22b_A3==2| BUD22b_A3==3| BUD22b_E1==2| BUD22b_E1==3|BUD22b_E2==2| BUD22b_E2==3|BUD22b_E3==2|BUD22b_E3==3|BUD22b_technocratic==1)
replace budgetvote=0 if BUD22b_norule==99|BUD22b_norule==1| BUD22b_norule==98

** budget bindingness
gen budgetbinding=1 if BUD23==2
replace budgetbinding=0.5 if BUD23==1
replace budgetbinding=0 if BUD23==0| BUD23==98| BUD23==99

tab budgetvote budgetbinding if end==1 & members>50 & members!=., missing

**ALL large IOs have a binding budget procedure

. tab budgetvote budgetbinding if end==1 & members>50 & members!=.

           | budgetbind
           |    ing
budgetvote |         1 |     Total
-----------+-----------+----------
         0 |         2 |         2 
         1 |        28 |        28 
-----------+-----------+----------
     Total |        30 |        30 
	 
 **create a variable that counts whether financial compliance is decided by majority 
gen complivote=0 if (COM24b_A1<2| COM24b_A2<2| COM24b_A3<2| COM24b_E1<2| COM24b_E2<2| COM24b_E3<2)
replace complivote=1 if complivote!=0 & (COM24b_A1==2| COM24b_A1==3| COM24b_A2==2| COM24b_A2==3| COM24b_A3==2| COM24b_A3==3| COM24b_E1==2| COM24b_E1==3|COM24b_E2==2| COM24b_E2==3|COM24b_E3==2|COM24b_E3==3|COM24b_technocratic==1)
replace complivote=0 if COM24b_norule==99|COM24b_norule==1| COM24b_norule==98

 . tab complivote if end==1 & members>50 & members!=.

 complivote |      Freq.     Percent        Cum.
------------+-----------------------------------
          0 |          3       10.00       10.00
          1 |         27       90.00      100.00
------------+-----------------------------------
      Total |         30      100.00

**three cases with voting rule=zero (PCA has no rules)

. list ioname complivote COM24b_norule COM24b_technocratic if complivote==0 & end==1 & members>50 & members!=., noobs

  +-----------------------------------------+
  | ioname   compli~e   COM24b..   COM24b~c |
  |-----------------------------------------|
  |    IMF          0          .          . |
  |   OSCE          0          .          . |
  |    PCA          0         99          . |
  +-----------------------------------------+

** five cases with fully technocratic procedure

 list ioname complivote COM24b_A1 COM24b_A2 COM24b_A3 COM24b_E1 COM24b_E2 COM24b_E3 COM24b_technocratic if end==1 & members>50 & members!=. & COM24b_technocratic==1, noobs

  +------------------------------------------------------------------------------------------------+
  | ioname   compli~e   COM~b_A1   COM~b_A2   COM~b_A3   COM~b_E1   COM~b_E2   COM~b_E3   COM24b~tech|
  |------------------------------------------------------------------------------------------------|
  | ComSec          1          .          .          .          .          .          .          1 |
  |    GEF          1          .          .          .          .          .          .          1 |
  |    ITU          1          .          .          .          .          .          .          1 |
  | IWhale          1          .          .          .          .          .          .          1 |
  |    UPU          1          .          .          .          .          .          .          1 |
  +------------------------------------------------------------------------------------------------+

  
 **create a variable that counts whether policy1 is decided by majority 
replace pol1vote=0 if (PM1_25b_A1<2| PM1_25b_A2<2| PM1_25b_A3<2| PM1_25b_E1<2| PM1_25b_E2<2| PM1_25b_E3<2)
replace pol1vote=1 if pol1vote!=0 & (PM1_25b_A1==2| PM1_25b_A1==3| PM1_25b_A2==2| PM1_25b_A2==3| PM1_25b_A3==2| PM1_25b_E1==3|PM1_25b_E1==2| PM1_25b_E2==2| PM1_25b_E2==3|PM1_25b_E3==2|PM1_25b_E3==3)
replace pol1vote=0 if PM1_25b_norule==99|PM1_25b_norule==1| PM1_25b_norule==98

***create bindingness 
gen pol1binding=1 if PM1_26==2
replace pol1binding=0.5 if PM1_26==1
replace pol1binding=0 if PM1_26==0| PM1_26==98| PM1_26==99

. tab pol1vote pol1binding if end==1 & members>50 & members!=., missing

           |           pol1binding
  pol1vote |         0         .5          1 |     Total
-----------+---------------------------------+----------
         0 |         2          0          1 |         3 
         1 |         7         13          7 |        27 
-----------+---------------------------------+----------
     Total |         9         13          8 |        30 


***create nonratification
gen pol1norat=1 if PM1_27==2|PM1_27==3
replace pol1norat=0 if pol1norat==. & PM1_27!=.

. tab pol1vote pol1norat if end==1 & members>50 & members!=., missing

           |       pol1norat
  pol1vote |         0          1 |     Total
-----------+----------------------+----------
         0 |         0          3 |         3 
         1 |         5         22 |        27 
-----------+----------------------+----------
     Total |         5         25 |        30 


. tab pol1binding pol1norat if end==1 & members>50 & members!=., missing

pol1bindin |       pol1norat
         g |         0          1 |     Total
-----------+----------------------+----------
         0 |         0          9 |         9 
        .5 |         5          8 |        13 
         1 |         0          8 |         8 
-----------+----------------------+----------
     Total |         5         25 |        30 

**just eight IOs combine bindingness with no ratification, and seven use majority voting while one of these (UN) uses selective veto 	 


  +-----------------------------------------+
  | ioname   pol1vote   pol1bi~g   pol1no~t |
  |-----------------------------------------|
  |     AU          1          1          1 |
  |    GEF          1          1          1 |
  |   IBRD          1          1          1 |
  |    ICC          1          1          1 |
  |    IMF          1          1          1 |
  |-----------------------------------------|
  |    ISA          1          1          1 |
  |     UN          0          1          1 |
  |    WTO          1          1          1 |
  +-----------------------------------------+


**create a variable that counts whether policy2 is decided by majority 
gen pol2vote=0 if (PM2_25b_A1<2| PM2_25b_A2<2| PM2_25b_A3<2| PM2_25b_E1<2| PM2_25b_E2<2| PM2_25b_E3<2)
replace pol2vote=1 if pol2vote!=0 & (PM2_25b_A1==2| PM2_25b_A1==3| PM2_25b_A2==2| PM2_25b_A2==3| PM2_25b_A3==2| PM2_25b_E1==3|PM2_25b_E1==2| PM2_25b_E2==2| PM2_25b_E2==3|PM2_25b_E3==2|PM2_25b_E3==3)
replace pol2vote=0 if PM2_25b_norule==99|PM2_25b_norule==1| PM2_25b_norule==98

***create bindingness 
gen pol2binding=1 if PM2_26==2
replace pol2binding=0.5 if PM2_26==1
replace pol2binding=0 if PM2_26==0| PM2_26==98| PM2_26==99

. tab pol2vote pol2binding if end==1 & members>50 & members!=.

           |           pol2binding
  pol2vote |         0         .5          1 |     Total
-----------+---------------------------------+----------
         0 |         1          0          0 |         1 
         1 |         3          3          2 |         8 
-----------+---------------------------------+----------
     Total |         4          3          2 |         9 


***create nonratification
gen pol2norat=1 if PM2_27==2|PM2_27==3
replace pol2norat=0 if pol2norat==. & PM2_27!=.

. tab pol2vote pol2norat if end==1 & members>50 & members!=.

           |       pol2norat
  pol2vote |         0          1 |     Total
-----------+----------------------+----------
         0 |         0          1 |         1 
         1 |         2          6 |         8 
-----------+----------------------+----------
     Total |         2          7 |         9 

. tab pol2binding pol2norat if end==1 & members>50 & members!=.

pol2bindin |       pol2norat
         g |         0          1 |     Total
-----------+----------------------+----------
         0 |         0          4 |         4 
        .5 |         2          1 |         3 
         1 |         0          2 |         2 
-----------+----------------------+----------
     Total |         2          7 |         9 

**just two IOs combine bindingness with no ratification and majority voting


. list ioname pol2vote pol2binding pol2norat if end==1 & members>50 & members!=. & pol2binding==1 & pol
> 2norat==1, noobs

  +-----------------------------------------+
  | ioname   pol2vote   pol2bi~g   pol2no~t |
  |-----------------------------------------|
  |     AU          1          1          1 |
  |   IAEA          1          1          1 |
  +-----------------------------------------+

 **create a variable that counts whether policy3 is decided by majority 
gen pol3vote=0 if (PM3_25b_A1<2| PM3_25b_A2<2| PM3_25b_A3<2| PM3_25b_E1<2| PM3_25b_E2<2| PM3_25b_E3<2)
replace pol3vote=1 if pol3vote!=0 & (PM3_25b_A1==2| PM3_25b_A1==3| PM3_25b_A2==2| PM3_25b_A2==3| PM3_25b_A3==2| PM3_25b_E1==3|PM3_25b_E1==2| PM3_25b_E2==2| PM3_25b_E2==3|PM3_25b_E3==2|PM3_25b_E3==3)
replace pol3vote=0 if PM3_25b_norule==99|PM3_25b_norule==1| PM3_25b_norule==98

***create bindingness 
gen pol3binding=1 if PM3_26==2
replace pol3binding=0.5 if PM3_26==1
replace pol3binding=0 if PM3_26==0| PM3_26==98| PM3_26==99 
  
. tab pol3vote pol3binding if end==1 & members>50 & members!=.

           | pol3bindin
           |     g
  pol3vote |         0 |     Total
-----------+-----------+----------
         0 |         1 |         1 
         1 |         1 |         1 
-----------+-----------+----------
     Total |         2 |         2 

***create nonratification
gen pol3norat=1 if PM3_27==2|PM3_27==3
replace pol3norat=0 if pol3norat==. & PM3_27!=.

. tab pol3vote pol3norat if end==1 & members>50 & members!=.

           | pol3norat
  pol3vote |         1 |     Total
-----------+-----------+----------
         0 |         1 |         1 
         1 |         1 |         1 
-----------+-----------+----------
     Total |         2 |         2 
	 
	 
. tab pol3binding pol3norat if end==1 & members>50 & members!=.


pol3bindin | pol3norat
         g |         1 |     Total
-----------+-----------+----------
         0 |         2 |         2 
-----------+-----------+----------
     Total |         2 |         2 

	 ** Comsec and UN: neither combines majority + binding + noratification


 **create a variable that counts whether policy4 is decided by majority : NONE
gen pol4vote=0 if (PM4_25b_A1<2| PM4_25b_A2<2| PM4_25b_A3<2| PM4_25b_E1<2| PM4_25b_E2<2| PM4_25b_E3<2)
replace pol4vote=1 if pol4vote!=0 & (PM4_25b_A1==2| PM4_25b_A1==3| PM4_25b_A2==2| PM4_25b_A2==3| PM4_25b_A3==2| PM4_25b_E1==3|PM4_25b_E1==2| PM4_25b_E2==2| PM4_25b_E2==3|PM4_25b_E3==2|PM4_25b_E3==3)
replace pol4vote=0 if PM4_25b_norule==99|PM4_25b_norule==1| PM4_25b_norule==98

gen pol4binding=1 if PM4_26==2
replace pol4binding=0.5 if PM4_26==1
replace pol4binding=0 if PM4_26==0| PM4_26==98| PM4_26==99 

***create nonratification
gen pol4norat=1 if PM4_27==2|PM4_27==3
replace pol4norat=0 if pol4norat==. & PM4_27!=.

 **create a variable that counts whether policy5 is decided by majority : NONE
gen pol5vote=0 if (PM5_25b_A1<2| PM5_25b_A2<2| PM5_25b_A3<2| PM5_25b_E1<2| PM5_25b_E2<2| PM5_25b_E3<2)
replace pol5vote=1 if pol5vote!=0 & (PM5_25b_A1==2| PM5_25b_A1==3| PM5_25b_A2==2| PM5_25b_A2==3| PM5_25b_A3==2| PM5_25b_E1==3|PM5_25b_E1==2| PM5_25b_E2==2| PM5_25b_E2==3|PM5_25b_E3==2|PM5_25b_E3==3)
replace pol5vote=0 if PM5_25b_norule==99|PM5_25b_norule==1| PM5_25b_norule==98
	 
gen pol5binding=1 if PM5_26==2
replace pol5binding=0.5 if PM5_26==1
replace pol5binding=0 if PM5_26==0| PM5_26==98| PM5_26==99 

***create nonratification
gen pol5norat=1 if PM5_27==2|PM5_27==3
replace pol5norat=0 if pol5norat==. & PM5_27!=.
	 
	 
*<<NOW CALCULATE MAJORITY VOTING FOR ALL IOS AT END STAGE>>**

list  ionumber ioname pol1vote pol1binding pol1norat pol2vote pol2binding pol2norat pol3vote pol3binding pol3norat pol4vote pol4binding pol4norat pol5vote pol5binding pol5norat if end==1, noobs clean

save as excel file "all IOs on majority binding norat"
**identify manually IOs with most supranational voting record (look at combination of vote, binding, rat)
**then calculate polvote10, polbinding10, polnorat10

gen polvote10=pol1vote if end==1
gen polbind10=pol1binding if end==1
gen polnorat10=pol1norat if end==1

replace polvote10=pol2vote if end==1 & (ionumber==470| ionumber==840| ionumber==4190| ionumber==1650| ionumber==1830| ionumber==1840| ionumber==2370| ionumber==3430| ionumber==3590| ionumber==3750| ionumber==5550)
replace polbind10=pol2binding if end==1 & (ionumber==470| ionumber==840| ionumber==4190|ionumber==1650| ionumber==1830| ionumber==1840| ionumber==2370| ionumber==3430| ionumber==3590| ionumber==3750| ionumber==5550)
replace polnorat10=pol2norat if end==1 & (ionumber==470| ionumber==840| ionumber==4190|ionumber==1650| ionumber==1830| ionumber==1840| ionumber==2370| ionumber==3430| ionumber==3590| ionumber==3750| ionumber==5550)
*//AMU Benelux, WCO, EU, FAO, IAEA, ALADI, NordC, OECD, SPC, SCO //
replace polvote10=pol3vote if end==1 & ionumber==1520
replace polbind10=pol3binding if end==1 & ionumber==1520
replace polnorat10=pol3norat if end==1 & ionumber==1520 //ECOWAS//

**now calculate majorityvote
gen majorityvote= accessvote + suspensvote + constitvote + budgetvote + complivote + polvote10 if end==1 & members!=.
	 
**now calculate bindingness
gen binding=polbind10 if end==1 & members!=.

**now calculate noratification	 
gen noratif= (accessnorat + constitnorat + polnorat10)/3


***NOW CALCULATE MAJORITY VOTE (ADJUSTED FOR BINDING AND RATIFICATION FOR EACH DECISION AREA

gen accessmaj=1 if accessvote==1 & accessnorat==1
replace accessmaj=0 if accessmaj==.
gen suspensmaj=suspensvote
gen constitmaj=1 if constitvote==1 & constitnorat==1
replace constitmaj=0 if constitmaj==.
gen budgetmaj=1 if budgetvote==1 & budgetbinding==1
replace budgetmaj=0 if budgetmaj==.
gen compliancemaj= complivote
gen policymaj=1 if polvote10==1 & polbind10==1 & polnorat10==1
replace policymaj=0 if policymaj==.
gen MAJORITY=.
order MAJORITY accessmaj suspensmaj constitmaj budgetmaj compliancemaj policymaj, after ( noratif)
gen VOTEOVERALL=.
gen majority= accessmaj+ suspensmaj +constitmaj +budgetmaj +compliancemaj +policymaj

gen members_trich=1 if members<25
replace members_trich=2 if members>24 & members<56
replace members_trich=3 if members>55


**Table 7.3: membership and number of decision areas by majority
gen members_dich55=1 if members>55
replace members_dich55=0 if members<=55
tab members_dich55 if end==1

members_dic |
        h55 |      Freq.     Percent        Cum.
------------+-----------------------------------
          0 |         51       67.11       67.11
          1 |         25       32.89      100.00
------------+-----------------------------------
      Total |         76      100.00


gen members_trich=1 if members<25
replace members_trich=2 if members>24 & members<56
replace members_trich=3 if members>55

tab majority members_trich if end==1, chi2

. tab majority members_trich if end==1, chi2

           |          members_trich
  majority |         1          2          3 |     Total
-----------+---------------------------------+----------
         0 |        18          3          0 |        21 
         1 |        11          2          0 |        13 
         2 |         3          3          1 |         7 
         3 |         3          4          5 |        12 
         4 |         0          2         10 |        12 
         5 |         0          1          8 |         9 
         6 |         0          1          1 |         2 
-----------+---------------------------------+----------
     Total |        35         16         25 |        76 

         Pearson chi2(12) =  57.7960   Pr = 0.000



***********************************************************************************************

use "INDEP_replication.dta"

*******************************************************************************
*****TABLE 7.2: EPISTEMIC COMMUNITY + appendix B.28
*******************************************************************************
reg pooling episteme if initial==1
reg pooling episteme politymean capabilities1 gdpmean1000 gdpcov if initial==1
reg pooling episteme corestate2 politmoving300 politymean capabilities1 gdpmean1000 gdpcov if initial==1
reg pooling episteme membersavlog corestate2 politmoving300 politymean capabilities1 gdpmean1000 gdpcov if initial==1
estat ic 

reg pooling idealdistmean scope corestate2 politmoving300 politymean capabilities1 gdpmean1000 if initial==1
reg pooling membersavlog idealdistmean scope corestate2 politmoving300 politymean capabilities1 gdpmean1000 if initial==1

***********************************************************************************
***appendix: correlations on alternative specifications for membership (B.27)
*************************************************************************************
collapse (mean) pooling members_log members episteme, by (ionumber)
save "correlationscollapse.dta"
gen membersavlog=log10(members)
pwcorr pooling membersavlog members episteme, sig b
pcorr pooling membersavlog episteme
pcorr pooling members episteme

**************************************************************************************************
***appendix:  HOMOGENEITY HYPOTHESIS: ideal points as alternative hypothesis: B.25
**************************************************************************************************
reg pooling idealdistmean if initial==1
reg pooling membersavlog idealdistmean scope corestate2 politmoving300 politymean capabilities1 gdpmean1000 gdpcov if initial==1
reg pooling idealdistmean scope corestate2 politmoving300 politymean capabilities1 gdpmean1000 gdpcov if initial==1
estat ic


**************************************************************************************************
*calculate security IOs: NATO and OSCE  // APPENDIX B.23
/*{take Boehmer classification Boehmer_sec and eliminate all IOs that also have another assignment)*/
****************************************************************************************************
list ioname pooling delegation if boeh_security ==1 & end==1 & boeh_economic!=1 & boeh_multiissue!=1
gen secdummy=1 if ioname=="NATO"| ioname=="OSCE"
replace secdummy=0 if secdummy==.
reg pooling membersavlog scope secdummy politmoving300 politymean capabilities1 gdpmean1000 gdpcov if initial==1
reg pooling memberslogend scope secdummy politmoving300 politymean capabilities1 gdpmean1000 gdpcov if initial==1
estat ic


Between regression (regression on group means)  Number of obs     =      3,203
Group variable: ionumber                        Number of groups  =         76

R-sq:                                           Obs per group:
     within  = 0.0097                                         min =          8
     between = 0.6286                                         avg =       42.1
     overall = 0.5172                                         max =         60

                                                F(6,69)           =      19.46
sd(u_i + avg(e_i.))=  .1097301                  Prob > F          =     0.0000

-------------------------------------------------------------------------------
    F.pooling |      Coef.   Std. Err.      t    P>|t|     [95% Conf. Interval]
--------------+----------------------------------------------------------------
  members_log |   .1811817   .0360509     5.03   0.000     .1092621    .2531012
        scope |  -.0040439   .0034075    -1.19   0.239    -.0108417    .0027539
     secdummy |   -.169394   .0802471    -2.11   0.038    -.3294826   -.0093054
   politymean |  -.0009048   .0029808    -0.30   0.762    -.0068513    .0050416
capabilities1 |  -.1572462   .0848529    -1.85   0.068    -.3265231    .0120307
  gdpmean1000 |  -.0002245   .0024479    -0.09   0.927    -.0051079     .004659
        _cons |   .1287295   .0966889     1.33   0.187    -.0641596    .3216185
-------------------------------------------------------------------------------

*******************************************************************



